@@ -10,7 +10,7 @@ $LastChangedRevision$
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-28 17:06:50 -0800 (Mon, 28 Nov 2005) $
+$LastChangedDate: 2006-01-17 16:09:49 -0800 (Tue, 17 Jan 2006) $
 
 =head1 DESCRIPTION
 
@@ -40,7 +40,7 @@ use lib './lib'; # To get local version number.
 # make sure we're root, otherwise uninformative errors result
 unless ($> == 0) {
     print "This process must (usually) be run as root.\n";
-    exit 1 unless ask_yesno("Continue as non-root user? [yes] ", 1);
+    exit 1 unless ask_yesno("Continue as non-root user?", 1);
 }
 
 # setup default root
@@ -61,7 +61,7 @@ print q{
 
 };
 
-exit 1 unless ask_yesno("Continue with the upgrade? [yes] ", 1);
+exit 1 unless ask_yesno("Continue with the upgrade?", 1);
 
 print "\n\n==> Setting-up Bricolage Upgrade Process <==\n\n";
 
@@ -117,7 +117,7 @@ another.  Please use "make install" if you wish to overwrite your
 current install.
 
 END
-        exit 1 unless ask_yesno("Continue with upgrade? [no] ", 0);
+        exit 1 unless ask_yesno("Continue with upgrade?", 0);
         @todo = ($VERSION);
 
     } else {
