@@ -17,7 +17,7 @@ use Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-28 18:15:17 -0800 (Mon, 28 Nov 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -288,6 +288,7 @@ sub test_table($) {
   exit if test_column $table_name, $column_name, $min_size;
   exit if test_column $table_name, $column_name, undef, $not_null;
   exit if test_column $table_name, $column_name, $min_size, $not_null;
+  exit if test_column $table_name, $column_name, $min_size, $not_null, $type;
 
 This function returns true if the specified column exists in specified table
 in the Bricolage database, and false if it does not. Use C<test_column()> in
@@ -391,7 +392,7 @@ sub test_constraint($$;$) {
   exit if test_foreign_key $table_name, $foreign_key_name;
   exit if test_foreign_key $table_name, $foreign_key_name, $delete_code;
 
-This function returns true if the specified foreign key constriant exists on
+This function returns true if the specified foreign key constraint exists on
 the specified table in the Bricolage database, and false if it does not. This
 is useful in upgrade scripts that add a new foreign key, and want to verify
 that the constraint has not already been created. The optional third argument
@@ -421,14 +422,14 @@ sub test_foreign_key($$;$) {
 
   exit if test_primary_key $table_name, $primary_key_name;
 
-This function returns true if the specified primary key constriant exists on
+This function returns true if the specified primary key constraint exists on
 the specified table in the Bricolage database, and false if it does not. This
 is useful in upgrade scripts that add a new primary key, and want to verify
 that the constraint has not already been created.
 
 =cut
 
-sub test_primary_key($$;$) {
+sub test_primary_key($$) {
     my ($table, $fk) = @_;
     my $sql = qq{
         SELECT 1
@@ -643,7 +644,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
