@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-16 12:29:31 -0800 (Mon, 16 Jan 2006) $
+$LastChangedDate: 2006-06-16 12:07:25 -0700 (Fri, 16 Jun 2006) $
 
 =head1 SYNOPSIS
 
@@ -67,8 +67,9 @@ $LastChangedDate: 2006-01-16 12:29:31 -0800 (Mon, 16 Jan 2006) $
  $asset = $asset->set_workflow_id($id);
 
  # Access note information
- $asset                 = $asset->add_note($note)
- ($note_list || @notes) = $asset->get_notes()
+ $asset         = $asset->set_note($note);
+ my $note       = $asset->get_note;
+ my $notes_href = $asset->get_notes()
 
  # Access active status
  $asset            = $asset->deactivate()
@@ -104,6 +105,7 @@ number the same but will associate a user with the object.
 # Standard Dependencies
 
 use strict;
+use List::Util qw(first);
 
 #--------------------------------------#
 # Programmatic Dependencies
@@ -151,8 +153,9 @@ use constant HAS_MULTISITE => 1;
 #--------------------------------------#
 # Private Class Fields
 my $meths;
-my @ord = qw(id name description priority uri cover_date version element
-             needs_publish publish_status expire_date active site_id site);
+my @ord = qw(id version_id name description priority uri cover_date version
+             element_type needs_publish publish_status expire_date active
+             site_id site);
 
 #--------------------------------------#
 # Instance Fields
@@ -177,6 +180,7 @@ BEGIN {
                         workflow_id       => Bric::FIELD_RDWR,
                         desk_id           => Bric::FIELD_READ,
                         site_id           => Bric::FIELD_RDWR,
+                        note              => Bric::FIELD_RDWR,
 
                         # Private Fields
                         _checkin          => Bric::FIELD_NONE,
@@ -185,11 +189,10 @@ BEGIN {
                         _active           => Bric::FIELD_NONE,
                         _delete           => Bric::FIELD_NONE,
                         _notes            => Bric::FIELD_NONE,
-                        _attribute_object => Bric::FIELD_NONE,
-                        _attr_cache       => Bric::FIELD_NONE,
-                        _update_attrs     => Bric::FIELD_NONE,
+                        _got_notes        => Bric::FIELD_NONE,
                         _versions         => Bric::FIELD_NONE,
                         _desk             => Bric::FIELD_NONE,
+                        _site             => Bric::FIELD_NONE,
         });
 }
 
@@ -219,7 +222,7 @@ sub new {
 
 =item $asset = Bric::Biz::Asset::Business::Media->lookup({ id => $id })
 
-=item $asset = Bric::Biz::Asset::Formatting->lookup({ id => $id })
+=item $asset = Bric::Biz::Asset::Template->lookup({ id => $id })
 
 This will return an asset that matches the ID provided.
 
@@ -240,10 +243,10 @@ NONE
 sub lookup {
     my ($pkg, $param) = @_;
     $pkg = ref $pkg || $pkg;
-    throw_gen(error => "Missing Required Parameters id or version_id")
-      unless $param->{id} || $param->{version_id}
+    throw_gen(error => "Missing Required Parameters id or uuid or version_id")
+      unless $param->{id} || $param->{version_id} || $param->{uuid}
       || ($param->{alias_id} && $param->{site_id});
-    throw_mni(error => 'Must call list on Story, Media, or Formatting')
+    throw_mni(error => 'Must call list on Story, Media, or Template')
       unless $pkg->CAN_DO_LOOKUP;
     # Check the cache.
     my $obj = $pkg->cache_lookup($param);
@@ -275,7 +278,7 @@ sub lookup {
 
 =item (@media_objs || $media) = Bric::Biz::Asset::Business::Media->list($params)
 
-=item (@template_objs || $templates) = Bric::Biz::Asset::Business::Formatting->list($params)
+=item (@template_objs || $templates) = Bric::Biz::Asset::Business::Template->list($params)
 
 B<See Also:>
 
@@ -285,7 +288,7 @@ B<See Also:>
 
 =item Bric::Biz::Asset::Business::Media->list()
 
-=item Bric::Biz::Asset::Business::Formatting->list()
+=item Bric::Biz::Asset::Business::Template->list()
 
 =back
 
@@ -294,7 +297,7 @@ B<See Also:>
 sub list {
     my ($pkg, $param) = @_;
     $pkg = ref $pkg || $pkg;
-    throw_mni(error => 'Must call list on Story, Media, or Formatting')
+    throw_mni(error => 'Must call list on Story, Media, or Template')
       unless $pkg->CAN_DO_LIST;
     $param = clean_params($pkg, $param);
     my $tables = tables($pkg, $param);
@@ -314,7 +317,7 @@ sub list {
 
 =item (@ids||$ids) = Bric::Biz::Asset::Business::Media->list_ids($params)
 
-=item (@ids||$ids) = Bric::Biz::Asset::Business::Formatting->list_ids($params)
+=item (@ids||$ids) = Bric::Biz::Asset::Business::Template->list_ids($params)
 
 B<See Also:>
 
@@ -324,7 +327,7 @@ B<See Also:>
 
 =item Bric::Biz::Asset::Business::Media->list_ids()
 
-=item Bric::Biz::Asset::Business::Formatting->list_ids()
+=item Bric::Biz::Asset::Business::Template->list_ids()
 
 =back
 
@@ -333,7 +336,7 @@ B<See Also:>
 sub list_ids {
     my ($pkg, $param) = @_;
     $pkg = ref $pkg || $pkg;
-    throw_mni(error => 'Must call list on Story, Media, or Formatting')
+    throw_mni(error => 'Must call list on Story, Media, or Template')
       unless $pkg->CAN_DO_LIST_IDS;
     # clean the params
     $param = clean_params($pkg, $param);
@@ -550,14 +553,9 @@ B<Notes:> NONE.
 
 sub my_meths {
     my ($pkg, $ord, $ident) = @_;
-    return if $ident;
-
-    # Return 'em if we got em.
-    return !$ord ? $meths : wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}]
-      if $meths;
 
     # We don't got 'em. So get 'em!
-    $meths = {
+    $meths ||= {
               id         => {
                               name     => 'id',
                               get_meth => sub { shift->get_id(@_) },
@@ -566,6 +564,22 @@ sub my_meths {
                               len      => 10,
                               type     => 'short',
                              },
+              uuid         => {
+                              name     => 'uuid',
+                              get_meth => sub { shift->get_uuid },
+                              get_args => [],
+                              disp     => 'UUID',
+                              len      => 36,
+                              type     => 'short',
+                             },
+              version_id => {
+                              name     => 'version_id',
+                              get_meth => sub { shift->get_version_id(@_) },
+                              get_args => [],
+                              disp     => 'Version ID',
+                              len      => 10,
+                              type     => 'short',
+                             },
             needs_publish => {
                               name     => 'needs_publish',
                               get_meth => sub { shift->needs_publish(@_) },
@@ -650,27 +664,28 @@ sub my_meths {
                               len      => 10,
                               type     => 'short',
                              },
-              element_id => {
-                              name     => 'element_id',
-                              get_meth => sub { shift->get_element__id(@_) },
+              element_type_id => {
+                              name     => 'element_type_id',
+                              get_meth => sub { shift->get_element_type_id(@_) },
                               get_args => [],
-                              set_meth => sub { shift->set_element__id(@_) },
+                              set_meth => sub { shift->set_element_type_id(@_) },
                               set_args => [],
-                              disp     => 'Element ID',
+                              disp     => 'Element Type ID',
                               len      => 10,
                               req      => 0,
                               type     => 'short',
                              },
-              element  => {
-                              name     => 'element',
+              element_type  => {
+                              name     => 'element_type',
                               get_meth => sub {
-                                  my $a_id = shift->get_element__id(@_);
-                                  my $a = Bric::Biz::AssetType->lookup({ id => $a_id }) or return;
+                                  my $a_id = shift->get_element_type_id(@_);
+                                  my $a = Bric::Biz::ElementType->lookup({ id => $a_id }) or return;
                                   $a->get_name(); },
                               get_args => [],
-                              disp     => 'Element',
+                              disp     => 'Element Type',
                               len      => 256,
                               type     => 'short',
+                              props    => { type       => 'select' },
                              },
               publish_status => {
                              name     => 'publish_status',
@@ -726,11 +741,18 @@ sub my_meths {
                   name     => 'site',
                   disp     => 'Site',
                   type     => 'short',
-                  props    => {}
+                  props    => { type => 'text' }
               },
 
              };
-    return !$ord ? $meths : wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}];
+
+    if ($ord) {
+        return wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}];
+    } elsif ($ident) {
+        return wantarray ? $meths->{version_id} : [$meths->{version_id}];
+    } else {
+        return $meths;
+    }
 }
 
 #--------------------------------------#
@@ -816,9 +838,9 @@ NONE
 
 ################################################################################
 
-=item $site_id = $workflow->get_site_id
+=item $site_id = $asset->get_site_id
 
-Returns the ID of the site this Workflow is a part of
+Returns the ID of the site this asset is a part of.
 
 B<Throws:> NONE.
 
@@ -830,6 +852,32 @@ B<Notes:> NONE.
 
 ################################################################################
 
+=item $site = $asset->get_site
+
+Returns the the site this asset is a part of.
+
+B<Throws:> NONE.
+
+B<Side Effects:> NONE.
+
+B<Notes:> NONE.
+
+=cut
+
+sub get_site {
+    my $self = shift;
+    my $site;
+    unless ($site = $self->_get('_site')) {
+        $self->_set(
+            ['_site'],
+            [ $site = Bric::Biz::Site->lookup({ id => $self->get_site_id }) ]
+        );
+    }
+    return $site;
+}
+
+################################################################################
+
 =item $description = $self->get_description()
 
 This returns the description for the asset
@@ -992,7 +1040,7 @@ NONE
 
 =item $user__id = $asset->get_modifier()
 
-Returns the user id of the person who edited this version of the asset.   If 
+Returns the user id of the person who edited this version of the asset.   If
 the asset is checked out it will be the same as the user who checked it out.
 
 B<Throws:>
@@ -1165,11 +1213,11 @@ Unable to format date.
 
 =back
 
-B<Side Effects:> 
+B<Side Effects:>
 
 NONE
 
-B<Notes:> 
+B<Notes:>
 
 NONE
 
@@ -1179,40 +1227,6 @@ sub get_expire_date { local_date($_[0]->_get('expire_date'), $_[1]) }
 
 ################################################################################
 
-=item $list or @list = $self->get_desk_stamps();
-
-This returns a reference to a list of desk stamps in scalar context
-or an array in array context.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:>
-
-This method has been deprecated and will be removed in Bricolage 1.10.0.
-
-=cut
-
-sub get_desk_stamps {
-    my ($self) = @_;
-    require Carp; Carp::carp(__PACKAGE__ . "::get_desk_stamps is deprecated "
-                             . " and will be removed in Bricolage 1.10.0");
-    my $ds = $self->_get_attr_hash({ subsys => 'deskstamps' });
-
-    # This needs to be a numerical sort (perl defaults to a alphanumeric sort)
-    my @keys = sort {$a <=> $b} keys %$ds;
-
-    my (%dc, @desks);
-    foreach (@keys) {
-        push @desks, $dc{$ds->{$_}} ||=
-          Bric::Biz::Workflow::Parts::Desk->lookup({id => $ds->{$_}});
-    }
-    return wantarray ? @desks : \@desks;
-}
-
-################################################################################
-
 =item $self = $self->set_current_desk($desk_object);
 
 This method takes a desk stamp object and adds it to the asset object
@@ -1457,85 +1471,119 @@ NONE
 
 ################################################################################
 
-=item  $self->set_note ( $note );
+=item  $self->set_note($note);
 
-Adds a note to the Asset Takes a note object. Flags that a new note record
-should be created come data base time
+=item  $self->add_note($note);
 
-B<Throws:>
+Sets the note for this instance of the assset.
 
-NONE
+B<Throws:> NONE.
 
-B<Side Effects:>
+B<Side Effects:> NONE.
 
-NONE
-
-B<Notes:>
-
-NONE
+B<Notes:> C<add_note()> is deprecated.
 
 =cut
 
-sub add_note {
-        my $self = shift;
-        my ($note) = @_;
-
-
-        my $notes = $self->_get_attr_hash({ subsys => 'notes'});
-
-        my $note_index = $self->get_version();
-
-        $self->_set_attr({
-                        subsys => 'notes',
-                        name => $note_index,
-                        sql_type => 'short',
-                        value => $note
-                });
-
-        return $self;
-}
+sub add_note { shift->set_note(@_) }
 
 ################################################################################
 
-=item  $self->get_notes ( );
+=item my $note = $asset->get_note
 
-Returns a list of Notes from the Asset
+Returns the note for this instance of the asset.
 
-B<Throws:>
+B<Throws:> NONE.
 
-NONE 
+B<Side Effects:> NONE.
 
-B<Side Effects:>
+B<Notes:> NONE.
 
-NONE 
+=cut
 
-B<Notes:>
+################################################################################
 
-NONE
+=item my $notes_href = $asset->get_notes;
+
+Returns a hash reference of the notes for the asset. The hash keys are asset
+version numbers, and the values are the notes.
+
+B<Throws:> NONE.
+
+B<Side Effects:> NONE.
+
+B<Notes:> NONE.
 
 =cut
 
 sub get_notes {
-        my $self = shift;
+    my $self  = shift;
+    my $notes = $self->_get('_notes');
 
-        my $notes = $self->_get_attr_hash({ subsys => 'notes' });
+    unless ($notes) {
+        my $table = $self->VERSION_TABLE;
+        my $col   = $self->TABLE . '__id';
+        my $sel   = prepare_c("
+            SELECT version, note
+            FROM   $table
+            WHERE  $col = ?
+            ORDER BY id DESC"
+        );
+        execute($sel, $self->get_id);
+        bind_columns($sel, \my ($version, $note));
+        while (fetch($sel)) {
+            $notes->{$version} = $note;
+        }
 
-        return $notes;
+        $self->_set(['_notes'] => [$notes] );
+    }
+
+    if (defined( my $note = $self->get_note)) {
+        $notes->{$self->get_version} = $note;
+    }
+    return $notes;
 }
 
 ################################################################################
 
+=item my $bool = $asset->has_notes
+
+Returns true if the asset has notes in any of its versions, and false if it
+does not.
+
+=cut
+
+sub has_notes {
+    my $self  = shift;
+    if (first { $_ } $self->_get(qw(note _got_notes _notes))) {
+        return $self;
+    }
+
+    my $table = $self->VERSION_TABLE;
+    my $col   = $self->TABLE . '__id';
+    my ($got_notes) = row_array(prepare_c("
+        SELECT 1
+        FROM   $table
+        WHERE  $col = ?
+               AND note IS NOT NULL
+        LIMIT  1
+    "), $self->get_id);
+
+    $self->_set(['_got_notes'] => [ $got_notes ]);
+    return $got_notes ? $self : undef;
+}
+
 =item $asset = $asset->activate()
 
 This will activate a nonactive asset
 
 B<Throws:>
 
-NONE 
+NONE
 
 B<Side Effects:>
 
-NONE 
+NONE
 
 B<Notes:>
 
@@ -1555,15 +1603,15 @@ sub activate {
 
 =item $asset = $asset->deactivate()
 
-This will set the asset to a non active state 
+This will set the asset to a non active state
 
 B<Throws:>
 
-NONE 
+NONE
 
 B<Side Effects:>
 
-NONE 
+NONE
 
 B<Notes:>
 
@@ -1676,33 +1724,6 @@ sub checkin {
 
 ################################################################################
 
-=item $self = $self->save()
-
-Preforms save functions for the asset objects.   This will sync the attributes
-for the asset
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub save {
-    my $self = shift;
-    $self->_sync_attributes;
-    return $self->SUPER::save;
-}
-
-################################################################################
-
 =back
 
 =head1 PRIVATE
@@ -1714,206 +1735,8 @@ NONE
 
 =head2 Private Instance Methods
 
-=over 4
-
-=item attrs = $self->_get_attr_hash()
-
-Returns the attributes from the cache or the object
-
-B<Throws:>
-
 NONE
 
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub _get_attr_hash {
-    my ($self, $param) = @_;
-    my $attrs;
-    if ($self->_get('id')) {
-        my $attr_obj = $self->_get_attribute_object();
-        $attrs = $attr_obj->get_attr_hash( $param);
-    } else {
-        my $attr_cache = $self->_get('_attr_cache');
-        foreach (keys %{ $attr_cache->{$param->{'subsys'}} } ) {
-            $attrs->{$_} = $attr_cache->{$param->{'subsys'}}->{$_}->{'value'};
-        }
-    }
-    return $attrs;
-}
-
-################################################################################
-
-=item $self = $self->_set_attr()
-
-Sets the attributes to the object or to a cache
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub _set_attr {
-        my ($self, $param) = @_;
-
-        my $dirty = $self->_get__dirty();
-
-        # check to see if we have an id, get attr obj if we do
-        # otherwise put it into a cache
-        if ($self->_get('id') ) {
-                my $attr_obj = $self->_get_attribute_object();
-
-                # param should have been passed in an acceptable manner
-                # send it straight to the attr obj
-                $attr_obj->set_attr( $param );
-
-        } else {
-                # get the cache or create a new one if necessary
-                my $attr_cache = $self->_get('_attr_cache') || {};
-
-                # the value for this subsys/name combo
-                $attr_cache->{$param->{'subsys'}}->{$param->{'name'}}->{'value'} =
-                        $param->{'value'};
-
-                # the sql type 
-                $attr_cache->{$param->{'subsys'}}->{$param->{'name'}}->{'type'} =
-                        $param->{'sql_type'};
-
-                # store the cache so we can access it later
-                $self->_set( { '_attr_cache' => $attr_cache });
-        }
-
-        # set the flag to update the attrs
-        $self->_set( { '_update_attrs' => 1 });
-
-        $self->_set__dirty($dirty);
-
-        return $self;
-}
-
-################################################################################
-
-=item $attr = $self->_get_attr($param)
-
-Returns the attr from either the cache or the object
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub _get_attr {
-        my ($self, $param) = @_;
-
-        # check for an id to see if we need to access the cache or
-        # the attribute object
-        my $attr;
-        if ($self->_get('id') ) {
-                # we have an id so get the attribute object
-                my $attr_obj = $self->_get_attribute_object();
-
-                # param should have been passed in a valid format
-                # send directly to the attr object
-                $attr = $attr_obj->get_attr( $param );
-
-        } else {
-
-                # get the cache if it exists or create if it does not
-                my $attr_cache = $self->_get('_attr_cache') || {};
-
-                # get the data to return 
-                $attr =
-                        $attr_cache->{$param->{'subsys'}}->{$param->{'name'}}->{'value'};
-        }
-
-        return $attr;
-}
-
-################################################################################
-
-=item $self = $self->_sync_attributes()
-
-Syncs the attributes if anything is needed to be done
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub _sync_attributes {
-        my ($self) = @_;
-
-        return $self unless $self->_get('_update_attrs');
-
-        my $attr_obj = $self->_get_attribute_object();
-        $attr_obj->save();
-
-        # see if we have attr in the cache to be stored...
-        my $attr_cache = $self->_get('_attr_cache');
-        if ($attr_cache) {
-                # retrieve cache and store it on the attribute object
-                foreach my $subsys (keys %$attr_cache) {
-                        foreach my $name (keys %{ $attr_cache->{$subsys} }) {
-                                # set the attribute
-                                $attr_obj->set_attr( {
-                                                subsys => $subsys,
-                                                name => $name,
-                                                sql_type => $attr_cache->{$subsys}->{$name}->{'type'},
-                                                value => $attr_cache->{$subsys}->{$name}->{'value'}
-                                        });
-                        }
-                }
-
-                # clear the attribute cache
-                $self->_set( { '_attr_cache' => undef });
-        }
-        # clear the update flag
-        $self->_set( { '_update_attrs' => undef });
-
-        # call save on the attribute object
-        $attr_obj->save();
-
-        return $self;
-}
-
-################################################################################
-
-=back
-
 =head2 Private Functions
 
 NONE
@@ -1926,7 +1749,15 @@ __END__
 
 =head1 AUTHOR
 
-michael soderstrom ( miraso@pacbell.net )
+=over
+
+=item michael soderstrom <miraso@pacbell.net>
+
+=item Mark Jaroski <jaroskim@who.int>
+
+=item David Wheeler <david@kineticode.com>
+
+=back
 
 =head1 SEE ALSO
 
