@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-18 11:24:10 -0800 (Wed, 18 Jan 2006) $
+$LastChangedDate: 2006-06-15 12:46:46 -0700 (Thu, 15 Jun 2006) $
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,6 @@ use strict;
 # Programatic Dependencies
 use Bric::Biz::Workflow qw(MEDIA_WORKFLOW);
 use Bric::Util::DBI qw(:all);
-use Bric::Util::Attribute::Media;
 use Bric::Util::Trans::FS;
 use Bric::Util::Grp::Media;
 use Bric::Util::Time qw(:all);
@@ -85,7 +84,8 @@ use constant VERSION_TABLE => 'media_instance';
 
 use constant ID_COL => 'mt.id';
 
-use constant COLS           => qw( element__id
+use constant COLS           => qw( uuid
+                                   element_type__id
                                    priority
                                    source__id
                                    current_version
@@ -94,7 +94,6 @@ use constant COLS           => qw( element__id
                                    first_publish_date
                                    publish_date
                                    expire_date
-                                   cover_date
                                    workflow__id
                                    desk__id
                                    publish_status
@@ -114,9 +113,12 @@ use constant VERSION_COLS   => qw( name
                                    file_name
                                    location
                                    uri
+                                   cover_date
+                                   note
                                    checked_out);
 
-use constant FIELDS         => qw( element__id
+use constant FIELDS         => qw( uuid
+                                   element_type_id
                                    priority
                                    source__id
                                    current_version
@@ -125,7 +127,6 @@ use constant FIELDS         => qw( element__id
                                    first_publish_date
                                    publish_date
                                    expire_date
-                                   cover_date
                                    workflow_id
                                    desk_id
                                    publish_status
@@ -145,10 +146,12 @@ use constant VERSION_FIELDS => qw( name
                                    file_name
                                    location
                                    uri
+                                   cover_date
+                                   note
                                    checked_out);
 
 use constant RO_FIELDS      => qw( class_id );
-use constant RO_COLUMNS     => ', at.biz_class__id';
+use constant RO_COLUMNS     => ', e.biz_class__id';
 
 use constant GROUP_PACKAGE => 'Bric::Util::Grp::Media';
 use constant INSTANCE_GROUP_ID => 32;
@@ -167,10 +170,9 @@ use constant GROUP_COLS => ('id_list(DISTINCT m.grp__id) AS grp_id',
 use constant WHERE => 'mt.id = i.media__id '
   . 'AND mm.object_id = mt.id '
   . 'AND m.id = mm.member__id '
-  . 'AND m.active = 1 '
+  . "AND m.active = '1' "
   . 'AND c.id = i.category__id '
-  . 'AND e.id = mt.element__id '
-  . 'AND at.id = e.type__id '
+  . 'AND e.id = mt.element_type__id '
   . 'AND mt.workflow__id = w.id';
 
 use constant COLUMNS => join(', mt.', 'mt.id', COLS) . ', '
@@ -184,30 +186,40 @@ use constant FROM => VERSION_TABLE . ' i';
 use constant PARAM_FROM_MAP => {
      keyword              => 'media_keyword mk, keyword k',
      output_channel_id    => 'media__output_channel moc',
-     simple               => 'media_member mm, member m, at_type at, element e, '
+     simple               => 'media_member mm, member m, element_type e, '
                              . 'category c, workflow w,' . TABLE . ' mt ',
      grp_id               => 'member m2, media_member mm2',
-     data_text            => 'media_data_tile md',
-     subelement_key_name  => 'media_container_tile mct',
+     data_text            => 'media_field md',
+     subelement_key_name  => 'media_element mct, element_type subet',
+     subelement_id        => 'media_element sme',
+     related_story_id     => 'media_element mctrs',
+     related_media_id     => 'media_element mctrm',
      contrib_id           => 'media__contributor sic',
+     note                 => 'media_instance mmi2',
+     uri                  => 'media_uri uri',
+     site                 => 'site',
 };
 
 PARAM_FROM_MAP->{_not_simple} = PARAM_FROM_MAP->{simple};
 
 use constant PARAM_WHERE_MAP => {
       id                    => 'mt.id = ?',
+      uuid                  => 'mt.uuid = ?',
+      exclude_id            => 'mt.id <> ?',
       active                => 'mt.active = ?',
       inactive              => 'mt.active = ?',
       alias_id              => 'mt.alias_id = ?',
       site_id               => 'mt.site__id = ?',
       no_site_id            => 'mt.site__id <> ?',
+      site                  => 'mt.site__id = site.id AND LOWER(site.name) LIKE LOWER(?)',
       workflow__id          => 'mt.workflow__id = ?',
       workflow_id           => 'mt.workflow__id = ?',
       _null_workflow_id     => 'mt.workflow__id IS NULL',
-      element__id           => 'mt.element__id = ?',
-      element_id            => 'mt.element__id = ?',
+      element_type_id       => 'mt.element_type__id = ?',
+      element__id           => 'mt.element_type__id = ?',
+      element_id            => 'mt.element_type__id = ?',
       version_id            => 'i.id = ?',
-      element_key_name      => 'mt.element__id = e.id AND LOWER(e.key_name) LIKE LOWER(?)',
+      element_key_name      => 'mt.element_type__id = e.id AND LOWER(e.key_name) LIKE LOWER(?)',
       source__id            => 'mt.source__id = ?',
       source_id             => 'mt.source__id = ?',
       priority              => 'mt.priority = ?',
@@ -216,40 +228,45 @@ use constant PARAM_WHERE_MAP => {
       first_publish_date_end   => 'mt.publish_date <= ?',
       publish_date_start    => 'mt.publish_date >= ?',
       publish_date_end      => 'mt.publish_date <= ?',
-      cover_date_start      => 'mt.cover_date >= ?',
-      cover_date_end        => 'mt.cover_date <= ?',
+      cover_date_start      => 'i.cover_date >= ?',
+      cover_date_end        => 'i.cover_date <= ?',
       expire_date_start     => 'mt.expire_date >= ?',
       expire_date_end       => 'mt.expire_date <= ?',
       unexpired             => '(mt.expire_date IS NULL OR mt.expire_date > CURRENT_TIMESTAMP)',
       desk_id               => 'mt.desk__id = ?',
       name                  => 'LOWER(i.name) LIKE LOWER(?)',
-      subelement_key_name   => 'i.id = mct.object_instance_id AND LOWER(mct.key_name) LIKE LOWER(?)',
+      subelement_key_name   => 'i.id = mct.object_instance_id AND mct.element_type__id = subet.id AND LOWER(subet.key_name) LIKE LOWER(?)',
+      subelement_id         => 'i.id = sme.object_instance_id AND sme.element_type__id = ?',
+      related_story_id      => 'i.id = mctrs.object_instance_id AND mctrs.related_story__id = ?',
+      related_media_id      => 'i.id = mctrm.object_instance_id AND mctrm.related_media__id = ?',
       data_text             => 'LOWER(md.short_val) LIKE LOWER(?) AND md.object_instance_id = i.id',
       title                 => 'LOWER(i.name) LIKE LOWER(?)',
       description           => 'LOWER(i.description) LIKE LOWER(?)',
       version               => 'i.version = ?',
-      published_version     => 'mt.published_version = i.version AND i.checked_out = 0',
+      published_version     => "mt.published_version = i.version AND i.checked_out = '0'",
       user__id              => 'i.usr__id = ?',
-      user_id              => 'i.usr__id = ?',
-      uri                   => 'LOWER(i.uri) LIKE LOWER(?)',
+      user_id               => 'i.usr__id = ?',
+      uri                   => 'mt.id = uri.media__id AND LOWER(uri.uri) LIKE LOWER(?)',
       file_name             => 'LOWER(i.file_name) LIKE LOWER(?)',
       location              => 'LOWER(i.location) LIKE LOWER(?)',
       _checked_in_or_out    => 'i.checked_out = '
-                             . '( SELECT max(checked_out) '
+                             . '( SELECT checked_out '
                              . 'FROM media_instance '
                              . 'WHERE version = i.version '
-                             . 'AND media__id = i.media__id)',
+                             . 'AND media__id = i.media__id '
+                             . 'ORDER BY checked_out DESC LIMIT 1 )',
       checked_in            => 'i.checked_out = '
-                             . '( SELECT min(checked_out) '
+                             . '( SELECT checked_out '
                              . 'FROM media_instance '
                              . 'WHERE version = i.version '
-                             . 'AND media__id = i.media__id)',
+                             . 'AND media__id = i.media__id '
+                             . 'ORDER BY checked_out ASC LIMIT 1 )',
       _checked_out          => 'i.checked_out = ?',
       checked_out           => 'i.checked_out = ?',
-      _not_checked_out       => 'i.checked_out = 0 AND mt.id not in '
+      _not_checked_out       => "i.checked_out = '0' AND mt.id not in "
                               . '(SELECT media__id FROM media_instance '
                               . 'WHERE mt.id = media_instance.media__id '
-                              . 'AND media_instance.checked_out = 1)',
+                              . "AND media_instance.checked_out = '1')",
       primary_oc_id         => 'i.primary_oc__id = ?',
       output_channel_id     => '(i.id = moc.media_instance__id AND '
                              . 'moc.output_channel__id = ?)',
@@ -262,7 +279,7 @@ use constant PARAM_WHERE_MAP => {
                              . 'LOWER(k.name) LIKE LOWER(?)',
       _no_return_versions   => 'mt.current_version = i.version',
       grp_id                => 'm2.grp__id = ? AND '
-                             . 'm2.active = 1 AND '
+                             . "m2.active = '1' AND "
                              . 'mm2.member__id = m2.id AND '
                              . 'mt.id = mm2.object_id',
       simple                => 'mt.id IN ('
@@ -275,13 +292,20 @@ use constant PARAM_WHERE_MAP => {
                              . 'JOIN keyword kk ON (kk.id = keyword_id) '
                              . 'WHERE LOWER(kk.name) LIKE LOWER(?))',
       contrib_id            => 'i.id = sic.media_instance__id AND sic.member__id = ?',
+      note                  => 'mmi2.media__id = mt.id AND LOWER(mmi2.note) LIKE LOWER(?)',
 };
 
 use constant PARAM_ANYWHERE_MAP => {
-    element_key_name       => [ 'mt.element__id = e.id',
+    element_key_name       => [ 'mt.element_type__id = e.id',
                                 'LOWER(e.key_name) LIKE LOWER(?)' ],
-    subelement_key_name    => [ 'i.id = mct.object_instance_id',
-                                'LOWER(mct.key_name) LIKE LOWER(?)' ],
+    subelement_key_name    => [ 'i.id = mct.object_instance_id AND mct.element_type__id = subet.id',
+                                'LOWER(subet.key_name) LIKE LOWER(?)' ],
+    subelement_id          => [ 'i.id = sme.object_instance_id',
+                                'sme.element_type__id = ?' ],
+    related_story_id       => [ 'i.id = mctrs.object_instance_id',
+                                'mctrs.related_story__id = ?' ],
+    related_media_id       => [ 'i.id = mctrm.object_instance_id',
+                                'mctrm.related_media__id = ?' ],
     data_text              => [ 'md.object_instance_id = i.id',
                                 'LOWER(md.short_val) LIKE LOWER(?)' ],
     output_channel_id      => [ 'i.id = moc.media_instance__id',
@@ -290,13 +314,21 @@ use constant PARAM_ANYWHERE_MAP => {
                                 'LOWER(c.uri) LIKE LOWER(?)' ],
     keyword                => [ 'mk.media_id = mt.id AND k.id = mk.keyword_id',
                                 'LOWER(k.name) LIKE LOWER(?)' ],
-    grp_id                 => [ 'm2.active = 1 AND mm2.member__id = m2.id AND mt.id = mm2.object_id',
+    grp_id                 => [ "m2.active = '1' AND mm2.member__id = m2.id AND mt.id = mm2.object_id",
                                 'm2.grp__id = ?' ],
     contrib_id             => [ 'i.id = sic.media_instance__id',
                                 'sic.member__id = ?' ],
+    note                   => [ 'mmi2.media__id = mt.id',
+                                'LOWER(mmi2.note) LIKE LOWER(?)'],
+    uri                    => [ 'mt.id = uri.media__id',
+                                'LOWER(uri.uri) LIKE LOWER(?)'],
+    site                   => [ 'mt.site__id = site.id',
+                                'LOWER(site.name) LIKE LOWER(?)' ],
+
 };
 
 use constant PARAM_ORDER_MAP => {
+    uuid                => 'mt.uuid',
     active              => 'mt.active',
     inactive            => 'mt.active',
     alias_id            => 'mt.alias_id',
@@ -304,15 +336,16 @@ use constant PARAM_ORDER_MAP => {
     workflow__id        => 'mt.workflow__id',
     workflow_id         => 'mt.workflow__id',
     uri                 => 'LOWER(i.uri)',
-    element__id         => 'mt.element__id',
-    element_id          => 'mt.element__id',
+    element_type_id     => 'mt.element_type__id',
+    element__id         => 'mt.element_type__id',
+    element_id          => 'mt.element_type__id',
     source__id          => 'mt.source__id',
     source_id           => 'mt.source__id',
     priority            => 'mt.priority',
     publish_status      => 'mt.publish_status',
     first_publish_date  => 'mt.first_publish_date',
     publish_date        => 'mt.publish_date',
-    cover_date          => 'mt.cover_date',
+    cover_date          => 'i.cover_date',
     expire_date         => 'mt.expire_date',
     name                => 'LOWER(i.name)',
     title               => 'LOWER(i.name)',
@@ -438,11 +471,11 @@ workflow_id
 
 =item *
 
-element__id - Required unless asset type object passed
+element_type_id - Required unless asset type object passed
 
 =item *
 
-element - the object required unless id is passed
+element_type - the object required unless id is passed
 
 =item *
 
@@ -525,6 +558,15 @@ Media Document description. May use C<ANY> for a list of possible values.
 
 The media document ID. May use C<ANY> for a list of possible values.
 
+=item uuid
+
+The media document UUID. May use C<ANY> for a list of possible values.
+
+=item exclude_id
+
+A media document ID to exclude from the list. May use C<ANY> for a list of
+possible values.
+
 =item version
 
 The media document version number. May use C<ANY> for a list of possible values.
@@ -545,10 +587,8 @@ most recent version. May use C<ANY> for a list of possible values.
 
 =item checked_out
 
-Indicates whether to list media that are checked out or not. If "0", then
-only non-checked out media will be returned. If "1", then only checked-out
-media will be returned. If "all", then the checked_out attributed will be
-ignored (unless the C<user__id> parameter is passed).
+A boolean value indicating whether to return only checked out or not checked
+out media.
 
 =item checked_in
 
@@ -602,6 +642,11 @@ of possible values.
 Returns media associated with a given keyword string (not object). May use
 C<ANY> for a list of possible values.
 
+=item note
+
+Returns media with a note matching the value associated with any of their
+versions. May use C<ANY> for a list of possible values.
+
 =item workflow_id
 
 Return a list of media in the workflow represented by the workflow ID. May
@@ -622,10 +667,15 @@ possible values.
 Returns a list of media associated with a given site ID. May use C<ANY>
 for a list of possible values.
 
-=item element_id
+=item site
 
-Returns a list of media associated with a given element ID. May use C<ANY>
-for a list of possible values.
+Returns a list of media associated with a given site name. May use C<ANY> for
+a list of possible values.
+
+=item element_type_id
+
+Returns a list of media associated with a given element type ID. May use
+C<ANY> for a list of possible values.
 
 =item source_id
 
@@ -708,6 +758,21 @@ values.
 The key name for a container element that's a subelement of a media
 document. May use C<ANY> for a list of possible values.
 
+=item subelement_id
+
+The ID for a container element that's a subelement of a media document. May
+use C<ANY> for a list of possible values.
+
+=item related_story_id
+
+Returns a list of media that have this story ID as a related story. May use
+C<ANY> for a list of possible values.
+
+=item related_media_id
+
+Returns a list of media that have this media ID as a related media document.
+May use C<ANY> for a list of possible values.
+
 =item data_text
 
 Text stored in the fields of the media element or any of its subelements. Only
@@ -720,12 +785,15 @@ Triggers a single OR search that hits title, description, uri and keywords.
 
 =item Order
 
-A property name to order by.
+A property name or array reference of property names to order by.
 
 =item OrderDirection
 
 The direction in which to order the records, either "ASC" for ascending (the
-default) or "DESC" for descending.
+default) or "DESC" for descending. This value is applied to the property
+specified by the C<Order> parameter, and may also be an array reference. If no
+value is supplied for any C<Order> property name, it will default to
+ascending.
 
 =item Limit
 
@@ -1043,12 +1111,8 @@ B<Notes:> NONE.
 
 sub my_meths {
     my ($pkg, $ord, $ident) = @_;
-    return if $ident;
-
-    # Return 'em if we got em.
-    return !$ord ? $meths : wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}]
-      if $meths;
 
+    unless ($meths) {
     # We don't got 'em. So get 'em!
     foreach my $meth (__PACKAGE__->SUPER::my_meths(1)) {
         $meths->{$meth->{name}} = $meth;
@@ -1075,10 +1139,18 @@ sub my_meths {
     $meths->{title}{name} = 'title';
     $meths->{title}{disp} = 'Title';
 
-    # Rename element.
-    $meths->{element} = { %{ $meths->{element} } };
-    $meths->{element}{disp} = 'Media Type';
-    return !$ord ? $meths : wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}];
+    # Rename element type.
+    $meths->{element_type} = { %{ $meths->{element_type} } };
+    $meths->{element_type}{disp} = 'Media Type';
+    }
+
+    if ($ord) {
+        return wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}];
+    } elsif ($ident) {
+        return wantarray ? $meths->{version_id} : [$meths->{version_id}];
+    } else {
+        return $meths;
+    }
 }
 
 ################################################################################
@@ -1271,6 +1343,8 @@ sub set_cover_date {
 
 =item $category = $media->get_category()
 
+=item $category = $media->get_primary_category()
+
 Returns the object of the category that this is a member of
 
 B<Throws:> NONE.
@@ -1292,6 +1366,7 @@ sub get_category_object {
 
 { no warnings;
   *get_category = \&get_category_object;
+  *get_primary_category = \&get_category_object;
 }
 
 ##############################################################################
@@ -1436,7 +1511,7 @@ B<Notes:> NONE.
 sub upload_file {
     my $self = shift;
 
-    my ($id, $v) = $self->_get(qw(id version));
+    my ($id, $v, $old_fn) = $self->_get(qw(id version file_name));
 
     unless ($id) {
         # If there is no ID, we're not ready to create a file name, yet.
@@ -1448,14 +1523,43 @@ sub upload_file {
     my @id_dirs = $id =~ /(\d\d?)/g;
     my $dir = Bric::Util::Trans::FS->cat_dir(MEDIA_FILE_ROOT, @id_dirs, "v.$v");
     Bric::Util::Trans::FS->mk_path($dir);
+
+    if (MEDIA_UNIQUE_FILENAME) {
+        # split the uploaded filename into prefix and ext
+        (my ($prefix,$ext)) = ($name =~  m/^(.+)(\.[^\.]+)$/ );
+        # is this a new version of an existing ID ?
+        if ($old_fn) {
+            # set the prefix to the prefix of the old filename
+            ($prefix) = ($old_fn =~ m/^(.+)\.[^\.]+$/i );
+        } else {
+            # generate a new prefix and make sure it is unique
+            my $idexists = 1;
+            while ($idexists) {
+                # generate new random 8 character filename
+                $prefix = substr(Digest::MD5::md5_hex(
+                    Digest::MD5::md5_hex(time.{}.$id.rand)), 0, 8
+                );
+                # add any required filename prefix if we need to 
+                $prefix = MEDIA_FILENAME_PREFIX . $prefix if (MEDIA_FILENAME_PREFIX);
+                # does this filename exist in DB regardless of extension ?
+                ($idexists) = Bric::Biz::Asset::Business::Media->list_ids({
+                    file_name => "$prefix%",
+                });
+            }
+        }
+        # construct the new filename
+        $name = $prefix . $ext;
+    }
+
     my $path = Bric::Util::Trans::FS->cat_dir($dir, $name);
 
     local *FILE;
     open FILE, ">$path" or throw_gen "Unable to open '$path': $!";
     my $buffer;
-    while (read($fh, $buffer, 10240)) { print FILE $buffer }
+    while (read($fh, $buffer, 4096)) { print FILE $buffer }
     close $fh;
     close FILE;
+    $self->_set(['needs_preview'] => [1]) if AUTO_PREVIEW_MEDIA;
 
     # Set the media type and the file size.
     if ($type = defined $type
@@ -1475,7 +1579,7 @@ sub upload_file {
     $self->set_size(defined $size ? $size : -s $path);
 
     # Get the Output Channel object.
-    my $at_obj = $self->_get_element_object;
+    my $at_obj = $self->get_element_type;
     my $oc_obj = $self->get_primary_oc;
 
     my $new_loc = Bric::Util::Trans::FS->cat_dir('/', @id_dirs, "v.$v", $name);
@@ -1491,23 +1595,23 @@ sub upload_file {
     if (my $auto_fields = $self->_get_auto_fields) {
         # We need to autopopulate data field values. Get the top level element
         # construct a MediaFunc object.
-        my $tile = $self->get_tile;
+        my $element = $self->get_element;
         my $path = Bric::Util::Trans::FS->cat_dir(MEDIA_FILE_ROOT, $new_loc);
         my $media_func = Bric::App::MediaFunc->new({ file_path => $path });
 
         # Iterate through all the elements.
-        foreach my $dt ($tile->get_tiles) {
+        foreach my $dt ($element->get_elements) {
             # Skip container elements.
             next if $dt->is_container;
             # See if this is an auto populated field.
             my $name = $dt->get_name;
-            if ($auto_fields->{$name} ) {
-                # Check the tile to see if we can override it.
+            if ($auto_fields->{$name}) {
+                # Check the element to see if we can override it.
                 next if $dt->is_locked;
                 # Get and set the value
                 my $method = $auto_fields->{$name};
                 my $val = $media_func->$method();
-                $dt->set_data(defined $val ? $val : '');
+                $dt->set_value(defined $val ? $val : '');
                 $dt->save;
             }
         }
@@ -1515,6 +1619,13 @@ sub upload_file {
     return $self;
 }
 
+sub delete_file {
+    my $self = shift;
+    return $self->_set(
+        [qw(file_name location  uri _update_uri)]
+        => [   undef, undef, undef, 1]);
+}
+
 ################################################################################
 
 =item $file_name = $media->get_file_name()
@@ -1631,6 +1742,8 @@ sub revert {
     throw_gen(error => "May not revert a non checked out version")
       unless $self->_get('checked_out');
 
+    # Clear out the cache and look up the old version.
+    $self->uncache_me;
     my $revert_obj = __PACKAGE__->lookup({
         id          => $self->_get_id,
         version     => $version,
@@ -1656,14 +1769,14 @@ sub revert {
     $self->_set([@attrs, qw(_contributors _update_contributors _queried_contrib)],
                 [$revert_obj->_get(@attrs), $contrib, 1, 1]);
 
-    # clone the tiles
-    # get rid of current tiles
-    my $tile = $self->get_tile;
-    $tile->do_delete;
-    my $new_tile = $revert_obj->get_tile;
-    $new_tile->prepare_clone;
-    $self->_set({ _delete_tile => $tile,
-                  _tile        => $new_tile});
+    # clone the elements
+    # get rid of current elements
+    my $element = $self->get_element;
+    $element->do_delete;
+    my $new_element = $revert_obj->get_element;
+    $new_element->prepare_clone;
+    $self->_set({ _delete_element => $element,
+                  _element        => $new_element});
 
     # Make sure the current version is cached.
     return $self->cache_me;
@@ -1685,8 +1798,8 @@ B<Notes:> NONE.
 
 sub clone {
     my $self = shift;
-    my $tile = $self->get_tile();
-    $tile->prepare_clone();
+    my $element = $self->get_element();
+    $element->prepare_clone();
 
     my $contribs = $self->_get_contributors();
     # clone contributors
@@ -1723,7 +1836,8 @@ B<Notes:> NONE.
 sub save {
     my $self = shift;
 
-    my ($id, $active, $update_uris) = $self->_get(qw(id _active _update_uri));
+    my ($id, $vid, $version, $active, $update_uris, $preview, $cancel) =
+      $self->_get(qw(id version_id version _active _update_uri needs_preview _cancel));
 
     # Start a transaction.
     begin();
@@ -1732,23 +1846,30 @@ sub save {
             # we have the main id make sure there's a instance id
             $self->_update_media();
 
-            if ($self->_get('version_id')) {
-                if ($self->_get('_cancel')) {
-                    $self->_delete_instance();
-                    if ($self->_get('version') == 0) {
-                        $self->_delete_media();
-                    }
-                    $self->_set( {'_cancel' => undef });
+            if ($vid) {
+                if ($cancel) {
+                    $self->_delete_instance;
+                    $self->_delete_media if $version == 0;
+                    $self->_delete_file;
+                    $self->_set(['_cancel'] => []);
+                    commit();
                     return $self;
                 } else {
                     $self->_update_instance();
                 }
             } else {
-                $self->_insert_instance();
+                if ($cancel) {
+                    $self->_delete_file;
+                    commit();
+                    return $self;
+                } else {
+                    $self->_insert_instance();
+                }
             }
         } else {
             # insert both
             if ($self->_get('_cancel')) {
+                commit();
                 return $self;
             } else {
                 $self->_insert_media();
@@ -1786,6 +1907,9 @@ sub save {
         rollback();
         rethrow_exception($err);
     }
+    if (AUTO_PREVIEW_MEDIA && $preview && !$cancel) {
+        $self->_preview;
+    }
 
     return $self;
 }
@@ -1952,31 +2076,6 @@ sub _get_auto_fields {
 
 ################################################################################
 
-=item $attribute_object = $self->_get_attribute_object()
-
-Returns the attribute object from a cache or creates a new record
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
-sub _get_attribute_object {
-    my $self = shift;
-    my ($attr_obj, $id) = $self->_get('_attribute_object', 'id');
-    return $attr_obj if $attr_obj;
-
-    # Let's Create a new one if one does not exist
-    $attr_obj = Bric::Util::Attribute::Media->new({ id => $id });
-    $self->_set( {'_attribute_object' => $attr_obj} );
-    return $attr_obj;
-}
-
-################################################################################
-
 =item $self = $self->_insert_media()
 
 Inserts a media record into the database
@@ -2124,17 +2223,49 @@ B<Notes:> NONE.
 
 sub _delete_instance {
     my $self = shift;
-
-    my $sql = 'DELETE FROM ' . VERSION_TABLE .
-      ' WHERE id=? ';
-
-    my $sth = prepare_c($sql, undef);
+    # Delete the database record.
+    my $sth = prepare_c('DELETE FROM ' . VERSION_TABLE . ' WHERE id=? ');
     execute($sth, $self->_get('version_id'));
     return $self;
 }
 
 ################################################################################
 
+=item $self = $self->_delete_file()
+
+Deletes the version directory for the current version if it exists.
+
+B<Throws:> NONE.
+
+B<Side Effects:> If the C<AUTO_PREVIEW_MEDIA> F<bricolage.conf> directive is
+enabled, the previous version of the media document will be looked up and its
+media file previewed, so as to replace the deleted media preview.
+
+B<Notes:> NONE.
+
+=cut
+
+sub _delete_file {
+    my $self = shift;
+
+    # Figure out where any new files would have been created.
+    my ($id, $v) = $self->_get(qw(id version file_name));
+    my @id_dirs = $id =~ /(\d\d?)/g;
+    my $dir = Bric::Util::Trans::FS->cat_dir(MEDIA_FILE_ROOT, @id_dirs, "v.$v");
+    return $self unless -d $dir;
+
+    Bric::Util::Trans::FS->del($dir);
+
+    if (AUTO_PREVIEW_MEDIA && $v) {
+        $self->uncache_me;
+        my $prev = ref($self)->lookup({ id => $id });
+        $prev->_preview;
+    }
+    return $self;
+}
+
+################################################################################
+
 =item $self = $self->_select_media($where, @bind);
 
 Populates the object from a database row
@@ -2188,8 +2319,8 @@ sub _do_update {
     my $self = shift;
 
     my $sql = 'UPDATE ' . TABLE . ' '.
-      'SET ' . join(', ', map { "$_=?" } COLS) .
-                                ' WHERE id=? ';
+        'SET ' . join(', ', map { "$_ = ?" } COLS) .
+        ' WHERE id=? ';
 
     my $update = prepare_c($sql, undef);
     execute($update, $self->_get( FIELDS ), $self->_get('id') );
@@ -2198,9 +2329,9 @@ sub _do_update {
 
 ################################################################################
 
-=item $attr_object = $self->_get_attr_obj()
+=item $self = $self->_preview()
 
-returns the attribute object for this media
+Previews the media document.
 
 B<Throws:> NONE.
 
@@ -2210,15 +2341,16 @@ B<Notes:> NONE.
 
 =cut
 
-sub _get_attr_obj {
+sub _preview {
     my $self = shift;
-    my $attr_obj = $self->_get('_attr_obj');
-    return $attr_obj if ($attr_obj);
+    my $burner = Bric::Util::Burner->new({
+        out_dir              => PREVIEW_ROOT,
+        _output_preview_msgs => 0,
+    });
 
-    $attr_obj = Bric::Util::Attribute::Media->new(
-      { object_id => $self->_get('id')});
-    $self->_set( { '_attr_obj' => $attr_obj });
-    return $attr_obj;
+    $burner->preview($self, 'media', get_user_id, $_->get_id)
+        for $self->get_output_channels;
+    $self->_set(['needs_preview'] => [0]);
 }
 
 1;
