@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-08-13 18:56:36 -0700 (Fri, 13 Aug 2004) $
+$LastChangedDate: 2006-06-20 09:51:13 -0700 (Tue, 20 Jun 2006) $
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,9 @@ $LastChangedDate: 2004-08-13 18:56:36 -0700 (Fri, 13 Aug 2004) $
 
 Allows assets to be grouped into categories. In addition to assets a category
 can contain other categories, allowing a hierarchical layout of categories and
-assets.
+assets. New categories will inherit group memberships and asset group
+permissions from their parents, but those relationships will thereafter be
+independent of the parent's.
 
 =cut
 
@@ -88,7 +90,7 @@ use Bric::Util::Grp::CategorySet;
 use Bric::Util::Attribute::Category;
 use Bric::Util::Trans::FS;
 use Bric::Util::Fault qw(throw_gen throw_dp);
-use Bric::Util::DBI qw(:standard col_aref);
+use Bric::Util::DBI qw(:standard :junction col_aref);
 use Bric::Util::Grp::Asset;
 use Bric::Util::Coll::Keyword;
 
@@ -127,7 +129,9 @@ my $table = 'category';
 my $mem_table = 'member';
 my $map_table = $table . "_$mem_table";
 my $sel_cols = 'a.id, a.site__id, a.directory, a.asset_grp_id, a.active, '.
-               'a.uri, a.parent_id, a.name, a.description, m.grp__id';
+               'a.uri, a.parent_id, a.name, a.description, id_list(DISTINCT m.grp__id)';
+my $grp_cols = 'a.id, a.site__id, a.directory, a.asset_grp_id, a.active, '.
+               'a.uri, a.parent_id, a.name, a.description';
 my @sel_props = qw(id site_id directory asset_grp_id _active uri parent_id name
                    description grp_ids);
 my @cols = qw(site__id directory asset_grp_id active uri parent_id
@@ -176,7 +180,10 @@ BEGIN {
 
 =item $obj = new Bric::Biz::Category($init);
 
-Create a new object of type Bric::Biz::Category
+Create a new object of type Bric::Biz::Category. Once C<save()>d, the new
+category will have the same group memberships as the parent, and have the same
+permissions granted to its asset group as are granted to the parent's asset
+group.
 
 Keys for $init are:
 
@@ -280,22 +287,43 @@ Criteria keys:
 
 =over 4
 
+=item id
+
+Category ID. May use C<ANY> for a list of possible values.
+
 =item name
 
+The name of the category. May use C<ANY> for a list of possible values.
+
 =item directory
 
+The category directory name. May use C<ANY> for a list of possible values.
+
 =item uri
 
+The category URI. May use C<ANY> for a list of possible values.
+
 =item active
 
 =item description
 
+The category description. May use C<ANY> for a list of possible values.
+
 =item parent_id
 
+The ID category of a parent category. May use C<ANY> for a list of possible
+values.
+
 =item grp_id
 
+The ID of a Bric::Util::Grp object to which the category belongs. May use
+C<ANY> for a list of possible values.
+
 =item site_id
 
+The ID of a Bric::Biz::Site object with which the category is associated. May
+use C<ANY> for a list of possible values.
+
 =back
 
 B<Throws:>
@@ -739,10 +767,8 @@ NONE
 
 sub ancestry {
     my $self = shift;
-    my @objs;
     my $cur = $self;
-
-    unshift @objs, $cur;
+    my @objs = ($cur);
 
     while ($cur = $cur->get_parent) {
         unshift @objs, $cur;
@@ -818,7 +844,7 @@ sub ancestry_dir {
 }
 
 
-=item C<my $dir = $cat->set_directory($dir);>
+=item my $dir = $cat->set_directory($dir);
 
 Sets this category's directory.
 
@@ -846,7 +872,7 @@ sub set_directory {
 }
 
 
-=item C<my $dir = $cat->set_parent_id($parent_id);>
+=item my $dir = $cat->set_parent_id($parent_id);
 
 Sets this category's parent ID, making it a child of that category.
 
@@ -1203,7 +1229,7 @@ sub keywords {
 
 #------------------------------------------------------------------------------#
 
-=item C<my @cats = $cat->get_children;>
+=item @cats = $cat->get_children;
 
 Returns the children of this category.
 
@@ -1232,7 +1258,7 @@ sub get_children {
 
 #------------------------------------------------------------------------------#
 
-=item C<my $parent = $cat->get_parent;>
+=item my $parent = $cat->get_parent;
 
 Returns the parent of this category or undef if it is a top level category.
 
@@ -1466,17 +1492,13 @@ sub deactivate {
 
 Save this category
 
-B<Throws:>
+B<Throws:> NONE.
 
-NONE
+B<Side Effects:> A new category will automatically be added to the same category
+groups as its parent, and permissions will be granted to its asset group
+exactly as they are granted to the parent.
 
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
+B<Notes:> NONE.
 
 =cut
 
@@ -1541,7 +1563,7 @@ Several that need documenting!
 sub _do_list {
     my ($pkg, $params, $ids) = @_;
     my $tables = "$table a, $mem_table m, $map_table c";
-    my $wheres = 'a.id = c.object_id AND c.member__id = m.id AND m.active = 1 '.
+    my $wheres = "a.id = c.object_id AND c.member__id = m.id AND m.active = '1' ".
                  'AND a.id <> 0';
     my @params;
 
@@ -1560,40 +1582,42 @@ sub _do_list {
 
     # Set up the other query properties.
     while (my ($k, $v) = each %$params) {
-	if ($k eq 'id' or $k eq 'parent_id') {
+        if ($k eq 'id' or $k eq 'parent_id') {
             # It's a simple numeric comparison.
-            $wheres .= " AND a.$k = ?";
-	    push @params, $v;
+            $wheres .= ' AND ' . any_where($v, "a.$k = ?", \@params);
             # Keep us from returning the super root category
-            if ($k eq 'parent_id' and $v == 0) {
+            if ($k eq 'parent_id'
+                and ((ref $v && grep { $_ == 0 } @$v) || $v == 0))
+            {
                 $wheres .= " AND a.id <> ?";
                 push @params, 0;
             }
         } elsif ($k eq 'site_id') {
-            $wheres .= " AND a.site__id = ?";
-            push @params, $v;
+            $wheres .= ' AND ' . any_where($v, "a.site__id = ?", \@params);
         } elsif ($k eq 'grp_id') {
             # Fancy-schmancy second join.
             $tables .= ", $mem_table m2, $map_table c2";
-            $wheres .= " AND a.id = c2.object_id AND c2.member__id = m2.id " .
-              " AND m2.active = 1 AND m2.grp__id = ?";
-            push @params, $v;
-	} else {
+            $wheres .= " AND a.id = c2.object_id AND c2.member__id = m2.id "
+              . " AND m2.active = '1' AND "
+              . any_where($v, "m2.grp__id = ?", \@params);
+        } else {
             # It's a simpler string comparison.
-	    $wheres .= " AND LOWER(a.$k) LIKE ?";
-	    push @params, lc $v;
-	}
+            $wheres .= ' AND '
+              . any_where($v, "LOWER(a.$k) LIKE LOWER(?)", \@params);
+        }
     }
 
     # Create the where clause and the select and order by clauses.
-    my ($qry_cols, $order) = $ids ? (\'DISTINCT a.id', '') :
-      (\$sel_cols, 'ORDER BY a.uri');
+    my ($qry_cols, $order, $group_by) = $ids
+        ? (\'DISTINCT a.id', '', '')
+        : (\$sel_cols, 'ORDER BY a.uri', "GROUP BY $grp_cols");
 
     # Prepare the statement.
     my $sel = prepare_c(qq{
         SELECT $$qry_cols
         FROM   $tables
         WHERE  $wheres
+        $group_by
         $order
     }, undef);
 
@@ -1602,32 +1626,18 @@ sub _do_list {
       if $ids;
 
     execute($sel, @params);
-    my (@d, @cats, $grp_ids);
+    my (@d, @cats);
     bind_columns($sel, \@d[0..$#sel_props]);
     $pkg = ref $pkg || $pkg;
-    my $last = -1;
     while (fetch($sel)) {
-        if ($d[0] != $last) {
-            $last = $d[0];
-            # Create a new Category object.
-            my $self = bless {}, $pkg;
-            $self->SUPER::new;
-            $grp_ids = $d[$#d] = [$d[$#d]];
-            $self->_set(\@sel_props, \@d);
-            # Add the attribute object.
-            # HACK: Get rid of this object!
-            $self->_set( ['_attr_obj'],
-                         [ Bric::Util::Attribute::Category->new
-                           ({ object_id => $d[0],
-                              subsys => $d[0] })
-                         ]
-                       );
-            $self->_set__dirty; # Disable the dirty flag.
-            push @cats, $self->cache_me;
-        } else {
-            # Append the ID.
-            push @$grp_ids, $d[$#d];
-        }
+        # Create a new Category object.
+        my $self = bless {}, $pkg;
+        $self->SUPER::new;
+        # Parse the group IDs.
+        $d[-1] = [ map { split } $d[-1] ];
+        $self->_set(\@sel_props, \@d);
+        $self->_set__dirty; # Disable the dirty flag.
+        push @cats, $self->cache_me;
     }
     return wantarray ? @cats : \@cats;
 }
@@ -1716,10 +1726,10 @@ sub _update_category {
 
     if ($self->_get('_update_uri') and not $self->is_root_category) {
         $self->_set(['_update_uri'], [0]);
-        $new_uri = Bric::Util::Trans::FS->cat_uri
-          ( $self->get_parent->get_uri,
-            $self->_get('directory')
-          );
+        $new_uri = Bric::Util::Trans::FS->cat_uri(
+            $self->get_parent->get_uri,
+            $self->_get('directory'),
+        ) . '/';
         $self->_set(['uri'], [$new_uri]);
     }
 
@@ -1772,8 +1782,10 @@ sub _insert_category {
     # created sites.  These root categories will set their own uri.
     unless ($self->is_root_category) {
         # Set the URI
-        my $uri = Bric::Util::Trans::FS->cat_uri($self->get_parent->get_uri,
-                                                 $self->_get('directory'));
+        my $uri = Bric::Util::Trans::FS->cat_uri(
+            $self->get_parent->get_uri,
+            $self->_get('directory')
+        ) . '/';
         $self->_set(['uri'], [$uri]);
     }
 
@@ -1781,7 +1793,7 @@ sub _insert_category {
     # to have a way to get a group ID from a category to track assets and
     # permissions. The assets will pretend they're in the group, even though
     # they're really not. See Bric::Biz::Asset->get_grp_ids to see it at work.
-    # XXX Yes, it's ugly that we're abusing name this way, but it does the
+    # XXX Yes, it's ugly that we're abusing the name this way, but it does the
     # trick.
     my $ag_obj = Bric::Util::Grp::Asset->new({
         name        => "Site $site_id Category Assets",
@@ -1789,16 +1801,40 @@ sub _insert_category {
     });
 
     $ag_obj->save;
-    $self->_set(['asset_grp_id'], [$ag_obj->get_id]);
+    my $ag_id = $ag_obj->get_id;
+    $self->_set(['asset_grp_id'], [$ag_id]);
 
     # Insert the new category.
     execute($sth, $self->_get(@props));
 
     # Set the ID of this object.
-    $self->_set(['id'],[last_key($table)]);
+    $self->_set(['id'] => [last_key($table)]);
 
-    # Add the category to the 'All Categories' group and return.
+    # Add the category to the 'All Categories' group.
     $self->register_instance(INSTANCE_GROUP_ID, GROUP_PACKAGE);
+
+    # Add it to all of the same groups as the parent category.
+    my $parent = $self->get_parent or return $self;
+    if (my @gids = grep { $_ != INSTANCE_GROUP_ID } $parent->get_grp_ids) {
+        for my $grp (Bric::Util::Grp->list({ id => ANY(@gids) })) {
+            $grp->add_member({ obj => $self, no_check => 1 });
+            $grp->save;
+        }
+    }
+
+    # Give its asset group the same permission associations as the parent.
+    for my $perm (Bric::Util::Priv->list({
+        obj_grp_id => $parent->get_asset_grp_id
+    })) {
+        # Create a matching permission for the new category.
+        $perm = Bric::Util::Priv->new({
+            obj_grp => $ag_id,
+            usr_grp => $perm->get_usr_grp_id,
+            value   => $perm->get_value,
+        });
+        $perm->save;
+    }
+
     return $self;
 }
 
@@ -1885,7 +1921,7 @@ Garth Webb <garth@perijove.com>
 
 Jeff "japhy" Pinyan <japhy@pobox.com>
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
