@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-08-12 17:13:34 -0700 (Thu, 12 Aug 2004) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -259,17 +259,30 @@ parameters passed via an anonymous hash. The supported lookup keys are:
 
 =over 4
 
-=item *
+=item id
 
-type
+Contact ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item type
 
-value
+Contact type. May use C<ANY> for a list of possible values.
 
-=item *
+=item description
 
-description
+Contact description. May use C<ANY> for a list of possible values.
+
+=item value
+
+Contact value. May use C<ANY> for a list of possible values.
+
+=item person_id
+
+ID of person object associated with contacts. May use C<ANY> for a list of
+possible values.
+
+=item alertable
+
+Boolean indicating whether or not alerts can be sent to contacts of this type.
 
 =back
 
@@ -1373,24 +1386,24 @@ B<Notes:> NONE.
 $get_em = sub {
     my ($pkg, $params, $ids, $href) = @_;
     my (@wheres, @params);
+    my $tables = "contact c, contact_value v";
     while (my ($k, $v) = each %$params) {
         if ($k eq 'id') {
-            push @wheres, "v.$k = ?";
-            push @params, $v;
+            push @wheres, any_where($v, 'v.id = ?', \@params);
         } elsif ($k eq 'value') {
-            push @wheres, "LOWER(v.$k) LIKE ?";
-            push @params, lc $v;
+            push @wheres, any_where($v, "LOWER(v.$k) LIKE LOWER(?)", \@params);
         } elsif ($k eq 'person_id') {
-            push @wheres, "v.id in (SELECT contact_value__id from "
-              . "person__contact_value where person__id = ?)";
-            push @params, $v;
+            $tables .= ', person__contact_value pcv';
+            push @wheres, 'v.id = pcv.contact_value__id',
+              any_where($v, 'pcv.person__id = ?', \@params);
+        } elsif ($k eq 'alertable') {
+            push @wheres, any_where($v ? 1 : 0, "c.$k = ?", \@params);
         } else {
-            push @wheres, "LOWER(c.$k) LIKE ?";
-            push @params, lc $v;
+            push @wheres, any_where($v,"LOWER(c.$k) LIKE LOWER(?)", \@params);
         }
     }
 
-    my $where = defined $params->{id} ? '' : ' AND v.active = 1';
+    my $where = defined $params->{id} ? '' : " AND v.active = '1'";
     local $" = ' AND ';
     $where .= " AND @wheres" if @wheres;
 
@@ -1398,7 +1411,7 @@ $get_em = sub {
     my @qry_cols = $ids ? ('v.id') : @cols;
     my $sel = prepare_ca(qq{
         SELECT @qry_cols
-        FROM   contact c, contact_value v
+        FROM   $tables
         WHERE  c.id = v.contact__id
                $where
         ORDER BY c.id
@@ -1499,13 +1512,13 @@ B<Notes:> NONE.
 $get_types = sub {
     my ($href, $alert, $ids) = @_;
     my @qry_cols = $href ? ('c.id', @type_cols) : ('c.type');
-    my $where = $alert ? 'AND alertable = 1' : '';
+    my $where = $alert ? "AND alertable = '1'" : '';
 
     local $" = ', ';
     my $sel = prepare_ca(qq{
         SELECT @qry_cols
         FROM   contact c
-        WHERE  active = 1 $where
+        WHERE  active = '1' $where
         ORDER BY c.id
     }, undef);
 
@@ -1535,7 +1548,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
