@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-09-06 10:19:12 -0700 (Mon, 06 Sep 2004) $
+$LastChangedDate: 2006-05-12 07:54:43 -0700 (Fri, 12 May 2006) $
 
 =head1 SYNOPSIS
 
@@ -56,7 +56,7 @@ $LastChangedDate: 2004-09-06 10:19:12 -0700 (Mon, 06 Sep 2004) $
   $oc->use_slug_off;
 
   # Output Channel Includes instance methods.
-  my @ocs = $oc->get_includes(@ocs);
+  my @ocs = $oc->get_includes;
   $oc->set_includes(@ocs);
   $oc->add_includes(@ocs);
   $oc->del_includes(@ocs);
@@ -91,18 +91,24 @@ use Bric::Util::DBI qw(:all);
 use Bric::Util::Grp::OutputChannel;
 use Bric::Util::Coll::OCInclude;
 use Bric::Util::Fault qw(throw_gen throw_dp);
+use List::Util 'first';
 
 #==============================================================================
 ## Inheritance                         #
 #======================================#
 use base qw(Bric Exporter);
-our @EXPORT_OK = qw(MIXEDCASE LOWERCASE UPPERCASE);
-our %EXPORT_TAGS = (case_constants => \@EXPORT_OK);
+our %EXPORT_TAGS = (
+    case_constants => [qw(MIXEDCASE LOWERCASE UPPERCASE)],
+    burners        => [qw(BURNER_MASON BURNER_TEMPLATE BURNER_TT BURNER_PHP)],
+);
+our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
+$EXPORT_TAGS{all} = \@EXPORT_OK;
 
 #=============================================================================
 ## Function Prototypes                 #
 #======================================#
 my ($get_inc, $parse_uri_format);
+my $tmpl_archs = [];
 
 #==============================================================================
 ## Constants                           #
@@ -119,10 +125,16 @@ use constant LOWERCASE => 2;
 use constant UPPERCASE => 3;
 
 # URI Defaults.
-use constant DEFAULT_URI_FORMAT => '/categories/year/month/day/slug/';
-use constant DEFAULT_FIXED_URI_FORMAT => '/categories/';
-use constant DEFAULT_URI_CASE => MIXEDCASE;
-use constant DEFAULT_USE_SLUG => 0;
+use constant DEFAULT_URI_FORMAT       => '/%{categories}/%Y/%m/%d/%{slug}/';
+use constant DEFAULT_FIXED_URI_FORMAT => '/%{categories}/';
+use constant DEFAULT_URI_CASE         => MIXEDCASE;
+use constant DEFAULT_USE_SLUG         => 0;
+
+# Possible values for burner.
+use constant BURNER_MASON    => 1;
+use constant BURNER_TEMPLATE => 2;
+use constant BURNER_TT       => 3;
+use constant BURNER_PHP      => 4;
 
 #==============================================================================
 ## Fields                              #
@@ -139,35 +151,32 @@ my $METHS;
 my $TABLE = 'output_channel';
 my $SEL_TABLES = "$TABLE oc, member m, output_channel_member sm";
 my $SEL_WHERES = 'oc.id = sm.object_id AND sm.member__id = m.id ' .
-  'AND m.active = 1';
+  "AND m.active = '1'";
 my $SEL_ORDER = 'oc.name, oc.id';
 
-my @COLS = qw(name description protocol site__id pre_path post_path primary_ce
-              filename file_ext uri_format fixed_uri_format uri_case use_slug
-              active);
+my @COLS = qw(name description protocol site__id primary_ce filename file_ext
+              uri_format fixed_uri_format uri_case use_slug burner active);
 
-my @PROPS = qw(name description protocol site_id pre_path post_path primary
-               filename file_ext uri_format fixed_uri_format uri_case _use_slug
-               _active);
+my @PROPS = qw(name description protocol site_id primary filename file_ext
+               uri_format fixed_uri_format uri_case _use_slug burner _active);
 
 my $SEL_COLS = 'oc.id, oc.name, oc.description, oc.protocol, oc.site__id, '.
-               'oc.pre_path, oc.post_path, oc.primary_ce, oc.filename, '.
-               'oc.file_ext, oc.uri_format, oc.fixed_uri_format, oc.uri_case, '.
-               'oc.use_slug, oc.active, m.grp__id';
+               'oc.primary_ce, oc.filename, oc.file_ext, oc.uri_format, ' .
+               'oc.fixed_uri_format, oc.uri_case, oc.use_slug, oc.burner, ' .
+               'oc.active, m.grp__id';
 my @SEL_PROPS = ('id', @PROPS, 'grp_ids');
 
-my @ORD = qw(name description site_id protocol pre_path post_path filename
-             file_ext  uri_format
-             fixed_uri_format uri_case use_slug active);
+my @ORD = qw(name description site_id protocol filename file_ext uri_format
+             fixed_uri_format uri_case use_slug burner active);
 my $GRP_ID_IDX = $#SEL_PROPS;
 
 # These are provided for the OutputChannel::Element subclass to take
 # advantage of.
-sub SEL_PROPS { @SEL_PROPS }
-sub SEL_COLS { $SEL_COLS }
+sub SEL_PROPS  { @SEL_PROPS }
+sub SEL_COLS   { $SEL_COLS }
 sub SEL_TABLES { $SEL_TABLES }
 sub SEL_WHERES { $SEL_WHERES }
-sub SEL_ORDER { $SEL_ORDER }
+sub SEL_ORDER  { $SEL_ORDER }
 sub GRP_ID_IDX { $GRP_ID_IDX }
 
 #--------------------------------------#
@@ -189,10 +198,10 @@ BEGIN {
        # What protocol to use for URLs (ie, http://, https://, ftp://)
        'protocol'              => Bric::FIELD_RDWR,
 
-       # Path to insert at the beginning of URIs.
+       # Path to insert at the beginning of URIs. Deprecated.
        'pre_path'              => Bric::FIELD_RDWR,
 
-       # Path to insert at the end of URIs.
+       # Path to insert at the end of URIs. Deprecated.
        'post_path'             => Bric::FIELD_RDWR,
 
        # These will be used to construct file names
@@ -204,6 +213,10 @@ BEGIN {
        uri_format              => Bric::FIELD_RDWR,
        fixed_uri_format        => Bric::FIELD_RDWR,
        uri_case                => Bric::FIELD_RDWR,
+
+       # What burner to use.
+       burner                  => Bric::FIELD_RDWR,
+
        _use_slug               => Bric::FIELD_NONE,
 
        # the flag as to wheather this is a primary
@@ -257,10 +270,6 @@ description
 
 =item *
 
-primary
-
-=item *
-
 active (default is active, pass undef to make a new inactive Output Channel)
 
 =back
@@ -297,6 +306,9 @@ sub new {
     $init->{uri_case} ||= DEFAULT_URI_CASE;
     $init->{_use_slug} = exists $init->{use_slug} && $init->{use_slug} ? 1 : 0;
 
+    # Set default burner.
+    $init->{burner} ||= BURNER_MASON;
+
     # Construct this puppy!
     push @{$init->{grp_ids}}, INSTANCE_GROUP_ID;
     return $class->SUPER::new($init);
@@ -376,57 +388,76 @@ are:
 
 =over 4
 
-=item *
+=item id
 
-name
+Output channel ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item name
 
-description
+The name of the output channel. May use C<ANY> for a list of possible values.
 
-=item *
+=item description
 
-site_id
+Description of the output channel. May use C<ANY> for a list of possible
+values.
 
-=item *
+=item site_id
 
-protocol
+The ID of the Bric::Biz::Site object with which the output channel is
+associated. May use C<ANY> for a list of possible values.
 
-=item *
+=item protocol
 
-primary
+The protocol or scheme for files published to an output channel, such as
+"http://". May use C<ANY> for a list of possible values.
 
-=item *
+=item server_type_id
 
-server_type_id
+The ID of a Bric::Dest::ServerType (destination) with which output channels
+may be associated. May use C<ANY> for a list of possible values.
 
-=item *
+=item include_parent_id
 
-include_parent_id
+The ID of an output channel that includes other output channels, to get a
+list of those includes. May use C<ANY> for a list of possible values.
 
-=item *
+=item story_instance_id
 
-story_instance_id
+The ID of a story with which output channels may be associated. May use C<ANY>
+for a list of possible values.
 
-=item *
+=item media_instance_id
 
-media_instance_id
+The ID of a media document with which output channels may be associated. May
+use C<ANY> for a list of possible values.
 
-=item *
+=item uri_format
 
-uri_format
+The URI format of an output channel. May use C<ANY> for a list of possible
+values.
 
-=item *
+=item fixed_uri_format
 
-uri_case
+The fixed URI format of an output channel. May use C<ANY> for a list of
+possible values.
 
-=item *
+=item uri_case
 
-use_slug
+The URI case of an output channel. May use C<ANY> for a list of possible values.
 
-=item *
+=item use_slug
 
-active
+A boolean indicating whether story slugs should be used for file names in an
+output channel.
+
+=item burner
+
+A burner constant as exported by this class. May use C<ANY> for a list of
+possible values.
+
+=item active
+
+A boolean indicating whether or not an output channel is active.
 
 =back
 
@@ -733,6 +764,16 @@ B<Notes:> NONE.
 sub my_meths {
     my ($pkg, $ord, $ident) = @_;
 
+    unless (@$tmpl_archs) {
+        push @$tmpl_archs, [BURNER_MASON, 'Mason'];
+        push @$tmpl_archs, [BURNER_TEMPLATE, 'HTML::Template']
+            if $Bric::Util::Burner::Template::VERSION;
+        push @$tmpl_archs, [BURNER_TT,'Template::Toolkit']
+            if $Bric::Util::Burner::TemplateToolkit::VERSION;
+        push @$tmpl_archs, [BURNER_PHP,'PHP']
+            if $Bric::Util::Burner::PHP::VERSION;
+    }
+
     # Create 'em if we haven't got 'em.
     $METHS ||= {
               name        => {
@@ -808,36 +849,6 @@ sub my_meths {
                                            maxlength => 16}
                              },
 
-              pre_path      => {
-                             name     => 'pre_path',
-                             get_meth => sub { shift->get_pre_path(@_) },
-                             get_args => [],
-                             set_meth => sub { shift->set_pre_path(@_) },
-                             set_args => [],
-                             disp     => 'URI Prefix',
-                             len      => 64,
-                             req      => 0,
-                             type     => 'short',
-                             props    => {   type       => 'text',
-                                             length     => 32,
-                                             maxlength => 64
-                                         }
-                            },
-              post_path      => {
-                             name     => 'post_path',
-                             get_meth => sub { shift->get_post_path(@_) },
-                             get_args => [],
-                             set_meth => sub { shift->set_post_path(@_) },
-                             set_args => [],
-                             disp     => 'URI Suffix',
-                             len      => 64,
-                             req      => 0,
-                             type     => 'short',
-                             props    => {   type       => 'text',
-                                             length     => 32,
-                                             maxlength => 64
-                                         }
-                            },
               filename      => {
                              name     => 'filename',
                              get_meth => sub { shift->get_filename(@_) },
@@ -928,6 +939,34 @@ sub my_meths {
                              type     => 'short',
                              props    => { type => 'checkbox' }
                             },
+              burner => {
+                             get_meth => sub { shift->get_burner(@_) },
+                             get_args => [],
+                             set_meth => sub { shift->set_burner(@_) },
+                             set_args => [],
+                             name     => 'burner',
+                             disp     => 'Burner',
+                             len      => 80,
+                             req      => 1,
+                             type     => 'short',
+                             props    => {
+                                 type => 'select',
+                                 vals => $tmpl_archs,
+                             }
+                         },
+
+              burner_name => {
+                             get_meth => sub {
+                                 my $burner = shift->get_burner;
+                                 my $map = first { $_->[0] == $burner } @$tmpl_archs;
+                                 return $map->[1];
+                             },
+                             get_args => [],
+                             name     => 'burner_name',
+                             disp     => 'Burner',
+                             props    => { type      => 'text' },
+                         },
+
               active     => {
                              name     => 'active',
                              get_meth => sub { shift->is_active(@_) ? 1 : 0 },
@@ -1050,50 +1089,6 @@ B<Side Effects:> NONE.
 
 B<Notes:> NONE.
 
-=item $oc = $oc->set_pre_path($pre_path)
-
-Sets the string that will be used at the beginning of the URIs for assets in
-this Output Channel.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=item $pre_path = $oc->get_pre_path
-
-Gets the string that will be used at the beginning of the URIs for assets in
-this Output Channel.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=item $oc = $oc->set_post_path($post_path)
-
-Sets the string that will be used at the end of the URIs for assets in this
-Output Channel.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=item $post_path = $oc->get_post_path
-
-Gets the string that will be used at the end of the URIs for assets in
-this Output Channel.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
 =item $oc = $oc->set_filename($filename)
 
 Sets the filename that will be used in the names of files burned into this
@@ -1196,7 +1191,54 @@ B<Notes:> Only one Output channel can be the primary output channel.
 
 =item $oc = $oc->set_uri_format($uri_format)
 
-Sets the URI format for documents output in this Output Channel.
+Sets the URI format for documents output in this Output Channel. URI formats
+are made up of a number of possible parts, that can be arranged in any
+combination and order of any of the following parts:
+
+=over
+
+=item %{categories}
+
+The category URI. This is the only part that is required in all formats.
+
+=item %{slug}
+
+The story slug. Not used for media URIs.
+
+=item %{uuid}
+
+The document UUID.
+
+=item %{base64_uuid}
+
+The base64-encoded document UUID.
+
+=item %{hex_uuid}
+
+The hex representation of the  document UUID.
+
+=item *
+
+Arbitrary strings. You can even ignore the C<uri_prefix> and C<uri_suffix>
+attributes, if you like.
+
+=item %Y
+
+The four-digit cover date year.
+
+=item %m
+
+The two-digit cover date month.
+
+=item %d
+
+The two-digit cover date month.
+
+=item etc.
+
+Any other L<DateTime|DateTime>-supproted C<strftime> format.
+
+=back
 
 B<Throws:>
 
@@ -1224,6 +1266,8 @@ sub set_uri_format {
                                      $_[1])])
 }
 
+##############################################################################
+
 =item my $format = $oc->get_uri_format
 
 Returns the URI format for documents output in this Output Channel.
@@ -1259,11 +1303,14 @@ B<Notes:> NONE.
 =cut
 
 sub set_fixed_uri_format {
-    $_[0]->_set(['fixed_uri_format'],
-                [$parse_uri_format->($_[0]->my_meths->{fixed_uri_format}{disp},
-                                     $_[1])])
+    $_[0]->_set(
+        ['fixed_uri_format'],
+        [$parse_uri_format->($_[0]->my_meths->{fixed_uri_format}{disp}, $_[1])]
+    )
 }
 
+##############################################################################
+
 =item (undef || 1 ) = $oc->can_use_slug
 
 Returns true if this is Output Channel can use the C<slug> property of a story
@@ -1311,6 +1358,34 @@ B<Notes:> NONE.
 
 sub use_slug_off { $_[0]->_set(['_use_slug'], [0]) }
 
+=item $burner = $oc->get_burner
+
+Returns the burner with which the output channel is associated.
+
+B<Throws:> NONE.
+
+B<Side Effects:> NONE.
+
+B<Notes:> NONE.
+
+=item $oc = $oc->set_burner($burner)
+
+Sets the value corresponding to the burner with which this output channel is
+associated. The value must correspond to one of the burner constants
+exportable by this class:
+
+=over
+
+=item BURNER_MASON
+
+=item BURNER_TEMPLATE
+
+=item BURNER_TT
+
+=item BURNER_PHP
+
+=back
+
 ##############################################################################
 
 =item my @inc = $oc->get_includes
@@ -1614,7 +1689,12 @@ sub save {
     my ($self) = @_;
     return $self unless $self->_get__dirty;
     my ($id, $inc) = $self->_get('id', '_includes');
-    defined $id ? $self->_do_update($id) : $self->_do_insert;
+    if ($id) {
+        $self->_do_update($id);
+    } else {
+        $self->_do_insert;
+        $id = $self->_get('id');
+    }
     $inc->save($id) if $inc;
     $self->SUPER::save();
 }
@@ -1677,12 +1757,11 @@ sub _do_list {
     while (my ($k, $v) = each %$params) {
         if ($k eq 'id' or $k eq 'uri_case') {
             # Simple numeric comparison.
-            $wheres .= " AND oc.$k = ?";
-            push @params, $v;
+            $wheres .= ' AND ' . any_where $v, "oc.$k = ?", \@params;
         } elsif ($k eq 'primary') {
-            # Simple numeric comparison.
+            # Simple boolean comparison.
             $wheres .= " AND oc.primary_ce = ?";
-            push @params, $v;
+            push @params, $v ? 1 : 0;
         } elsif ($k eq 'active' or $k eq 'use_slug') {
             # Simple boolean comparison.
             $wheres .= " AND oc.$k = ?";
@@ -1690,45 +1769,42 @@ sub _do_list {
         } elsif ($k eq 'grp_id') {
             # Add in the group tables a second time and join to them.
             $tables .= ", member m2, output_channel_member c2";
-            $wheres .= " AND oc.id = c2.object_id AND c2.member__id = m2.id" .
-              " AND m2.active = 1 AND m2.grp__id = ?";
-            push @params, $v;
+            $wheres .= " AND oc.id = c2.object_id AND c2.member__id = m2.id"
+              . " AND m2.active = '1' AND "
+              . any_where $v, 'm2.grp__id = ?', \@params;
         } elsif ($k eq 'include_parent_id') {
             # Include the parent ID.
             $tables .= ', output_channel_include inc';
-            $wheres .= ' AND oc.id = inc.include_oc_id ' .
-              'AND inc.output_channel__id = ?';
-            push @params, $v;
+            $wheres .= ' AND oc.id = inc.include_oc_id AND '
+              . any_where $v, 'inc.output_channel__id = ?', \@params;
         } elsif ($k eq 'server_type_id') {
             # Join in the server_type__output_channel table.
             $tables .= ', server_type__output_channel stoc';
-            $wheres .= ' AND oc.id = stoc.output_channel__id ' .
-              'AND stoc.server_type__id = ?';
-            push @params, $v;
+            $wheres .= ' AND oc.id = stoc.output_channel__id AND '
+              . any_where $v, 'stoc.server_type__id = ?', \@params;
         } elsif ($k eq 'story_instance_id') {
             # Join in the story__output_channel table.
             $tables .= ', story__output_channel soc';
-            $wheres .= ' AND oc.id = soc.output_channel__id ' .
-              'AND soc.story_instance__id = ?';
-            push @params, $v;
+            $wheres .= ' AND oc.id = soc.output_channel__id AND '
+              . any_where $v, 'soc.story_instance__id = ?', \@params;
         } elsif ($k eq 'media_instance_id') {
             # Join in the media__output_channel table.
             $tables .= ', media__output_channel moc';
-            $wheres .= ' AND oc.id = moc.output_channel__id ' .
-              'AND moc.media_instance__id = ?';
-            push @params, $v;
+            $wheres .= ' AND oc.id = moc.output_channel__id AND '
+              . any_where $v, 'moc.media_instance__id = ?', \@params;
         } elsif ($k eq 'site_id') {
-            $wheres .= ' AND oc.site__id = ?';
-            push @params, $v;
+            $wheres .= ' AND ' . any_where $v, 'oc.site__id = ?', \@params;
+        } elsif ($k eq 'burner') {
+            $wheres .= ' AND ' . any_where $v, 'oc.burner = ?', \@params;
         } else {
             # Simple string comparison!
-            $wheres .= " AND LOWER(oc.$k) LIKE ?";
-            push @params, lc $v;
+            $wheres .= ' AND '
+                    . any_where $v, "LOWER(oc.$k) LIKE LOWER(?)", \@params;
         }
     }
 
     my @sel_props = $pkg->SEL_PROPS;
-    my $sel_cols = $pkg->SEL_COLS;
+    my $sel_cols  = $pkg->SEL_COLS;
     my $sel_order = $pkg->SEL_ORDER;
     my ($order, $props, $qry_cols) = ($sel_order, \@sel_props, \$sel_cols);
     if ($ids) {
@@ -2009,33 +2085,22 @@ B<Notes:> NONE.
 
 $parse_uri_format = sub {
     my ($name, $format) = @_;
-    my %toks = map { $_ => 1 } qw(categories day month year slug);
 
     # Throw an exception for an empty or bogus format.
     throw_dp(error => "No $name value specified")
       if not $format or $format =~ /^\s*$/;
 
-    # Parse the format for invalid tokens.
-    $format =~ s#/?(.+)/?#$1#;
-    my (@tokens, @bad);
-    foreach my $token (split /\//, $format) {
-        $toks{$token} ?
-          push @tokens, $token :
-          push @bad, $token;
+    # Make sure that the URI format has %{categories} unless set otherwise
+    unless (ALLOW_URIS_WITHOUT_CATEGORIES) {
+        throw_dp "Missing the %{categories} token from $name"
+          unless $format =~ /%{categories}/;
     }
 
-    # Throw an exception for a format with invalid tokens.
-    if (my $c = @bad) {
-        my $pl = $c > 1 ? 's' : '';
-        my $bad = join ', ', @bad;
-        throw_dp(error => "Invalid $name token$pl: $bad");
-    }
-
-    # Return the format.
-    return '/' . join('/', @tokens) . '/';
+    # Make sure there's a closing slash.
+    $format .= '/' unless $format =~ m|/$|;
+    return $format;
 };
 
-
 1;
 __END__
 
@@ -2049,11 +2114,11 @@ NONE.
 
 Michael Soderstrom <miraso@pacbell.net>
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@kineticode.com>
 
 =head1 SEE ALSO
 
-L<perl>, L<Bric>, L<Bric::Biz::Asset::Business>, L<Bric::Biz::AssetType>,
-L<Bric::Biz::Asset::Formatting>.
+L<perl>, L<Bric>, L<Bric::Biz::Asset::Business>, L<Bric::Biz::ElementType>,
+L<Bric::Biz::Asset::Template>.
 
 =cut
