@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-08-12 17:13:34 -0700 (Thu, 12 Aug 2004) $
+$LastChangedDate: 2006-05-25 11:23:06 -0700 (Thu, 25 May 2006) $
 
 =head1 SYNOPSIS
 
@@ -296,29 +296,34 @@ parameters passed via an anonymous hash. The supported lookup keys are:
 
 =over 4
 
-=item *
+=item id
 
-prefix
+Person ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item prefix
 
-lname
+A name prefix, such as "Mr."  May use C<ANY> for a list of possible values.
 
-=item *
+=item lname
 
-fname
+Last name or surname. May use C<ANY> for a list of possible values.
 
-=item *
+=item fname
 
-mname
+First name or given name. May use C<ANY> for a list of possible values.
 
-=item *
+=item mname
 
-suffix
+Middle name or second name. May use C<ANY> for a list of possible values.
 
-=item *
+=item suffix
 
-grp_id
+Name suffix, such as "Jr." May use C<ANY> for a list of possible values.
+
+=item grp_id
+
+The ID of a Bric::Util::Grp object of which person objects may be a member.
+May use C<ANY> for a list of possible values.
 
 =back
 
@@ -1482,7 +1487,7 @@ sub del_contacts {
 
 =item my (@gids || $gids_aref) = $p->get_grp_ids
 
-Returns a list or anonymous array of Bric::Biz::Group::Person object ids
+Returns a list or anonymous array of Bric::Util::Grp::Person object ids
 representing the groups of which this Bric::Biz::Person object is a member.
 
 B<Throws:> See Bric::Util::Grp::Person::list().
@@ -1495,12 +1500,12 @@ B<Notes:> NONE.
 
 =item my (@groups || $groups_aref) = $p->get_grps
 
-Returns a list or anonymous array of Bric::Biz::Group::Person objects representing
+Returns a list or anonymous array of Bric::Biz::Grp::Person objects representing
 the groups of which this Bric::Biz::Person object is a member.
 
-Use the Bric::Biz::Group::Person instance method calls add_members() and
+Use the Bric::Biz::Grp::Person instance method calls add_members() and
 delete_members() to associate and dissociate Bric::Biz::Person objects with any
-given Bric::Biz::Group::Person object.
+given Bric::Biz::Grp::Person object.
 
 B<Throws:> See Bric::Util::Grp::Person::list().
 
@@ -1799,21 +1804,18 @@ $get_em = sub {
     my $extra_wheres = '';
     while (my ($k, $v) = each %$params) {
         if ($k eq 'id') {
-            push @wheres, "p.$k = ?";
-            push @params, $v;
+            push @wheres, any_where $v, "p.$k = ?", \@params;
         } elsif ($k eq 'grp_id') {
             $extra_tables = ", $mem_table m2, $map_table c2";
             $extra_wheres = "AND p.id = c2.object_id AND " .
-              "m2.active = 1 AND c2.member__id = m2.id";
-            push @wheres, "m2.grp__id = ?";
-            push @params, $v;
+              "m2.active = '1' AND c2.member__id = m2.id";
+            push @wheres, any_where $v, "m2.grp__id = ?", \@params;
         } else {
-            push @wheres, "LOWER(p.$k) LIKE ?";
-            push @params, lc $v;
+            push @wheres, any_where $v, "LOWER(p.$k) LIKE LOWER(?)", \@params;
         }
     }
 
-    my $where = defined $params->{id} ? '' : 'p.active = 1';
+    my $where = defined $params->{id} ? '' : "p.active = '1'";
     $where .= ($where ? ' AND ' : '') . join(' AND ', @wheres) if @wheres;
 
     local $" = ', ';
@@ -1822,7 +1824,7 @@ $get_em = sub {
     my $sel = prepare_c(qq{
         SELECT @$qry_cols
         FROM   $table p, $mem_table m, $map_table c $extra_tables
-        WHERE  p.id = c.object_id AND c.member__id = m.id and m.active = 1
+        WHERE  p.id = c.object_id AND c.member__id = m.id and m.active = '1'
                $extra_wheres AND $where
         ORDER BY $order
     }, undef);
@@ -1929,7 +1931,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
