@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use Bric::Biz::Asset::Business::Media;
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 use Bric::Biz::Category;
 use Bric::Biz::Site;
 use Bric::Util::Grp::Parts::Member::Contrib;
@@ -52,7 +52,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-03 15:10:57 -0800 (Thu, 03 Nov 2005) $
+$LastChangedDate: 2006-01-17 16:09:49 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -268,15 +268,18 @@ sub list_ids {
       category_path_to_id(__PACKAGE__, delete $args->{category}, $args)
       if exists $args->{category};
 
-    # handle element => element__id conversion
-    if (exists $args->{element}) {
-        my ($element_id) = Bric::Biz::AssetType->list_ids(
-                              { key_name => $args->{element}, media => 1 });
+    # handle element => element_id conversion
+    $args->{element_type} = $args->{element} if exists $args->{element};
+    if (exists $args->{element_type}) {
+        my ($element_id) = Bric::Biz::ElementType->list_ids({
+            key_name => $args->{element_type},
+            media => 1,
+        });
         throw_ap(error => __PACKAGE__ . "::list_ids : no element found matching "
-                   . "(element => \"$args->{element}\")")
+                   . "(element => \"$args->{element_type}\")")
           unless defined $element_id;
-        $args->{element__id} = $element_id;
-        delete $args->{element};
+        $args->{element_type_id} = $element_id;
+        delete $args->{element_type};
     }
 
     # translate dates into proper format
@@ -656,24 +659,26 @@ sub load_asset {
         $mdata->{site} = 'Default Site' unless exists $mdata->{site};
         $init{site_id} = site_to_id(__PACKAGE__, $mdata->{site});
 
-        if (exists $mdata->{element} and not $aliased) {
-            unless ($melems{$mdata->{element}}) {
-                my $e = (Bric::Biz::AssetType->list({
-                    key_name => $mdata->{element},
-                    media    => 1
+        $mdata->{element_type} = delete $mdata->{element}
+            if exists $mdata->{element};
+        if (exists $mdata->{element_type} and not $aliased) {
+            unless ($melems{$mdata->{element_type}}) {
+                my $e = (Bric::Biz::ElementType->list({
+                    key_name => $mdata->{element_type},
+                    media    => 1,
                 }))[0] or throw_ap(
                     error => __PACKAGE__ .
                       "::create : no media element found " .
-                      "matching (element => \"$mdata->{element}\")"
+                      "matching (element_type => \"$mdata->{element_type}\")"
                 );
-                $melems{$mdata->{element}} = [
+                $melems{$mdata->{element_type}} = [
                     $e->get_id,
                     { map { $_->get_name => $_ } $e->get_output_channels }
                 ];
             }
 
             # get element object for asset type
-            $init{element__id} = $melems{$mdata->{element}}->[0];
+            $init{element_type_id} = $melems{$mdata->{element_type}}->[0];
 
         } elsif ($aliased) {
             # It's an alias.
@@ -729,6 +734,7 @@ sub load_asset {
         my $media;
         unless ($update) {
             # create empty media
+            # XXX Put in supplied UUID?
             $media = Bric::Biz::Asset::Business::Media->new(\%init);
             throw_ap(error => __PACKAGE__ . "::create : failed to create empty media object.")
               unless $media;
@@ -781,8 +787,14 @@ sub load_asset {
                 log_event('media_checkout', $media);
             }
 
+            # Make sure that the UUID hasn't changed.
+            if (exists $mdata->{uuid}) {
+                throw_ap __PACKAGE__ . "::update: media \"$id\" has a different UUID"
+                  if $media->get_uuid ne $mdata->{uuid};
+            }
+
             # update %init fields
-            delete @init{qw(element__id alias_id)};
+            delete @init{qw(element_id alias_id)};
             $media->_set([keys(%init)],[values(%init)]);
         }
 
@@ -868,7 +880,7 @@ sub load_asset {
 
         # Manage the output channels if any are included in the XML file.
         load_ocs($media, $mdata->{output_channels}{output_channel},
-                 $melems{$mdata->{element}}->[1], 'media', $update)
+                 $melems{$mdata->{element_type}}->[1], 'media', $update)
           if $mdata->{output_channels}{output_channel};
 
         # sanity checks
@@ -986,9 +998,10 @@ sub serialize_asset {
     # open a media element
     my $alias_id = $media->get_alias_id;
     $writer->startTag("media",
-                      id => $media_id,
+                      id   => $media_id,
+                      uuid => $media->get_uuid,
                       ( $alias_id ? (alias_id => $alias_id) :
-                        (element => $media->get_element_key_name)));
+                        (element_type => $media->get_element_key_name)));
 
     # Write out the name of the site.
     my $site = Bric::Biz::Site->lookup({ id => $media->get_site_id });
