@@ -53,7 +53,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-14 18:23:31 -0700 (Thu, 14 Jul 2005) $
+$LastChangedDate: 2005-09-21 18:22:17 -0700 (Wed, 21 Sep 2005) $
 
 =head1 SYNOPSIS
 
@@ -189,8 +189,8 @@ sub xs_date_to_db_date {
     my $xs = shift;
 
     # extract time-zone if present from end of ISO 8601 date
-    my ($tz) = $xs =~ /([A-Za-z]+)$/;
-    $tz = 'UTC' unless defined $tz and $tz ne 'Z';
+    $xs =~ s/(\D+)$//;
+    my $tz = $1 && $1 ne 'Z' ? $1 : 'UTC';
 
     my $db = db_date($xs, undef, $tz);
     print STDERR "xs_date_to_db_date:\n  $xs\n  $db\n\n" if DEBUG;
@@ -247,8 +247,8 @@ sub parse_asset_document {
                  keyattr       => [],
                  suppressempty => '',
                  forcearray    => [qw( contributor category output_channel
-                                       keyword element container
-                                       data story media template ),
+                                       keyword element_type element container
+                                       data field story media template ),
                                    @extra_force_array
                                   ]
                 );
@@ -270,7 +270,7 @@ sub serialize_elements {
     my @related;
 
     # output element data
-    my $element = $object->get_tile;
+    my $element = $object->get_element;
     my %attr;
     if (my $related_story = $element->get_related_story) {
         $attr{related_story_id} = $related_story->get_id;
@@ -296,21 +296,23 @@ sub serialize_elements {
         # first serialize all data elements
         foreach my $e (@$elems) {
             next if $e->is_container;
-            push(@related, _serialize_tile(writer  => $writer,
-                                           element => $e,
-                                           args    => $options{args},
-                                           diff    => $diff,
-                                          ));
+            push(@related, _serialize_element(
+                writer       => $writer,
+                element_type => $e,
+                args         => $options{args},
+                diff         => $diff,
+            ));
         }
 
         # then all containers
         foreach my $e (@$elems) {
             next unless $e->is_container;
-            push(@related, _serialize_tile(writer  => $writer,
-                                           element => $e,
-                                           args    => $options{args},
-                                           diff    => $diff,
-                                          ));
+            push(@related, _serialize_element(
+                writer       => $writer,
+                element_type => $e,
+                args         => $options{args},
+                diff         => $diff,
+            ));
         }
     }
 
@@ -337,10 +339,10 @@ The business asset with which to associate the output channels.
 The array reference of output channels from the SOAP data, e.g.,
 C<$data->{stories}{story}[0]{output_channels}{output_channel}.
 
-=item C<$elem_ocs>
+=item C<$elem_type_ocs>
 
-A hash reference of the output channels in the element that defines the asset
-(i.e., the story type element or the media type element). The hash keys are
+A hash reference of the output channels in the element type that define the asset
+(i.e., the story element type or the media element type). The hash keys are
 the output channel names, and the values are the corresponding output channel
 objects.
 
@@ -376,7 +378,7 @@ sub load_ocs {
         my $oc = delete $ocs{$ocname};
         unless ($oc) {
             # We have to add the new output channel to the document. Grab the
-            # OC object from the element.
+            # OC object from the element type.
             $oc = $elem_ocs->{$ocname} or
               throw_ap(error => __PACKAGE__ . "::create : output channel matching " .
                          "(name => \"$ocname\") not allowed or cannot be found");
@@ -401,8 +403,8 @@ sub load_ocs {
 =item @relations = deseralize_elements(object => $story, data => $data,
                                        type   => 'story')
 
-Loads an asset object with element data from the data hash.  Calls
-_deserialize_tile recursively down through containers.
+Loads an asset object with element type data from the data hash.  Calls
+_deserialize_element recursively down through containers.
 
 Throws: NONE
 
@@ -414,10 +416,10 @@ Notes:
 
 sub deserialize_elements {
     my %options = @_;
-    $options{element} = $options{object}->get_tile;
+    $options{element} = $options{object}->get_element;
     $options{site_id} = $options{object}->get_site_id;
     return _load_relateds(@options{qw(element data site_id)}),
-      _deserialize_tile(%options);
+      _deserialize_element(%options);
 }
 
 =back
@@ -426,9 +428,9 @@ sub deserialize_elements {
 
 =over 4
 
-=item @related = _deserialize_tile(element => $element, data => $data)
+=item @related = _deserialize_element(element => $element, data => $data)
 
-Deserializes a single tile from <elements> data into $element.  Calls
+Deserializes a single element from <elements> data into $element.  Calls
 recursively down through containers building up fixup data from
 related objects in @related.
 
@@ -442,7 +444,7 @@ contain the kung-fu necessary for this task.
 
 =cut
 
-sub _deserialize_tile {
+sub _deserialize_element {
     my %options   = @_;
     my $element   = $options{element};
     my $data      = $options{data};
@@ -454,37 +456,43 @@ sub _deserialize_tile {
     # make sure we have an empty element - Story->new() helpfully (?)
     # creates empty data elements for required elements.
     if (my @e = $element->get_elements) {
-        $element->delete_tiles(\@e);
+        $element->delete_elements(\@e);
         $element->save; # required for delete to "take"
     }
 
     # get lists of possible data types and possible containers that
     # can be added to this element.  Hash on names for quick lookups.
-    my %valid_data      = map { ($_->get_key_name, $_) }
-        $element->get_possible_data();
-    my %valid_container = map { ($_->get_key_name, $_) }
+    my %valid_data      = map { $_->get_key_name => $_ }
+        $element->get_possible_field_types();
+    my %valid_container = map { $_->get_key_name, $_  }
         $element->get_possible_containers();
 
     # load data elements
-    if ($data->{data}) {
-        foreach my $d (@{$data->{data}}) {
-            my $at = $valid_data{$d->{element}};
+    $data->{field} ||= $data->{data};
+    if ($data->{field}) {
+        foreach my $d (@{$data->{field}}) {
+            my $key_name = $d->{type} || $d->{element};
+            my $at = $valid_data{$key_name};
             throw_ap(error => "Error loading data element for " .
                        $element->get_key_name .
-                       " cannot add data element $d->{element} here.")
+                       " cannot add field $key_name here.")
               unless $at;
 
             if ($at->get_sql_type eq 'date') {
                 # add date data to container
-                $element->add_data($at,
-                                   exists $d->{content} ?
-                                   xs_date_to_db_date($d->{content}) : '',
-                                   $d->{order});
+                $element->add_field(
+                    $at,
+                    exists $d->{content} ?
+                        xs_date_to_db_date($d->{content}) : '',
+                    $d->{order}
+                );
             } else {
                 # add data to container
-                $element->add_data($at,
-                                   exists $d->{content} ? $d->{content} : '',
-                                   $d->{order});
+                $element->add_field(
+                    $at,
+                    exists $d->{content} ? $d->{content} : '',
+                    $d->{order}
+                );
             }
 
             $element->save; # I'm not sure why this is necessary after
@@ -495,10 +503,11 @@ sub _deserialize_tile {
     # load containers
     if ($data->{container}) {
         foreach my $c (@{$data->{container}}) {
-            my $at = $valid_container{$c->{element}};
+            my $key_name = $c->{element_type} || $c->{element};
+            my $at = $valid_container{$key_name};
             throw_ap(error => "Error loading container element for " .
                        $element->get_key_name .
-                       " cannot add data element $c->{element} here.")
+                       " cannot add field $key_name here.")
               unless $at;
 
             # setup container object
@@ -511,9 +520,11 @@ sub _deserialize_tile {
             push @relations, _load_relateds($container, $c, $site_id);
 
             # recurse
-            push @relations, _deserialize_tile(element   => $container,
-                                               site_id   => $site_id,
-                                               data      => $c);
+            push @relations, _deserialize_element(
+                element   => $container,
+                site_id   => $site_id,
+                data      => $c
+            );
             # Log it.
             log_event("${type}_add_element", $object,
                       { Element => $container->get_key_name })
@@ -562,25 +573,28 @@ sub _load_relateds {
 }
 
 
-=item @related = _serialize_tile(writer => $writer, element => $element, args => $args)
+=item @related = _serialize_element(writer => $writer, element => $element, args => $args)
 
-Serializes a single tile into the contents of an <elements> tag in the
+Serializes a single element into the contents of an <elements> tag in the
 media and story elements. It calls itself recursively on containers.
 Returns a list of two-element arrays - [ "media", $id ] or [ "story",
 $id ].  These are the related objects serialized.
 
 =cut
 
-sub _serialize_tile {
+sub _serialize_element {
     my %options  = @_;
-    my $element  = $options{element};
+    my $element  = $options{element_type};
     my $writer   = $options{writer};
     my $diff     = $options{diff} || 0;
     my @related;
 
     if ($element->is_container) {
-        my %attr  = (element => $element->get_key_name,
-                     order   => $element->get_place - $diff);
+        my %attr = (
+            element_type => $element->get_key_name,
+            order   => $element->get_place - $diff
+        );
+
         my @e = $element->get_elements();
 
         # look for related stuff and tag relative if we'll include in
@@ -608,19 +622,21 @@ sub _serialize_tile {
             # first serialize all data elements
             foreach my $e (@e) {
                 next if $e->is_container;
-                push(@related, _serialize_tile(writer  => $writer,
-                                               element => $e,
-                                               args    => $options{args},
-                                              ));
+                push(@related, _serialize_element(
+                    writer  => $writer,
+                    element_type => $e,
+                    args    => $options{args},
+                ));
             }
 
             # then all containers
             foreach my $e (@e) {
                 next unless $e->is_container;
-                push(@related, _serialize_tile(writer  => $writer,
-                                               element => $e,
-                                               args    => $options{args},
-                                              ));
+                push(@related, _serialize_element(
+                    writer       => $writer,
+                    element_type => $e,
+                    args         => $options{args},
+                ));
             }
 
             $writer->endTag("container");
@@ -631,22 +647,26 @@ sub _serialize_tile {
     } else {
         my $data;
 
-        if ($element->get_element_data_obj->get_sql_type eq 'date') {
+        if ($element->get_sql_type eq 'date') {
             # get date data and format for output
-            $data = $element->get_data(ISO_8601_FORMAT);
+            $data = $element->get_value(ISO_8601_FORMAT);
             $data = db_date_to_xs_date($data) if $data;
         } else {
-            $data = $element->get_data();
+            $data = $element->get_value();
         }
 
         if (defined $data and length $data) {
-            $writer->dataElement("data", $data,
-                                 element => $element->get_key_name,
-                                 order   => $element->get_place - $diff);
+            $writer->dataElement(
+                field       => $data,
+                type => $element->get_key_name,
+                order       => $element->get_place - $diff,
+            );
         } else {
-            $writer->emptyTag("data",
-                              element => $element->get_key_name,
-                              order   => $element->get_place - $diff);
+            $writer->emptyTag(
+                'field',
+                type => $element->get_key_name,
+                order       => $element->get_place - $diff,
+            );
         }
     }
 
@@ -664,7 +684,7 @@ sub resolve_relations {
                            "\"$r->{story_id}\"")
                   unless exists $story_ids->{$r->{story_id}};
                 $r->{container}->
-                    set_related_instance_id($story_ids->{$r->{story_id}});
+                    set_related_story_id($story_ids->{$r->{story_id}});
             }
             if ($r->{media_id}) {
                 throw_ap(error => __PACKAGE__ .
@@ -682,7 +702,7 @@ sub resolve_relations {
                   unless Bric::Biz::Asset::Business::Story->list_ids({
                       id => $r->{story_id}
                   });
-                $r->{container}->set_related_instance_id($r->{story_id});
+                $r->{container}->set_related_story_id($r->{story_id});
             } elsif ($r->{story_uri}) {
                 my ($sid) = Bric::Biz::Asset::Business::Story->list_ids({
                     primary_uri => $r->{story_uri},
@@ -690,7 +710,7 @@ sub resolve_relations {
                 });
                 throw_ap(error => __PACKAGE__ . qq{ : related story_uri "$r->{story_uri}"}
                            . qq{ not found in site "$r->{site_id}"}) unless $sid;
-                $r->{container}->set_related_instance_id($sid);
+                $r->{container}->set_related_story_id($sid);
             }
             if ($r->{media_id}) {
                 throw_ap(error => __PACKAGE__ . " : related media_id \"$r->{media_id}\""
