@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-08-12 17:13:34 -0700 (Thu, 12 Aug 2004) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ use strict;
 ################################################################################
 # Programmatic Dependences
 use Bric::Config qw(:alert);
-use Bric::Util::DBI qw(:standard col_aref);
+use Bric::Util::DBI qw(:all);
 use Bric::Util::AlertType;
 use Bric::Util::Alerted;
 use Bric::Util::EventType;
@@ -95,10 +95,11 @@ use constant DEBUG => 0;
 # Identifies databse columns and object keys.
 my @cols = qw(id event__id alert_type__id subject message timestamp);
 my @props = qw(id event_id alert_type_id subject message timestamp);
-my %map = (id => 'id',
-           timestamp => 'timestamp',
-           event_id => 'event__id',
-           alert_type_id => 'alert_type__id'
+my %map = (
+    id            => 'id = ?',
+    timestamp     => 'timestamp = ?',
+    event_id      => 'event__id = ?',
+    alert_type_id => 'alert_type__id = ?',
 );
 
 # How we know what libraries to use for sending alerts.
@@ -296,13 +297,13 @@ sub new {
     my $sth = prepare_c(qq{
         INSERT INTO alert (@cols)
         VALUES ($fields)
-        }, undef);
+    }, undef);
     execute($sth, @{$init}{@props[1..$#props]});
     # Grab its new ID.
     $init->{id} = last_key('alert');
 
     # Now send all the individual alerts.
-    &$send_em($init, $at, $event);
+    $send_em->($init, $at, $event, $user);
     $self->SUPER::new($init);
 }
 
@@ -376,43 +377,42 @@ parameters passed via an anonymous hash. The supported lookup keys are:
 
 =over 4
 
-=item *
+=item id
 
-alert_type_id
+Alert ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item alert_type_id
 
-event_id
+A Bric::Util::AlertType ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item event_id
 
-subject
+A Bric::Util::Event ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item subject
 
-message
+=item name
 
-=item *
+An alert subject. C<name> is an alias for C<subject>. May use C<ANY> for a
+list of possible values.
 
-timestamp
+=item message
 
-=item *
+An alert message. May use C<ANY> for a list of possible values.
 
-no_ack
+=item timestamp
 
-=item *
+An alert timestamp. May use C<ANY> for a list of possible values.
 
-time_start and time_end
+=item time_start
+
+=item time_end
+
+These two parameters, when used, must be used together to specify a range of
+dates between which to retrieve Bric::Util::Alert objects.
 
 =back
 
-The last two lookup keys, time_start and time_end, must be used together, as
-they represent a range of dates between which to retrieve Bric::Util::Alert
-objects. Set no_ack to true to have list() return only unacknowledged alerts.
-
-Any combination of these keys may be used, although the most common may be
-event_id or a combination of alert_type_id and no_ack.
-
 B<Throws:>
 
 =over 4
@@ -1206,37 +1206,48 @@ B<Notes:> NONE.
 
 $get_em = sub {
     my ($pkg, $params, $ids) = @_;
-    my (@txt_wheres, @num_wheres, @params);
-    while (my ($k, $v) = each %$params) {
-        next if $k eq 'time_end';
-        if ($k eq 'time_start') {
-            push @num_wheres, 'timestamp BETWEEN ? AND ?';
-            push @params, @{$params}{qw(time_start time_end)};
-        } elsif ($k eq 'subject' || $k eq 'message') {
-            push @txt_wheres, "LOWER($k)";
-            push @params, lc $v;
+    my (@wheres, @params);
+    my $time_end = delete $params->{time_end};
+    if (exists $params->{name}) {
+        # Name is an alias for subject.
+        if (exists $params->{subject}) {
+            # Prefer subject. XXX Throw exception?
+            delete $params->{name};
         } else {
-            push @num_wheres, $map{$k};
-            push @params, $v;
+            $params->{subject} = delete $params->{name};
+        }
+    }
+
+    while (my ($k, $v) = each %$params) {
+        if ($k eq 'time_start') {
+            push @wheres, 'timestamp BETWEEN ? AND ?';
+            push @params, db_date($params->{time_start}), db_date($time_end);
+        } elsif ($k eq 'subject' || $k eq 'message') {
+            push @wheres, any_where $v, "LOWER($k) LIKE LOWER(?)", \@params;
+        } else {
+            if ($k eq 'timestamp') {
+                $v = ref $v ? ANY( map { db_date($_) } @$v )
+                            : db_date($v)
+                            ;
+            }
+            push @wheres, any_where $v, $map{$k}, \@params;
         }
     }
 
     # Assemble the WHERE clause.
-    my $where = '';
-    local $" = ' = ? AND ';
-    $where = "WHERE  @num_wheres = ?" if @num_wheres;
-    local $" = ' LIKE ? AND ';
-    $where .= $where ? "AND @txt_wheres LIKE ?" : "WHERE  @txt_wheres LIKE ?"
-      if @txt_wheres;
+    my $where = @wheres ? 'WHERE ' . join ' AND ', @wheres
+                        : ''
+                        ;
 
     # Assemble and prepare the query.
-    local $" = ', ';
-    my @qry_cols = $ids ? ('id') : @cols;
+    my ($qry_cols, $order) = $ids ? ('id', 'id')
+                                  : (join(', ', @cols), 'timestamp')
+                                  ;
     my $sel = prepare_c(qq{
-        SELECT @qry_cols
+        SELECT $qry_cols
         FROM   alert
         $where
-        ORDER BY timestamp
+        ORDER BY $order
     }, undef);
 
     # Just return the IDs, if they're what's wanted.
@@ -1300,10 +1311,10 @@ $replace = sub {
     return $prop;
 };
 
-=item my $bool = &$send_em($self, $at, $event)
+=item my $bool = $send_em->($self, $at, $event, $user)
 
-Sends individual alerts to their recipients, and creates new Bric::Util::Alerted
-objects for each one of them.
+Sends individual alerts to their recipients, and creates new
+Bric::Util::Alerted objects for each one of them.
 
 B<Throws:> NONE.
 
@@ -1319,7 +1330,7 @@ $send_em = sub {
     # database, but that seems like a waste of overhead, since this function
     # is only called internally, and therefore doesn't need access to
     # individual Bric::Util::Alerted objects. So I just do it all here.
-    my ($self, $at, $event) = @_;
+    my ($self, $at, $event, $user) = @_;
 
     # Use this sth to insert users into alerted.
     my $ins_alerted = prepare_c(qq{
@@ -1334,6 +1345,19 @@ $send_em = sub {
         VALUES (?, ?, ?, ?)
     }, undef);
 
+    my $from = ALERT_FROM;
+    # Try to find an address for the trigger user.
+    if (my @contacts = Bric::Biz::Contact->list({
+        person_id => $user->get_id,
+        type      => ANY(Bric::Biz::Contact->list_alertable_types)
+    })) {
+        my %contacts = map { $_->get_type => $_->get_value } @contacts;
+        $from = $contacts{'Primary Email'}
+             || $contacts{'Secondary Email'}
+             || $contacts{'Pager Email'}
+             || $from;
+    }
+
     my (%alerted, %missed);
     my %ctypes = Bric::Biz::Contact->href_alertable_type_ids;
     while (my ($ctype, $cid) = each %ctypes) {
@@ -1357,11 +1381,12 @@ $send_em = sub {
         next unless %email;
 
         # Now send the email.
-        my $m = Bric::Util::Trans::Mail->new({ from => ALERT_FROM,
-                                             &ALERT_TO_METH => [ keys %email ],
-                                             subject => $self->{subject},
-                                             message => $self->{message}
-                                           });
+        my $m = Bric::Util::Trans::Mail->new({
+            from           => $from,
+            &ALERT_TO_METH => [ keys %email ],
+            subject        => $self->{subject},
+            message        => $self->{message}
+        });
         eval { $m->send; };
         my $time = $@ ? (warn "Alert Emailing failed: $@\n", undef)[1]
           : db_date(undef, 1);
@@ -1399,7 +1424,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -1409,4 +1434,3 @@ L<Bric::Util::EventType|Bric::Util::EventType>,
 L<Bric::Util::Event|Bric::Util::Event>
 
 =cut
-
