@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-08-26 13:42:53 -0700 (Fri, 26 Aug 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -335,29 +335,39 @@ search parameters passed via an anonymous hash. The supported lookup keys are:
 
 =over 4
 
-=item *
+=item id
 
-event_type_id
+Alert type ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item event_type_id
 
-owner_id
+Event type ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item owner_id
 
-name
+User id for user who owns alert types. May use C<ANY> for a list of possible
+values.
 
-=item *
+=item name
 
-subject
+Alert type name. May use C<ANY> for a list of possible values.
 
-=item *
+=item subject
 
-message
+Alert type subject. May use C<ANY> for a list of possible values.
 
-=item *
+=item message
 
-active
+Alert type message. May use C<ANY> for a list of possible values.
+
+=item active
+
+Boolean value indicating whether or not an alert type is active.
+
+=item grp_id
+
+ID of a Bric::Util::Grp with which alert types may be associated. May use
+C<ANY> for a list of possible values.
 
 =back
 
@@ -1055,7 +1065,7 @@ When the alert is sent and saved as a Bric::Util::Alert object in the database,
 these variables will be evaluated and filled in with their underlying values:
 
   A story was saved and moved to the Publish Desk by David Wheeler
-  <david@wheeler.net>.
+  <david@justatheory.com>.
 
 Feel free to use as many variables as necessary (and as are available from
 Bric::Util::EventType::get_alert_props()). Be sure to call $at->save if you have
@@ -2562,23 +2572,24 @@ $get_em = sub {
     my ($pkg, $params, $ids) = @_;
     my $tables = "$table a, $mem_table m, $map_table c";
     my @wheres = ('a.id = c.object_id','c.member__id = m.id',
-                  'm.active = 1');
-    push @wheres, "a.del = 0" unless exists $params->{id};
+                  "m.active = '1'");
+    push @wheres, "a.del = '0'" unless exists $params->{id};
 
     my @params;
     while (my ($k, $v) = each %$params) {
         if ($map{$k}) {
-            push @wheres, "a.$map{$k} = ?";
-            push @params, $v;
+            push @wheres, any_where $v, "a.$map{$k} = ?", \@params;
         } elsif ($k eq 'grp_id') {
             # Fancy-schmancy second join.
             $tables .= ", $mem_table m2, $map_table c2";
-            push @wheres, ('a.id = c2.object_id', 'c2.member__id = m2.id',
-                           'm2.active = 1', 'm2.grp__id = ?');
-            push @params, $v;
+            push @wheres, (
+                'a.id = c2.object_id',
+                'c2.member__id = m2.id',
+                "m2.active = '1'",
+                any_where $v, 'm2.grp__id = ?', \@params
+            );
         } else {
-            push @wheres, "LOWER(a.$k) LIKE ?";
-            push @params, lc $v;
+            push @wheres, any_where $v, "LOWER(a.$k) LIKE LOWER(?)", \@params;
         }
     }
 
@@ -2869,7 +2880,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
