@@ -3,7 +3,7 @@ package Bric::Util::Burner::Mason;
 
 =head1 NAME
 
-Bric::Util::Burner::Mason - Bric::Util::Burner subclass to publish business assets using Mason formatting assets.
+Bric::Util::Burner::Mason Publish sturies using Mason templates
 
 =head1 VERSION
 
@@ -15,22 +15,21 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
- use Bric::Util::Burner::Mason;
+  use Bric::Util::Burner::Mason;
 
- # Create a new Mason burner using the settings from $burner
- $mason_burner = Bric::Util::Burner::Mason->new($burner);
+  # Create a new Mason burner using the settings from $burner
+  my $mason_burner = Bric::Util::Burner::Mason->new($burner);
 
- # burn an asset, get back a list of resources
- @resources = $mason_burner->burn_one($ba, $oc, $cat, $at);
+  # burn an asset, get back a list of resources
+  my $resources = $mason_burner->burn_one($ba, $oc, $cat, $at);
 
 =head1 DESCRIPTION
 
-This module handles burning business assets using Mason formatting
-assets.
+This module handles burning business assets using Mason templates.
 
 =cut
 
@@ -51,10 +50,9 @@ use HTML::Mason::Compiler::ToObject;
 use Bric::Util::Fault qw(throw_gen rethrow_exception isa_exception
                          throw_burn_error);
 use Bric::Util::Trans::FS;
-use Bric::Dist::Resource;
 use Bric::Config qw(:burn :l10n);
 use Bric::Util::Burner qw(:modes);
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 require XML::Writer if INCLUDE_XML_WRITER;
 
 #==============================================================================#
@@ -95,7 +93,6 @@ BEGIN {
                          #- Per burn/deploy values.
                          'job'            => Bric::FIELD_READ,
                          'more_pages'     => Bric::FIELD_READ,
-                         'burn_again'     => Bric::FIELD_RDWR,
 
                          # Private Fields
                          '_interp'         => Bric::FIELD_NONE,
@@ -105,12 +102,11 @@ BEGIN {
                          '_elem'           => Bric::FIELD_NONE,
                          '_at'             => Bric::FIELD_NONE,
                          '_files'          => Bric::FIELD_NONE,
-                         '_res'            => Bric::FIELD_NONE,
                          '_page_place'     => Bric::FIELD_NONE,
                         });
 }
 
-__PACKAGE__->_register_burner( Bric::Biz::AssetType::BURNER_MASON,
+__PACKAGE__->_register_burner( Bric::Biz::OutputChannel::BURNER_MASON,
                                category_fn    => 'autohandler',
                                cat_fn_has_ext => 0,
                                exts           =>
@@ -143,10 +139,6 @@ has its attributes initialized by the passed object.
 sub new {
     my ($class, $burner) = @_;
     my $init = { %$burner };
-
-    # setup defaults (in addition to those provided by $burner)
-    $init->{_res}     ||= [];
-
     # create the object using Bric's constructor and return it
     return $class->Bric::new($init);
 }
@@ -163,10 +155,10 @@ sub new {
 
 #------------------------------------------------------------------------------#
 
-=item @resources = $b->burn_one($ba, $oc, $cat, $at);
+=item $resources = $b->burn_one($ba, $oc, $cat, $at);
 
-Burn an asset in a given output channel and category, this is usually called by
-the preview or publish method. Returns a list of resources burned. 
+Burn an asset in a given output channel and category, this is usually called
+by the preview or publish method. Returns a list of resources burned.
 
 Parameters are:
 
@@ -186,8 +178,7 @@ A category in which to burn the asset.
 
 =item C<$at>
 
-A asset type object for $ba . 
-Note that this is not currently used by Mason.
+A asset type object for $ba . Note that this is not currently used by Mason.
 
 =back
 
@@ -225,12 +216,13 @@ sub burn_one {
     }
 
     # Find the inheritance path and the template name.
-    my $element   = $ba->get_tile;
+    my $element   = $ba->get_element;
     my $tmpl_path = $cat->ancestry_path;
     my $tmpl_name = $element->get_key_name . '.mc';
 
     # Create the interpreter
     my $interp = HTML::Mason::Interp->new(
+        MASON_INTERP_ARGS,
         $self->_interp_args,
         request_class => 'HTML::Mason::Request',
         error_mode    => 'fatal',
@@ -297,7 +289,8 @@ sub burn_one {
                              mode    => $self->get_mode,
                              oc      => $self->get_oc->get_name,
                              cat     => $self->get_cat->get_uri,
-                             elem    => $element->get_name;
+                             elem    => $element->get_name,
+                             element => $element;
         }
 
         # End the page if there is content in the buffer.
@@ -324,11 +317,7 @@ sub burn_one {
 
     # Free up the element stack.
     $self->_pop_element;
-
-    # Return a list of the resources we just burned.
-    my $ret = $self->_get('_res') || return;
-    $self->_set(['_res', 'page'], [[], 0]);
-    return wantarray ? @$ret : $ret;
+    return $self->get_resources;
 }
 
 ################################################################################
@@ -353,10 +342,12 @@ sub chk_syntax {
     my $data = $tmpl->get_data or return $self;
 
     # Create the interpreter
-    my $interp = HTML::Mason::Interp->new( $self->_interp_args,
-                                          'comp_root'  => $self->get_comp_dir,
-                                          'data_dir'   => $self->get_data_dir,
-                                          );
+    my $interp = HTML::Mason::Interp->new(
+        MASON_INTERP_ARGS,
+        $self->_interp_args,
+        'comp_root'  => $self->get_comp_dir,
+        'data_dir'   => $self->get_data_dir,
+    );
 
     $interp->set_global('$burner', $self);
 
@@ -477,56 +468,6 @@ sub find_first_template {
 
 #------------------------------------------------------------------------------#
 
-=item $success = $b->display_pages($paginated_element_name)
-
-=item $success = $b->display_pages($paginated_element_name, %ARGS)
-
-=item $success = $b->display_pages(\@paginated_element_names, %ARGS)
-
-A method to be called from template space. Use this method to display
-paginated elements. If this method is used, the burn system will run once for
-every page element listed in C<\@paginated_element_names> (or just
-C<$paginated_element_name>) in the story; this is so that autohandlers will be
-called when appropriate. All arguments after the first argument will be passed
-to the template executed as its C<%ARGS> hash.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
-sub display_pages {
-    my $self = shift;
-    my $names = shift;
-    $names = [$names] unless ref $names;
-
-    # Get the current element
-    my $elem = $self->_current_element;
-    my $page_place = $self->_get('_page_place') || 0;
-
-    # Get the next two containers starting with place == $page_place
-    # and having name eq one of @$names. $next_page will be undef
-    # for the last page. The map changes old-style names to key_names.
-    my $joined_names = join('|', map {y/a-z0-9/_/cs; lc $_} @$names);
-    my ($page_elem, $next_page) =
-      grep { $_->is_container
-             && $_->get_place >= $page_place
-             && $_->get_key_name =~ /^($joined_names)$/ }
-      $elem->get_tiles;
-
-    # Set the 'more_pages' and '_page_place' properties.
-    $self->_set([ qw(more_pages _page_place) ],
-                [ $next_page,
-                  $page_elem ? $page_elem->get_place + 1 : $page_place + 1 ]);
-
-    $self->display_element($page_elem, @_);
-}
-
-#------------------------------------------------------------------------------#
-
 =item $success = $b->display_element($element)
 
 =item $success = $b->display_element($element, %ARGS)
@@ -591,32 +532,6 @@ B<Notes:> NONE.
 
 =cut
 
-##############################################################################
-
-=item $success = $b->set_burn_again(1)
-
-=item my $again = $b->get_burn_again
-
-This method is designed to be called from within a template. When passed a
-true value, it causes the burner to burn the current story and page again,
-creating another file. This is useful for creating multi-file output without
-extra paginated subelements. For example, if you need to create an index of
-stories, and you only want to list 10 on a page over multiple pages, you can
-use this method to force the burner to burn as many pages as you need to get
-the job done.
-
-When the burner prepares to burn the page again, it resets the C<burn_again>
-attribute. So you'll need to set it for every page for which another page
-burned.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
 #------------------------------------------------------------------------------#
 
 =item $success = $b->chain_next()
@@ -680,7 +595,7 @@ sub end_page {
     close(OUT);
 
     # Add a resource to the job object.
-    $self->_add_resource($file, $uri);
+    $self->add_resource($file, $uri);
 
     # Clear the output buffer.
     $$buf = '';
@@ -702,48 +617,10 @@ NONE.
 
 =over 4
 
-=item $success = $b->_add_resource();
-
-Adds a Bric::Dist::Resource object to this burn.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
-sub _add_resource {
-    my $self = shift;
-    my ($file, $uri) = @_;
-    my ($story, $ext) = $self->_get(qw(story output_ext));
-
-    # Create a resource for the distribution stuff.
-    my $res = Bric::Dist::Resource->lookup({
-        path => $file,
-        uri  => $uri,
-    }) ||
-    Bric::Dist::Resource->new({
-        path => $file,
-        uri  => $uri,
-    });
-
-    # Set the media type.
-    $res->set_media_type(Bric::Util::MediaType->get_name_by_ext($ext));
-    # Add our story ID.
-    $res->add_story_ids($story->get_id);
-    $res->save;
-    my $ress = $self->_get('_res');
-    push @$ress, $res;
-}
-
-#------------------------------------------------------------------------------#
-
 =item $template = $b->_load_template_element($element);
 
-Given an element (a business asset/data tile) return the template element that
-formats it.
+Given an element (a business asset/data element) return the template element
+that formats it.
 
 B<Throws:> NONE.
 
@@ -767,7 +644,8 @@ sub _load_template_element {
                           mode  => $self->get_mode,
                           oc    => $self->get_oc->get_name,
                           cat   => $self->get_cat->get_uri,
-                          elem  => $element->get_name;
+                          elem  => $element->get_name,
+                          element => $element;
     return $tmpl;
 }
 
@@ -827,7 +705,7 @@ sub _push_element {
     my ($elem_stack, $at_stack) = $self->_get('_elem', '_at');
 
     push @$elem_stack, $element;
-    push @$at_stack, $element->get_element;
+    push @$at_stack, $element->get_element_type;
 
     $self->_set(['_elem', '_at'], [$elem_stack, $at_stack]);
 }
@@ -891,9 +769,9 @@ sub _render_element {
         return $html;
     } else {
         if ($display) {
-            HTML::Mason::Request->instance->out($elem->get_data);
+            HTML::Mason::Request->instance->out($elem->get_value);
         } else {
-            return $elem->get_data();
+            return $elem->get_value();
         }
     }
 }
@@ -1009,7 +887,7 @@ Garth Webb L<gt>garth@perijove.comL<lt>
 
 Sam Tregar L<gt>stregar@about-inc.comL<lt>
 
-David Wheeler L<gt>david@wheeler.netL<lt>
+David Wheeler L<gt>david@justatheory.comL<lt>
 
 =head1 SEE ALSO
 
