@@ -3,8 +3,7 @@ package Bric::Util::Burner::Template;
 
 =head1 NAME
 
-Bric::Util::Burner::Template - Bric::Util::Burner subclass to publish business
-assets using HTML::Template formatting assets.
+Bric::Util::Burner::Template - Publish stories using HTML::Template templates
 
 =head1 VERSION
 
@@ -16,22 +15,21 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
+$LastChangedDate: 2006-01-17 16:09:49 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
- use Bric::Util::Burner::Template;
+  use Bric::Util::Burner::Template;
 
   # Create a new HTML::Template burner using the settings from $burner
-  $template_burner = Bric::Util::Burner::Template->new($burner);
+  my $template_burner = Bric::Util::Burner::Template->new($burner);
 
   # burn an asset, get back a list of resources
-  @resources = $template_burner->burn_one($ba, $oc, $cat, $at);
+  my $resources = $template_burner->burn_one($ba, $oc, $cat, $at);
 
 =head1 DESCRIPTION
 
-This module handles burning business assets using HTML::Template formatting
-assets.
+This module handles burning business assets using HTML::Template templates.
 
 =cut
 
@@ -53,7 +51,6 @@ use strict;
 use HTML::Template::Expr;
 use Bric::Util::Trans::FS;
 use Bric::Util::Fault qw(throw_gen throw_burn_error);
-use Bric::Dist::Resource;
 use Bric::Config qw(:burn :l10n);
 use Digest::MD5 qw(md5 md5_hex);
 use Time::HiRes qw(time);
@@ -77,7 +74,6 @@ my $fs = Bric::Util::Trans::FS->new();
 my %SCRIPT_CACHE;
 
 use constant PAGE_BREAK => "<<<<<<<<<<<<<<<<<< PAGE BREAK >>>>>>>>>>>>>>>>>>";
-use constant CONTENT    => "<<<<<<<<<<<<<<<<<< CONTENT >>>>>>>>>>>>>>>>>>";
 use constant DEBUG      => 0;
 
 #--------------------------------------#
@@ -88,15 +84,14 @@ BEGIN {
     Bric::register_fields({
                            # Private Fields
                            _template_roots  => Bric::FIELD_NONE,
-                           _res             => Bric::FIELD_NONE,
                            _output_path     => Bric::FIELD_NONE,
                            _at              => Bric::FIELD_NONE,
-                           _header          => Bric::FIELD_NONE,
-                           _footer          => Bric::FIELD_NONE,
+                           _output          => Bric::FIELD_NONE,
+                           _tmpl_file       => Bric::FIELD_NONE,
                           });
 }
 
-__PACKAGE__->_register_burner( Bric::Biz::AssetType::BURNER_TEMPLATE,
+__PACKAGE__->_register_burner( Bric::Biz::OutputChannel::BURNER_TEMPLATE,
                                category_fn    => 'category',
                                cat_fn_has_ext => 1,
                                exts           =>
@@ -147,10 +142,10 @@ sub new {
 
 =over 4
 
-=item @resources = $template_burner->burn_one($ba, $oc, $cat, $at);
+=item $resources = $template_burner->burn_one($ba, $oc, $cat, $at);
 
-Burn an asset in a given output channel and category, this is usually called by
-the preview or publish method. Returns a list of resources burned. 
+Burn an asset in a given output channel and category, this is usually called
+by the preview or publish method. Returns a list of resources burned.
 
 Parameters are:
 
@@ -190,14 +185,11 @@ NONE
 
 sub burn_one {
     my $self = shift;
-    my ($story, $oc, $cat, $at) = @_;
+    my ($story, $oc, $cat) = @_;
 
     print STDERR __PACKAGE__, "::burn_one() called.\n"
         if DEBUG;
 
-    # setup empty state for this burn
-    my $res      = [];
-
     # compute template_roots for later
     my $comp_dir = $self->get_comp_dir;
     my $template_roots = [ map { $fs->cat_dir($comp_dir, "oc_" . $_->get_id) }
@@ -209,41 +201,21 @@ sub burn_one {
                            ($oc, $oc->get_includes);
     }
 
+    my $at = $story->get_element_type;
     # save burn parameters
-    $self->_set([qw(_res _at _template_roots)],
-                [$res, $at, $template_roots]);
-
-    # run the category script if it exists
-    if ($self->_find_file('category', '.pl') or
-        $self->_find_file('category', '.tmpl')) {
-        my $category_output = $self->run_script('category', '.pl');
-        if (defined $category_output) {
-            # get header and footer and save them for _write_pages
-            my ($header, $footer) = split(/${\CONTENT}/, $category_output, 2);
-            $self->_set([qw(_header _footer)], [\$header, \$footer]);
-        }
-    }
+    $self->_set([qw(_at _template_roots)] => [$at, $template_roots]);
 
     # get the element for the story
-    my $element = $story->get_tile;
+    my $element = $story->get_element;
 
     # run the script for the element
     my $output = $self->run_script($element);
 
     # write the files
-    $self->_write_pages(\$output);
+    $self->_write_pages(\$output, $element);
 
     # Return a list of the resources we just burned.
-    my $ret = $self->_get('_res') || return;
-
-    throw_burn_error error => "No files burned",
-                     mode  => $self->get_mode,
-                     oc    => $oc->get_name,
-                     cat   => $cat->get_uri,
-                     elem  => $element->get_name
-      unless @$ret;
-
-    return wantarray ? @$ret : $ret;
+    return $self->get_resources
 }
 
 ################################################################################
@@ -357,10 +329,6 @@ B<Notes:> NONE.
 
 sub run_script {
     my ($self, $element) = (shift, shift);
-    my ($story) = $self->get_story;
-    my $template_root = $fs->cat_dir($self->get_comp_dir,
-                                     ('oc_' . $self->get_oc->get_id));
-
     throw_burn_error error =>  __PACKAGE__ . "::run_script() requires an " .
                               "\$element argument.",
                      mode  => $self->get_mode,
@@ -370,118 +338,8 @@ sub run_script {
 
     print STDERR __PACKAGE__, "::run_script() called.\n" if DEBUG;
 
-    # find script element
-    my $script = $self->_find_file($element, '.pl');
-
-    # Set the element attribute.
-    $self->_set(['element'], [$element]);
-
-    # no script, perform default script action directly
-    if (not defined $script) {
-        return $self->new_template(element => $element)->output();
-    }
-
-    print STDERR __PACKAGE__, "::run_script() : found script file : $script.\n"
-      if DEBUG;
-
-    # construct package name
-
-    # escape everything into valid perl identifiers
-    my $package = $script;
-    $package =~ s/([^A-Za-z0-9_\/])/sprintf("_%2x",unpack("C",$1))/eg;
-
-    # second pass for slashes and words starting with a digit
-    $package =~ s{
-                  (/+)       # directory
-                  (\d?)      # package's first character
-              }[
-                "::" . (length $2 ? sprintf("_%2x",unpack("C",$2)) : "")
-               ]egx;
-
-    # prepend our root package
-    $package = "Bric::Util::Burner::Template::SANDBOX$package";
-
-    # read script contents into $sub
-    my $sub = "";
-    print STDERR __PACKAGE__, "::run_script() : reading $script.\n"
-      if DEBUG;
-    open(SCRIPT, $script)
-      or throw_burn_error error =>  "Unable to read $script : $!",
-                          mode  => $self->get_mode,
-                          oc    => $self->get_oc->get_name,
-                          cat   => $self->get_cat->get_uri,
-                          elem  => $element->get_name;
-    binmode(SCRIPT, ':utf8') if ENCODE_OK;
-    while(read(SCRIPT, $sub, 102400, length($sub))) {};
-    close(SCRIPT);
-
-    # compute md5 for script - used in caching system
-    my $md5 = md5($sub);
-
-    # check if script is cached and unchanged
-    if (exists $SCRIPT_CACHE{$package} and 
-        $SCRIPT_CACHE{$package} eq $md5) {
-        # compiled code is still good - nothing to do
-        print STDERR __PACKAGE__,
-        "::run_script() : skipping compilation - cached copy still good.\n"
-          if DEBUG;
-    } else {
-        print STDERR __PACKAGE__, "::run_script() : compiling...\n"
-          if DEBUG;
-
-        # determine filename for #line directive
-        my $line_file = substr($script, length($template_root));
-
-        # construct the code
-        my $code = <<END;
-package $package;
-use strict;
-use utf8;
-use vars ('\$burner', '\$element', '\$story');
-sub _run_script {
-#line 1 $line_file
-$sub
-}
-1;
-END
-        # compile the code
-        undef &{"$package\::_run_script"}; #avoid warnings
-        my $result = _compile($code);
-        unless ($result) {
-            throw_burn_error error   =>  "Error compiling script.",
-                             payload => $@,
-                             mode    => $self->get_mode,
-                             oc      => $self->get_oc->get_name,
-                             cat     => $self->get_cat->get_uri,
-                             elem    => $element->get_name
-              if $@;
-        }
-
-        # remember the md5
-        $SCRIPT_CACHE{$package} = $md5;
-    }
-
-    # setup globals for the script
-    {
-        no strict 'refs';
-        ${"$package\::burner"}  = $self;
-        ${"$package\::story"}   = $story;
-        ${"$package\::element"} = $element;
-    }
-
-    # call the script
-    my $cv = \&{"$package\::_run_script"};
-    my $output;
-    eval { $output = $cv->(@_) };
-
-    throw_burn_error error   =>  "Error running script.",
-                     payload => $@,
-                     mode    => $self->get_mode,
-                     oc      => $self->get_oc->get_name,
-                     cat     => $self->get_cat->get_uri,
-                     elem    => ref $element ? $element->get_name : $element
-      if $@;
-    return $output;
+    # find script element and run it.
+    return $self->_runit($element, $self->_find_file($element, '.pl'));
 }
 
 =item $template = $burner->new_template(...)
@@ -597,7 +455,7 @@ sub new_template {
     delete $args{element};
     delete $args{autofill};
 
-    if ($element and not exists $args{filename}) {
+    if ($element and not $args{filename} ||= $self->_get('_tmpl_file')) {
         # find element template file
         my $file = $self->_find_file($element, '.tmpl');
         throw_burn_error error => "Unable to find HTML::Template template"
@@ -606,7 +464,8 @@ sub new_template {
                          mode  => $self->get_mode,
                          oc    => $self->get_oc->get_name,
                          cat   => $self->get_cat->get_uri,
-                         elem  => $element->get_name
+                         elem  => $element->get_name,
+                         element => $element
           unless defined $file;
 
         print STDERR __PACKAGE__, "::new_template() : found template file ",
@@ -626,7 +485,8 @@ sub new_template {
     $args{cache} = 0             unless exists $args{cache};
 
     # setup some useful functions
-    # $args{functions}{call} => sub { $self->run_script($_[0]) };
+    #$args{functions}{call} => sub { $self->run_script($_[0]) };
+    $args{functions}{get_page} = sub { $self->get_page(@_); };
     $args{functions}{page_link} = sub { $self->page_file(@_); };
     $args{functions}{next_page_link} = sub { $self->page_file($_[0] + 1); };
     $args{functions}{prev_page_link} = sub { $self->page_file($_[0] - 1); };
@@ -637,22 +497,27 @@ sub new_template {
         HTML::Template::Expr->new(%args);
     };
 
+    # Add any existing content.
+    if (my $content = $self->_get('_output')) {
+        $template->param(content => $$content)
+    }
+
     # autofill with element data
     if ($autofill and $element) {
         my $story = $self->get_story();
         # fill in some non-element data
-        $template->param(title => $story->get_title)
-          if $template->query(name => "title");
+        my $meths = $story->my_meths;
+        while (my ($k, $v) = each %$meths) {
+            next unless $template->query(name => $k);
+            my $get = $v->{get_meth};
+            $template->param($k => $get->($story));
+        }
         $template->param(page_break => PAGE_BREAK)
           if $template->query(name => "page_break");
-        $template->param(content => CONTENT)
-          if $template->query(name => "content") and $element eq 'category';
 
-        unless ($element eq 'category') {
+        if ($element ne 'category') {
             # setup data for template
-            my $data = $self->_build_element_vars($element,
-                                                  $template,
-                                                  []);
+            my $data = $self->_build_element_vars($element, $template, []);
             $template->param($data);
         }
     }
@@ -682,31 +547,6 @@ sub page_break {
     return PAGE_BREAK;
 }
 
-=item $burner->content()
-
-This routine returns the magic content marker used in category templates to
-break between the header and the footer.
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub content {
-    return CONTENT;
-}
-
-#--------------------------------------#
-
 =back
 
 =head2 Private Instance Methods
@@ -741,7 +581,8 @@ sub _build_element_vars {
     # get list of names in this scope
     my %exists;
     if (@$path) {
-        %exists = map { $_ => 1 } $template->query(loop => [ @$path ]);
+        %exists = map { $_ => 1 } grep { defined }
+          $template->query(loop => [ @$path ]);
     } else {
         %exists = map { $_ => 1 } $template->param();
     }
@@ -749,7 +590,8 @@ sub _build_element_vars {
     # get list of names in element_loop scope
     my %element_loop_exists;
     if (@$path) {
-        %element_loop_exists = map { $_ => 1 } $template->query(loop => [ @$path, 'element_loop' ]);
+        %element_loop_exists = map { $_ => 1 }
+          grep { defined } $template->query(loop => [ @$path, 'element_loop' ]);
     } elsif ($template->param('element_loop')) {
         %element_loop_exists = map { $_ => 1 } $template->param('element_loop');
     }
@@ -759,16 +601,18 @@ sub _build_element_vars {
     my %loop = ( element_loop => [] );
     my %var;
 
-    # get link if related
-    my ($thing, $link);
-    if (($thing = $element->get_related_media()) or
-        ($thing = $element->get_related_story())) {
-        $link = $thing->get_primary_uri;
-        $var{link} = $link;
+    # Get related story URI. Keep "link" for backwards compatability.
+    if (my $thing = $element->get_related_story) {
+        $var{link} = $var{rel_story_uri} = $thing->get_primary_uri;
+    }
+
+    # Get related media URI. Backwards-compatable "link" overrides story.
+    if (my $thing = $element->get_related_media) {
+        $var{link} = $var{rel_media_uri} = $thing->get_uri;
     }
 
     # loop over elements
-    foreach my $e ($element->get_tiles()) {
+    foreach my $e ($element->get_elements()) {
         # get a proper name
         my $name = lc $e->get_key_name;
 
@@ -780,7 +624,7 @@ sub _build_element_vars {
 
         # simple data elements
         unless ($e->is_container) {
-            $var{$name} = $e->get_data();
+            $var{$name} = $e->get_value();
             $loop{"$name\_loop"} = [] unless exists $loop{"$name\_loop"};
 
             # push a row for this value
@@ -876,7 +720,7 @@ sub _find_file {
             my $path = $fs->cat_dir($troot, @cats, $filename);
             return $path if -e $path;
         }
-    } while(pop(@cats));
+    } while (pop @cats);
 
     # returns undef if we didn't find anything
     return undef;
@@ -915,49 +759,11 @@ sub _get_template_path {
 }
 
 
-=item $success = $self->_add_resource();
+=item $self->_write_pages(\$output, $element)
 
-Adds a Bric::Dist::Resource object to this burn.
-
-B<Throws:>
-
-NONE
-
-B<Side Effects:>
-
-NONE
-
-B<Notes:>
-
-NONE
-
-=cut
-
-sub _add_resource {
-    my $self = shift;
-    my ($file, $uri) = @_;
-    my $ba  = $self->get_story;
-
-    # Create a resource for the distribution stuff.
-    my $res = Bric::Dist::Resource->lookup({ path => $file}) ||
-              Bric::Dist::Resource->new({ path => $file,
-                                          uri  => $uri});
-
-    # Set the media type.
-    $res->set_media_type(
-      Bric::Util::MediaType->get_name_by_ext($self->_get('output_ext')));
-    # Add our story ID.
-    $res->add_story_ids($ba->get_id);
-    $res->save;
-    my $ress = $self->_get('_res');
-    push @$ress, $res;
-}
-
-=item $self->_write_pages(\$output)
-
-Writes pages in $output (and _header and _footer) to the appropriate output
-files on disk. Also takes care of building a list of resources in _res for the
-files written.
+Splits the pages in $$output in to their separate parts, executes any category
+templates for each, and writes them to the appropriate output files on disk.
+Also takes care of adding resources for the files written.
 
 B<Throws:>
 
@@ -974,64 +780,238 @@ NONE
 =cut
 
 sub _write_pages {
-    my ($self, $output) = @_;
-    my ($header, $footer) = $self->_get(qw(_header _footer));
-    $header ||= \"";
-    $footer ||= \"";
+    my ($self, $output, $element) = @_;
 
     print STDERR __PACKAGE__, "::_write_pages() called.\n"
         if DEBUG;
 
-    # multiple pages?
-    if ($$output =~ /${\PAGE_BREAK}/) {
-        my @pages = split /${\PAGE_BREAK}/, $$output;
-        for (my $page = 0; $page < @pages; $page++) {
-            # skip empty last page
-            last if $page == $#pages and $pages[$page] =~ /^\s*$/;
+    my @cat_tmpls = $self->_find_category_scripts;
 
-            # compute filename
-            my $filename = $self->page_filepath($page + 1);
+    my @pages = split /${\PAGE_BREAK}/, $$output;
+    for (my $page = 0; $page < @pages; $page++) {
+        # skip empty last page
+        last if $page == $#pages and $pages[$page] =~ /^\s*$/;
 
-            print STDERR __PACKAGE__, "::_write_pages() : opening multi page $filename\n"
-                if DEBUG;
-
-            # open new file and write to it
-            open(OUT, ">$filename")
-              or throw_gen error   => "Unable to open $filename",
-                           payload => $!;
-            binmode(OUT, ':' . $self->get_encoding || 'utf8') if ENCODE_OK;
-            print OUT $$header;
-            print OUT $pages[$page];
-            print OUT $$footer;
-            close(OUT);
-
-            # add resource object for this file
-            my $uri = $self->page_uri($page + 1);
-            $self->_add_resource($filename, $uri);
-        }
-    } else {
         # compute filename
-        my $filename = $self->page_filepath(1);
+        my $filename = $self->page_filepath($page + 1);
 
-        print STDERR __PACKAGE__,
-          "::_write_pages() : opening single page $filename\n" if DEBUG;
+        print STDERR __PACKAGE__, "::_write_pages() : opening page $filename\n"
+          if DEBUG;
+
+        # Execute any category templates.
+        for my $catspec (@cat_tmpls) {
+            $self->_set(['_output'] => [\$pages[$page]]);
+            if ($catspec->[1] eq 'pl') {
+                $self->_set(['_tmpl_file'] => ["$catspec->[0].tmpl"]);
+                $pages[$page] = $self->_runit($element, "$catspec->[0].pl");
+            } else {
+                my $tmpl = $self->new_template(
+                    element  => $element,
+                    filename => "$catspec->[0].tmpl",
+                );
+                $pages[$page] = $tmpl->output;
+            }
+        }
+        $self->_set([qw(_output _tmpl_file)] => [undef, undef]);
 
         # open new file and write to it
         open(OUT, ">$filename")
           or throw_gen error   => "Unable to open $filename",
                        payload => $!;
         binmode(OUT, ':' . $self->get_encoding || 'utf8') if ENCODE_OK;
-        print OUT $$header;
-        print OUT $$output;
-        print OUT $$footer;
+        print OUT $pages[$page];
         close(OUT);
 
         # add resource object for this file
-        my $uri = $self->page_uri(1);
-        $self->_add_resource($filename, $uri);
+        my $uri = $self->page_uri($page + 1);
+        $self->add_resource($filename, $uri);
     }
 }
 
+##############################################################################
+
+=item $output = $self->_runit($element, $script)
+
+Called by C<run_script()> and, for category templates, by C<_write_pages()>,
+this method executes the script (with the full path to the F<.pl> script
+defined in $script and returns the result. If $script is undefined,
+C<_runit()> simply calls C<new_template()> and returns the output of the
+template.
+
+B<Throws:> NONE.
+
+B<Side Effects:> NONE.
+
+B<Notes:> NONE.
+
+=cut
+
+sub _runit {
+    my ($self, $element, $script) = @_;
+    my ($story) = $self->get_story;
+    my $template_root = $fs->cat_dir(
+        $self->get_comp_dir, 'oc_' . $self->get_oc->get_id
+    );
+
+    # Set the element attribute.
+    $self->_set(['element'], [$element]);
+
+    # no script, perform default script action directly
+    if (not defined $script) {
+        return $self->new_template(element => $element)->output();
+    }
+
+    print STDERR __PACKAGE__, "::run_script() : found script file : $script.\n"
+      if DEBUG;
+
+    # escape everything into valid perl identifiers
+    my $package = $script;
+    $package =~ s/([^A-Za-z0-9_\/])/sprintf("_%2x",unpack("C",$1))/eg;
+
+    # second pass for slashes and words starting with a digit
+    $package =~ s{
+                  (/+)       # directory
+                  (\d?)      # package's first character
+              }[
+                "::" . (length $2 ? sprintf("_%2x",unpack("C",$2)) : "")
+               ]egx;
+
+    # prepend our root package
+    $package = "Bric::Util::Burner::Template::SANDBOX$package";
+
+    # read script contents into $sub
+    my $sub = "";
+    print STDERR __PACKAGE__, "::run_script() : reading $script.\n"
+      if DEBUG;
+    open(SCRIPT, $script)
+      or throw_burn_error error =>  "Unable to read $script : $!",
+                          mode  => $self->get_mode,
+                          oc    => $self->get_oc->get_name,
+                          cat   => $self->get_cat->get_uri,
+                          elem  => ref $element ? $element->get_name : $element,
+                          (ref($element) ? (element => $element) : ());
+    binmode(SCRIPT, ':utf8') if ENCODE_OK;
+    while(read(SCRIPT, $sub, 102400, length($sub))) {};
+    close(SCRIPT);
+
+    # compute md5 for script - used in caching system
+    my $md5 = md5($sub);
+
+    # check if script is cached and unchanged
+    if (exists $SCRIPT_CACHE{$package} and $SCRIPT_CACHE{$package} eq $md5) {
+        # compiled code is still good - nothing to do
+        print STDERR __PACKAGE__,
+        "::run_script() : skipping compilation - cached copy still good.\n"
+          if DEBUG;
+    } else {
+        print STDERR __PACKAGE__, "::run_script() : compiling...\n"
+          if DEBUG;
+
+        # determine filename for #line directive
+        my $line_file = substr($script, length($template_root));
+
+        # construct the code
+        my $code = <<END;
+package $package;
+use strict;
+use utf8;
+use vars ('\$burner', '\$element', '\$story');
+sub _run_script {
+#line 1 $line_file
+$sub
+}
+1;
+END
+        # compile the code
+        undef &{"$package\::_run_script"}; #avoid warnings
+        my $result = _compile($code);
+        unless ($result) {
+            throw_burn_error error   =>  "Error compiling script.",
+                             payload => $@,
+                             mode    => $self->get_mode,
+                             oc      => $self->get_oc->get_name,
+                             cat     => $self->get_cat->get_uri,
+                             elem    => $element->get_name,
+                             element => $element
+              if $@;
+        }
+
+        # remember the md5
+        $SCRIPT_CACHE{$package} = $md5;
+    }
+
+    # setup globals for the script
+    {
+        no strict 'refs';
+        ${"$package\::burner"}  = $self;
+        ${"$package\::story"}   = $story;
+        ${"$package\::element"} = $element;
+    }
+
+    # call the script
+    my $cv = \&{"$package\::_run_script"};
+    my $output;
+    eval { $output = $cv->(@_) };
+
+    throw_burn_error error   =>  "Error running script.",
+                     payload => $@,
+                     mode    => $self->get_mode,
+                     oc      => $self->get_oc->get_name,
+                     cat     => $self->get_cat->get_uri,
+                     elem    => ref $element ? $element->get_name : $element,
+                     (ref($element) ? (element => $element) : ())
+      if $@;
+    return $output;
+}
+
+##############################################################################
+
+=item @category_template_paths = $self->_find_category_scripts
+
+This method is called by C<_write_pages()> fo find all of the category
+templates that need executing. The templates are returned as a list of array
+refereneces. Each array reference contains two items: The full path to the
+script without the file type extension and a string indicating the template
+type, either "pl" or "tmpl". The order of the list is defined by the order of
+execution. For example, if a story was being published in the
+F</reviews/books> category, and the category templates F</category.pl> and
+F</reviews/category.tmpl> exist, then the return value will be
+
+  (
+    ['/reviews/category', 'tmpl'],
+    ['/category', 'pl'],
+  )
+
+The upshot being that F</reviews/category.tmpl> should be executed first (by
+calling C<new_template()>) and that F</category.pl> should be executed second
+(by calling C<run_script()>).
+
+=cut
+
+sub _find_category_scripts {
+    my $self = shift;
+
+    # Search up category hierarchy for category templates.
+    my $template_roots = $self->_get('_template_roots');
+    my @cats =  map { $_->get_uri } $self->get_cat->ancestry;
+    my @cat_tmpls;
+
+    CATEGORY:
+    for my $cat (@cats) {
+        ROOT:
+        for my $troot (@$template_roots) {
+            my $path = $fs->cat_dir($troot, $cat, 'category');
+            if (-e "$path.pl") {
+                unshift @cat_tmpls, [$path, 'pl'];
+                next CATEGORY;
+            }
+            next ROOT unless -e "$path.tmpl";
+            unshift @cat_tmpls, [$path, "tmpl"];
+        }
+    }
+
+    return @cat_tmpls;
+}
 
 
 #--------------------------------------#
