@@ -3,7 +3,7 @@ package Bric::Util::Burner::TemplateToolkit;
 
 =head1 NAME
 
-Bric::Util::Burner::TemplateToolkit - Bric::Util::Burner subclass to publish business assets using TemplateToolkit formatting assets.
+Bric::Util::Burner::TemplateToolkit - Publish stories using Template Toolkit templates
 
 =head1 VERSION
 
@@ -15,22 +15,21 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
+$LastChangedDate: 2006-01-17 16:09:49 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
  use Bric::Util::Burner::TemplateToolkit;
 
- # Create a new TemplateToolkit burner using the settings from $burner
- $tt_burner = Bric::Util::Burner::TemplateToolkit->new($burner);
+  # Create a new TemplateToolkit burner using the settings from $burner
+  my $tt_burner = Bric::Util::Burner::TemplateToolkit->new($burner);
 
- # Burn an asset, get back a list of resources
- @resources = $tt_burner->burn_one($ba, $oc, $cat, $at);
+  # Burn an asset, get back a list of resources
+  my $resources = $tt_burner->burn_one($ba, $oc, $cat, $at);
 
 =head1 DESCRIPTION
 
-This module handles burning business assets using TemplateToolkit formatting
-assets.
+This module handles burning business assets using TemplateToolkit templates.
 
 =cut
 
@@ -49,9 +48,9 @@ use strict;
 use Template 2.14;
 use Bric::Util::Fault qw(throw_gen throw_burn_error);
 use Bric::Util::Trans::FS;
-use Bric::Dist::Resource;
 use Bric::Config qw(:burn :l10n);
 use Template::Constants qw( :debug );
+use List::Util qw(first);
 
 #==============================================================================#
 # Inheritance                          #
@@ -63,7 +62,6 @@ use base qw(Bric::Util::Burner);
 #======================================#
 
 
-
 #==============================================================================#
 # Constants                            #
 #======================================#
@@ -79,37 +77,53 @@ use base qw(Bric::Util::Burner);
 #--------------------------------------#
 # Private Class Fields
 my $fs = Bric::Util::Trans::FS->new;
+my %vars;
+do {
+    no strict 'refs';
+    while ( my ($k, $v) = each %{TEMPLATE_BURN_PKG . '::'} ) {
+        if (my $type = first { defined *{$v}{$_} }
+            qw(CODE HASH ARRAY IO GLOB FORMAT)
+        ) {
+            # Use the reference to the variable. IOs can be used directly.
+            $vars{$k} = *{$v}{$type};
+        } else {
+            # Dereference any scalar value. SCALAR is always true, so we
+            # evaluate it last (with the "if" in for future-proofing).
+            # See _Programming Perl 3ed_ p 250.
+            $vars{$k} = ${*{$v}{SCALAR}} if *{$v}{SCALAR};
+        };
+    }
+};
 
 #--------------------------------------#
 # Instance Fields
 
 BEGIN {
     Bric::register_fields({
-                         #- Per burn/deploy values.
-                         'job'            => Bric::FIELD_READ,
-                         'more_pages'     => Bric::FIELD_READ,
+        #- Per burn/deploy values.
+        job        => Bric::FIELD_READ,
+        more_pages => Bric::FIELD_READ,
 
-                         # Private Fields
-                         '_tt'             => Bric::FIELD_NONE,
-                         '_comp_root'      => Bric::FIELD_NONE,
-                         '_buf'            => Bric::FIELD_NONE,
-                         '_writer'         => Bric::FIELD_NONE,
-                         '_elem'           => Bric::FIELD_NONE,
-                         '_at'             => Bric::FIELD_NONE,
-                         '_files'          => Bric::FIELD_NONE,
-                         '_res'            => Bric::FIELD_NONE,
-                         '_page_place'     => Bric::FIELD_NONE,
-                        });
+        # Private Fields
+        _tt         => Bric::FIELD_NONE,
+        _comp_root  => Bric::FIELD_NONE,
+        _buf        => Bric::FIELD_NONE,
+        _writer     => Bric::FIELD_NONE,
+        _elem       => Bric::FIELD_NONE,
+        _at         => Bric::FIELD_NONE,
+        _files      => Bric::FIELD_NONE,
+        _page_place => Bric::FIELD_NONE,
+    });
 }
 
-__PACKAGE__->_register_burner( Bric::Biz::AssetType::BURNER_TT,
-                               category_fn    => 'wrapper',
-                               cat_fn_has_ext => 1,
-                               exts           =>
-                                 { tt   => 'Template Toolkit (.tt)',
-                                 }
-                             );
-
+__PACKAGE__->_register_burner(
+    Bric::Biz::OutputChannel::BURNER_TT,
+    category_fn    => 'wrapper',
+    cat_fn_has_ext => 1,
+    exts           => {
+        tt   => 'Template Toolkit (.tt)',
+    }
+);
 
 #==============================================================================#
 
@@ -138,8 +152,6 @@ sub new {
     my ($class, $burner) = @_;
     my $init = { %$burner };
 
-    $init->{_res}     ||= [];
-
     # create the object using Bric's constructor and return it
     return $class->Bric::new($init);
 }
@@ -156,10 +168,10 @@ sub new {
 
 #------------------------------------------------------------------------------#
 
-=item @resources = $b->burn_one($ba, $oc, $cat, $at);
+=item $resources = $b->burn_one($ba, $oc, $cat, $at);
 
-Burn an asset in a given output channel and category, this is usually called by
-the preview or publish method. Returns a list of resources burned. 
+Burn an asset in a given output channel and category, this is usually called
+by the preview or publish method. Returns a list of resources burned.
 
 Parameters are:
 
@@ -179,8 +191,8 @@ A category in which to burn the asset.
 
 =item C<$at>
 
-A asset type object for $ba.
-Note that this is not currently used by the TT burner
+A asset type object for $ba. Note that this is not currently used by the TT
+burner
 
 =back
 
@@ -188,9 +200,9 @@ Note that this is not currently used by the TT burner
 
 sub burn_one {
     my $self = shift;
-    my ($story, $oc, $cat, $at) = @_;
+    my ($story, $oc, $cat) = @_;
 
-    my $element = $story->get_tile();
+    my $element = $story->get_element();
 
     my($ba);  #gone
     my ($outbuf, $retval);
@@ -207,109 +219,91 @@ sub burn_one {
         push @$template_roots, $fs->cat_dir($comp_dir, $inc_dir);
     }
 
-    # Save an existing TemplateToolkit request object and Bricolage objects.
-    my (%bric_objs);
-
     my @wrappers;
+    my @cats = map { $_->get_uri } $self->get_cat->ancestry;
 
-    {
-	# search up category hierarchy for wrappers
-	my @cats = map { $_->get_directory } $self->get_cat->ancestry;
-
-	do {
-	    # if the file exists, return it
-	    foreach my $troot (@$template_roots) {
-		my $path = $fs->cat_dir($troot, @cats, 'wrapper.tt');
-		if(-e $path) {
-		    push @wrappers, $path;
-		    last;
-		}
-	    }
-	} while(pop(@cats));
-	@wrappers = reverse @wrappers;
+    # Search up category hierarchy for wrappers.
+    CATEGORY:
+    for my $cat (@cats) {
+        ROOT:
+        for my $troot (@$template_roots) {
+            my $path = $fs->cat_dir($troot, $cat, 'wrapper.tt');
+            if (-e $path) {
+                push @wrappers, $path;
+                next CATEGORY;
+            }
+        }
     }
 
+    @vars{qw(burner story element)} = ($self, $story, $element);
     my $tt = Template->new({
-	#questionable layout things, but we got the time to sort it out
-	PRE_CHOMP  => 1,
-	POST_CHOMP => 1,
-	TRIM       => 1,
-
-	# now for the real stuff
-	OUTPUT       => \$outbuf,
-	INCLUDE_PATH => $template_roots,
-	WRAPPER      => \@wrappers,
-	EVAL_PERL    => 1,
-	ABSOLUTE     => 1,
-	VARIABLES    => {
-	    burner  => $self,
-	    story   => $story,
-	    element => $element,
-	},
+        TT_OPTIONS   => 1,
+        COMPILE_EXT  => 'ttc',
+        RECURSION    => 1,
+        OUTPUT       => \$outbuf,
+        INCLUDE_PATH => $template_roots,
+        WRAPPER      => \@wrappers,
+        EVAL_PERL    => 1,
+        ABSOLUTE     => 1,
+        VARIABLES    => \%vars,
     });
 
-
+    # Find the template.
     my $template;
-    {
-	my @cats = map { $_->get_directory } $self->get_cat->ancestry;
-	my $tmpl_name = $element->get_key_name . '.tt';
-        do {
-	    foreach my $troot (@$template_roots) {
-		my $path = $fs->cat_dir($troot, @cats, $tmpl_name);
-		if(-e $path) {
-		    $template = $path;
-		    goto LABEL;
-		}
-	    }
-	} while(pop(@cats));
-      LABEL:
+    my $tmpl_name = $element->get_key_name . '.tt';
+    CATEGORY:
+    for my $cat (@cats) {
+        ROOT:
+        foreach my $troot (@$template_roots) {
+            $template = $fs->cat_dir($troot, $cat, $tmpl_name);
+            last CATEGORY if -e $template;
+        }
     }
 
     $self->_set([qw(_buf      page story   element   _comp_root       _tt)],
-		[   \$outbuf, 0,   $story, $element, $template_roots, $tt]);
+                [   \$outbuf, 0,   $story, $element, $template_roots, $tt]);
 
     $self->_push_element($element);
 
     while(1) {
         use utf8;
-	$tt->process($template, ( ENCODE_OK
-                                  ? (undef, undef, binmode => ':utf8')
-                                  : ()
-                                 ))
-          or throw_burn_error
-          error   => "Error executing '$template'",
-          payload => $tt->error,
-          mode    => $self->get_mode,
-          oc      => $self->get_oc->get_name,
-          cat     => $self->get_cat->get_uri,
-          elem    => $element->get_name;
+        $tt->process($template, (
+            ENCODE_OK
+              ? (undef, undef, binmode => ':utf8')
+              : ()
+          )) or throw_burn_error
+            error   => "Error executing '$template'",
+            payload => $tt->error,
+            mode    => $self->get_mode,
+            oc      => $self->get_oc->get_name,
+            cat     => $self->get_cat->get_uri,
+            elem    => $element->get_name,
+            element => $element;
 
-	my $page = $self->_get('page') + 1;
+        my $page = $self->_get('page') + 1;
 
-	if($outbuf !~ /^\s*$/) {
-	    my $file = $self->page_filepath($page);
-	    my $uri  = $self->page_uri($page);
+        if ($outbuf !~ /^\s*$/) {
+            my $file = $self->page_filepath($page);
+            my $uri  = $self->page_uri($page);
 
-	    # Save the page we've created so far.
-	    open(OUT, ">$file")
-              or throw_gen error => "Unable to open '$file' for writing",
+            # Save the page we've created so far.
+            open(OUT, ">$file")
+              or throw_gen error   => "Unable to open '$file' for writing",
                            payload => $!;
             binmode(OUT, ':' . $self->get_encoding || 'utf8') if ENCODE_OK;
-	    print OUT $outbuf;
-	    close(OUT);
-	    $outbuf = '';
-	    # Add a resource to the job object.
-	    $self->_add_resource($file, $uri);
-	}
-	$self->_set([qw(page)],[$page]);
-	last unless $self->_get('more_pages');
+            print OUT $outbuf;
+            close(OUT);
+            $outbuf = '';
+            # Add a resource to the job object.
+            $self->add_resource($file, $uri);
+        }
+        $self->_set([qw(page)],[$page]);
+        last unless $self->_get('more_pages');
     }
     $self->_pop_element;
 
-    $self->_set(['_tt','_comp_root'],[undef,undef]);
-    my $ret = $self->_get('_res') || return;
-    $self->_set(['_res', 'page'], [[], 0]);
-    return wantarray ? @$ret : $ret;
+    $self->_set([qw(_tt _comp_root page)] => [undef, undef, 0]);
+    return $self->get_resources;
 }
 
 ################################################################################
@@ -370,12 +364,12 @@ sub find_template {
     my @cats = $fs->split_uri($uri);
     my $root = $self->_get('_comp_root');
     do {
-	# if the file exists, return it
-	foreach my $troot (@$root) {
-	    my $path = $fs->cat_dir($troot, @cats, $name);
-	    return $path if -e $path;
-	}
-    } while(pop(@cats));
+        # if the file exists, return it
+        foreach my $troot (@$root) {
+            my $path = $fs->cat_dir($troot, @cats, $name);
+            return $path if -e $path;
+        }
+    } while ( pop @cats );
     return;
 }
 
@@ -446,67 +440,15 @@ sub find_first_template {
 
 #------------------------------------------------------------------------------#
 
-=item $success = $b->display_pages($paginated_element_name)
+=item $content = $b->display_element($element)
 
-=item $success = $b->display_pages($paginated_element_name, %ARGS)
+=item $content = $b->display_element($element, %ARGS)
 
-=item $success = $b->display_pages(\@paginated_element_names, %ARGS)
-
-A method to be called from template space. Use this method to display
-paginated elements. If this method is used, the burn system will run once for
-every page element listed in C<\@paginated_element_names> (or just
-C<$paginated_element_name>) in the story; this is so that autohandlers will be
-called when appropriate. All arguments after the first argument will be passed
-to the template executed as its C<%ARGS> hash.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
-sub display_pages {
-    my $self = shift;
-    my $names = shift;
-    $names = [$names] unless ref $names;
-
-    # Get the current element
-    my $elem = $self->_current_element;
-    my $page_place = $self->_get('_page_place') || 0;
-
-    my ($next_page, $page_elem);
-    my $tiles = $elem->get_tiles;
-    foreach my $place ($page_place..$#$tiles) {
-        my $e = $tiles->[$place];
-        next unless $e->is_container;
-        foreach my $name (@$names) {
-            next unless $e->has_name($name);
-            $page_elem ? $next_page = 1 : $page_elem = $e;
-            next unless $next_page;
-            last;
-        }
-    }
-
-    # Set the 'more_pages' and '_page_place' properties.
-    $self->_set([ qw(more_pages _page_place) ],
-                [ $next_page,
-                  $page_elem ? $page_elem->get_place + 1 : $page_place + 1 ]);
-
-    $self->display_element($page_elem, @_);
-}
-
-#------------------------------------------------------------------------------#
-
-=item $success = $b->display_element($element)
-
-=item $success = $b->display_element($element, %ARGS)
-
-A method to be called from template space. This method will find the mason
-element associated with the element passed in and call C<< $m->comp >>. All
-arguments after the first argument will be passed to the template executed as
-its C<%ARGS> hash.
+A method to be called from template space. This method will find the template
+associated with the element passed in and call include it in the Template
+Toolkit execution. The return value is the content to be output. Pass in a
+list of arguments to have them set up variables in the stash of the element's
+execution context.
 
 B<Throws:> NONE.
 
@@ -518,31 +460,23 @@ B<Notes:> NONE.
 
 sub display_element {
     my $self = shift;
-    my $elem = shift or return;
-    my $buf = $self->_get('_buf');
+    my $elem = shift or return '';
+    return $elem->get_value unless $elem->is_container;
+
     my $data = '';
-    # Call another element if this is a container otherwise output the data.
+    my $tt = $self->_get('_tt');
 
-    if ($elem->is_container) {
-        my $tt = $self->_get('_tt');
+    # Push this element on to the stack
+    $self->_push_element($elem);
 
-        # Set the elem global to the current element.
-        # Push this element on to the stack
-        $self->_push_element($elem);
+    my $template = $self->_load_template_element($elem);
+    $data .= $tt->context->include($template, {
+        element => $elem,
+        @_
+    });
 
-        my $template = $self->_load_template_element($elem);
-	$data .= $tt->context->include($template, {
-	    'element' => $elem,
-	});
-
-        # Pop the element back off again.
-        $self->_pop_element();
-
-        # Set the elem global to the previous element
-
-    } else {
-	$data .= $elem->get_data();
-    }
+    # Pop the element back off again.
+    $self->_pop_element;
     return $data;
 }
 
@@ -579,43 +513,10 @@ NONE.
 
 =over 4
 
-=item $success = $b->_add_resource();
-
-Adds a Bric::Dist::Resource object to this burn.
-
-B<Throws:> NONE.
-
-B<Side Effects:> NONE.
-
-B<Notes:> NONE.
-
-=cut
-
-sub _add_resource {
-    my $self = shift;
-    my ($file, $uri) = @_;
-    my ($story, $ext) = $self->_get(qw(story output_ext));
-
-    # Create a resource for the distribution stuff.
-    my $res = Bric::Dist::Resource->lookup({ path => $file }) ||
-      Bric::Dist::Resource->new({ path => $file,
-                                  uri  => $uri });
-
-    # Set the media type.
-    $res->set_media_type(Bric::Util::MediaType->get_name_by_ext($ext));
-    # Add our story ID.
-    $res->add_story_ids($story->get_id);
-    $res->save;
-    my $ress = $self->_get('_res');
-    push @$ress, $res;
-}
-
-#------------------------------------------------------------------------------#
-
 =item $template = $b->_load_template_element($element);
 
-Given an element (a business asset/data tile) return the template element that
-formats it.
+Given an element (a business asset/data element) return the template element
+that formats it.
 
 B<Throws:> NONE.
 
@@ -638,7 +539,8 @@ sub _load_template_element {
                           mode  => $self->get_mode,
                           oc    => $self->get_oc->get_name,
                           cat   => $self->get_cat->get_uri,
-                          elem  => $element->get_name;
+                          elem  => $element->get_name,
+                          element => $element;
     return $tmpl;
 }
 
@@ -698,7 +600,7 @@ sub _push_element {
     my ($elem_stack, $at_stack) = $self->_get('_elem', '_at');
 
     push @$elem_stack, $element;
-    push @$at_stack, $element->get_element;
+    push @$at_stack, $element->get_element_type;
 
     $self->_set(['_elem', '_at'], [$elem_stack, $at_stack]);
 }
@@ -731,11 +633,9 @@ NONE.
 
 =head1 AUTHOR
 
-Garth Webb L<gt>garth@perijove.comL<lt>
+Arther Bergman <sky@nanisky.com>
 
-Sam Tregar L<gt>stregar@about-inc.comL<lt>
-
-David Wheeler L<gt>david@wheeler.netL<lt>
+David Wheeler <david@kineticode.com>
 
 =head1 SEE ALSO
 
