@@ -19,7 +19,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-08-23 16:32:50 -0700 (Tue, 23 Aug 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,7 @@ use constant CONNECT_PASS => $ENV{BRIC_DBI_PASS} || DBI_PASS;
 DBI->trace(DBI_TRACE);
 
 # The strftime format for DB dates. Used by Bric::Util::Time::db_date().
-use constant DB_DATE_FORMAT => '%Y-%m-%d %T';
+use constant DB_DATE_FORMAT => Bric::Config::ISO_8601_FORMAT;
 
 # Package constant variables. This one is for the DB connection attributes.
 my $ATTR =  { RaiseError         => 1,
@@ -122,17 +122,17 @@ use base qw(Exporter);
 # You can explicitly import any of the functions in this class. The last two
 # should only ever be imported by Bric::Util::Time, however.
 our @EXPORT_OK = qw(prepare prepare_c prepare_ca execute fetch row_aref
-		    col_aref last_key next_key db_date_parts DB_DATE_FORMAT
-		    clean_params bind_columns bind_col bind_param begin commit
-		    rollback finish is_num row_array all_aref fetch_objects
-		    order_by group_by build_query build_simple_query
-                    where_clause tables ANY);
+		    col_aref last_key next_key db_date_parts db_datetime
+		    DB_DATE_FORMAT clean_params bind_columns bind_col
+		    bind_param begin commit rollback finish is_num row_array
+		    all_aref fetch_objects order_by group_by build_query
+		    build_simple_query where_clause tables ANY any_where);
 
 # But you'll generally just want to import a few standard ones or all of them
 # at once.
 our %EXPORT_TAGS = (standard => [qw(prepare_c row_aref fetch fetch_objects
                                     execute next_key last_key bind_columns
-                                    finish)],
+                                    finish any_where)],
 		    trans => [qw(begin commit rollback)],
                     junction => [qw(ANY)],
 		    all => \@EXPORT_OK);
@@ -737,7 +737,7 @@ sub fetch_objects {
         my $obj = bless {}, $pkg;
         # The group IDs are in the last four columns.
         $grp_ids = $d[-$grp_col_cnt] = [map { split } @d[-$grp_col_cnt..-1]];
-        $obj ->_set($fields, \@d);
+        $obj->_set($fields, \@d);
         $obj->_set__dirty(0);
         # Cache the object before reblessing it.
         $obj->cache_me;
@@ -841,7 +841,8 @@ sub clean_params {
     $param->{_no_return_versions} = 1
       unless $param->{return_versions}
       || defined $param->{version}
-      || $param->{published_version};
+      || $param->{published_version}
+      || $param->{version_id};
     # add default order
     $param->{Order} = $class->DEFAULT_ORDER unless $param->{Order};
     # support of NULL workflow__id
@@ -924,6 +925,50 @@ sub where_clause {
 
 ##############################################################################
 
+=item any_where
+
+  my $where = any_where($value, $where_expression, \@params);
+
+Examines $value to determine whether it is a single value or an C<ANY> value.
+If it is an C<ANY> value, then each of those value is pushed on to the end of
+the C<$params> array reference and the where expression is grouped together in
+parenetheses and C<OR>ed together the same number of times as there are
+values. Otherwise, a single value is pushed onto the C<$params> array
+reference and the where expression simply returned.
+
+For example, if called like so:
+
+  my @params;
+  my $where = any_where(ANY(1, 2, 3), "f.name = ?", \@params);
+
+Then C<@params> will contain C<(1, 2, 3)> and the string "(f.name = ? OR
+f.name = ? OR f.name = ?)" will be assigned to C<$where>.
+
+However, if the value is not an C<ANY> value:
+
+  my @params;
+  my $where = any_where(1, "f.name = ?", \@params);
+
+Then C<@params> will of course contain only C<(1)> and the string "f.name = ?"
+will be assigned to C<$where>.
+
+This function is useful in classes that wisht to add C<ANY> support to
+specific C<list()> method parameters.
+
+=cut
+
+sub any_where {
+    my ($value, $sql, $params) = @_;
+    if (UNIVERSAL::isa($value, 'Bric::Util::DBI::ANY')) {
+        push @$params, @$value;
+        return '(' . join(' OR ', ($sql) x @$value) . ')';
+    }
+    push @$params, $value;
+    return $sql;
+}
+
+##############################################################################
+
 =item my $order_by = order_by
 
 Builds up the ORDER BY clause.
@@ -932,6 +977,8 @@ B<Throws:>
 
 =over 4
 
+=item Bad Order parameter.
+
 =item OrderDirection parameter must either ASC or DESC.
 
 =back
@@ -954,21 +1001,26 @@ sub order_by {
     my $map = $pkg->PARAM_ORDER_MAP;
 
     # Make sure it's legit.
-    my $ord = $map->{$param->{Order}}
-      or throw_da "Bad Order parameter '$param->{Order}'";
+    my $ords = ref $param->{Order} ? $param->{Order} : [ $param->{Order} ];
+    my $dirs = ref $param->{OrderDirection} ? $param->{OrderDirection}
+                                            : [ $param->{OrderDirection} ]
+                                            ;
 
-    # Set up the order direction.
-    my $dir = 'ASC';
-    if ($param->{OrderDirection}) {
-        # Make sure it's legit.
-        throw_da 'OrderDirection parameter must either ASC or DESC.'
-          if $param->{OrderDirection} ne 'ASC'
-            and $param->{OrderDirection} ne 'DESC';
-        # Grab it.
-        $dir = $param->{OrderDirection};
+    # Assemble the order atttributes.
+    my @ord;
+    for my $i (0..$#$ords) {
+        my $attr = $map->{$ords->[$i]}
+            or throw_da "Bad Order parameter '$ords->[$i]'";
+        if (my $dir = $dirs->[$i]) {
+            throw_da 'OrderDirection parameter must either ASC or DESC.'
+                if $dir ne 'ASC' and $dir ne 'DESC';
+            $attr .= " $dir";
+        }
+        push @ord, $attr;
     }
+
     # Return the ORDER BY clause with the ID column.
-    return "ORDER BY $ord $dir, $id_col";
+    return 'ORDER BY ' . join(', ', @ord) . ", $id_col";
 }
 
 ##############################################################################
@@ -1873,7 +1925,7 @@ NONE.
 
 =head1 AUTHOR
 
-David E. Wheeler <david@wheeler.net>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
