@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-13 21:03:08 -0700 (Wed, 13 Jul 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -75,6 +75,7 @@ use Bric::Util::AlertType;
 #use Bric::Util::Grp::Event;
 use Bric::Biz::Person::User;
 use Bric::Util::Fault qw(throw_dp);
+use Scalar::Util qw(blessed);
 
 ##############################################################################
 # Inheritance
@@ -113,17 +114,21 @@ my @EPROPS = qw(id event_type_id user_id obj_id timestamp);
 my @ORD = qw(name key_name description trig_id trig class timestamp);
 my $METHS;
 
-my %NUM_MAP = (id            => 'e.id',
-               event_type_id => 't.id',
-               user_id       => 'e.usr__id',
-               obj_id        => 'e.obj_id',
-               class_id      => 't.class__id');
+my %NUM_MAP = (
+    id            => 'e.id',
+    event_type_id => 't.id',
+    user_id       => 'e.usr__id',
+    obj_id        => 'e.obj_id',
+    class_id      => 't.class__id'
+);
 
-my %TXT_MAP = (key_name      => 'LOWER(t.key_name)',
-               name          => 'LOWER(t.name)',
-               description   => 'LOWER(t.description)',
-               class         => 'LOWER(c.pkg_name)'
-              );
+my %TXT_MAP = (
+    key_name      => 't.key_name',
+    name          => 't.name',
+    description   => 't.description',
+    class         => 'c.pkg_name',
+    value         => 'ea.value',
+);
 
 ##############################################################################
 # Instance Fields
@@ -282,8 +287,9 @@ sub new {
     unless ($et) {
         if (defined $init->{et_id}) {
             $et = Bric::Util::EventType->lookup({ id => $init->{et_id} });
-        } elsif ($init->{key_name}) {
-            $et = Bric::Util::EventType->lookup({ key_name => $init->{key_name} });
+        } elsif (my $kn = $init->{key_name}) {
+            $et = Bric::Util::EventType->lookup({ key_name => $kn })
+                or throw_dp qq{No event type found for key_name "$kn"};
         } else {
             throw_dp(error => "No Bric::Util::EventType object, ID, or "
                      . "key_name passed to " .  __PACKAGE__ . '::new()');
@@ -402,41 +408,57 @@ lookup keys are:
 
 =over 4
 
-=item *
+=item id
 
-event_type_id
+Event ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item event_type_id
 
-user_id
+Event type ID. May use C<ANY> for a list of possible values.
 
-=item *
+=item user_id
 
-class_id
+User ID for user who may have triggered events. May use C<ANY> for a list of
+possible values.
 
-=item *
+=item class_id
 
-class
+ID of the class of object on which events have been logged. May use C<ANY> for
+a list of possible values.
 
-=item *
+=item class
 
-key_name
+The package name of a class, the objects of which may have had events logged
+against them. May use C<ANY> for a list of possible values.
 
-=item *
+=item key_name
 
-name
+Event type key name. May use C<ANY> for a list of possible values.
 
-=item *
+=item name
 
-description
+Event name. May use C<ANY> for a list of possible values.
 
-=item *
+=item description
 
-obj_id
+Event description. May use C<ANY> for a list of possible values.
 
-=item *
+=item obj_id
 
-timestamp
+ID of a Bricolage object for which events may have been logged. May use C<ANY>
+for a list of possible values.
+
+=item timestamp
+
+Time at which events have been logged.If passed as a scalar, events that
+occurred at that exact time will be returned. If passed as an anonymous array,
+the first two values will be assumed to represent a range of dates between
+which to retrieve Bric::Util::Event objects. May also use C<ANY> for a list of
+possible values.
+
+=item value
+
+The value of an event attribute. May use C<ANY> for a list of possible values.
 
 =begin comment
 
@@ -446,13 +468,27 @@ grp_id
 
 =end comment
 
-=back
+=item Order
 
-If timestamp is passed as a scalar, events that occurred at that exact time
-will be returned. If it is passed as an anonymous hash, the first two values
-will be assumed to represent a range of dates between which to retrieve
-Bric::Util::Event objects. Any combination of the above keys may be used,
-although the most common may be a combination of class_id and obj_id.
+An attribute name to order by.
+
+=item OrderDirection
+
+The direction in which to order the records, either "ASC" for ascending (the
+default) or "DESC" for descending. This value is applied to the property
+specified by the C<Order> parameter. Defaults to ascending.
+
+=item Limit
+
+A maximum number of objects to return. If not specified, all objects that
+match the query will be returned.
+
+=item Offset
+
+The number of objects to skip before listing the remaining objcts or the
+number of objects specified by C<Limit>.
+
+=back
 
 B<Throws:>
 
@@ -1366,46 +1402,79 @@ $get_em = sub {
     my $wheres = 'e.event_type__id = t.id AND t.class__id = c.id'; # .
 #      ' AND e.id = em.object_id AND m.id = em.member__id';
     my @params;
+
+    # Handle query metadata.
+    my $order_by = 'e.timestamp DESC, e.id DESC';
+    if (my $ord = delete $params->{Order}) {
+        $order_by = $ord eq 'timestamp' ? 'e.timestamp'
+                                        : $TXT_MAP{$ord} || $NUM_MAP{$ord}
+                                        ;
+        $order_by .= ' ' . delete $params->{OrderDirection}
+            if $params->{OrderDirection};
+    }
+
+    my $limit     = exists $params->{Limit}
+        ? 'LIMIT ' . delete $params->{Limit}
+        : ''
+        ;
+    my $offset    = exists $params->{Offset}
+        ? 'OFFSET ' . delete $params->{Offset}
+        : ''
+        ;
+
     while (my ($k, $v) = each %$params) {
         if ($k eq 'timestamp') {
             # It's a date column.
-            if (ref $v) {
+            if (blessed $v) {
+                # It's an ANY value.
+                db_date($_) for @$v;
+                $wheres .= ' AND ' . any_where $v, "e.$k = ?", \@params;
+            }
+            elsif (ref $v && !blessed $v) {
                 # It's an arrayref of dates.
                 $wheres .= " AND e.$k BETWEEN ? AND ?";
                 push @params, (db_date($v->[0]), db_date($v->[1]));
-            } else {
-                # It's a single value.
-                $wheres .= " AND e.$k = ?";
-                push @params, db_date($v);
             }
-        } elsif ($NUM_MAP{$k}) {
+            else {
+                # It's a single value.
+                $wheres .= ' AND ' . any_where $v, "e.$k = ?", \@params;
+            }
+        }
+
+        elsif ($NUM_MAP{$k}) {
             # It's a numeric column.
-            $wheres .= " AND $NUM_MAP{$k} = ?";
-            push @params, $v;
-        } elsif ($TXT_MAP{$k}) {
+            $wheres .= ' AND ' . any_where $v, "$NUM_MAP{$k} = ?", \@params;
+        }
+
+        elsif ($TXT_MAP{$k}) {
             # It's a text-based column.
-            $wheres .= " AND $TXT_MAP{$k} LIKE ?";
-            push @params, lc $v;
-#        } elsif ($k eq 'grp_id') {
+            $wheres .= ' AND '
+                . any_where $v, "LOWER($TXT_MAP{$k}) LIKE LOWER(?)", \@params;
+        }
+
+# elsif ($k eq 'grp_id') {
 #            # Add in the group tables a second time and join to them.
-#            $tables .= ", member m2, event_member em2";
-#            $wheres .= " AND e.id = em2.object_id AND em2.member__id = m2.id" .
-#              " AND m2.grp__id = ?";
-#            push @params, $v;
-        } else {
+#            $tables .= ', member m2, event_member em2';
+#            $wheres .= ' AND e.id = em2.object_id AND em2.member__id = m2.id'
+#                . ' AND ' any_where $v, 'm2.grp__id = ?', \@params;
+#        }
+
+        else {
             # We're horked.
             throw_dp(error => "Invalid property '$k'.");
         }
     }
 
-    my ($qry_cols, $order) = $ids ? (\'DISTINCT e.id', 'e.id') :
-      (\$SEL_COLS, 'e.timestamp DESC, e.id DESC');
+    my ($qry_cols, $order) = $ids ? (\'DISTINCT e.id', 'e.id')
+                                  : (\$SEL_COLS, $order_by)
+                                  ;
 
     my $sel = prepare_c(qq{
         SELECT $$qry_cols
         FROM   $tables
         WHERE  $wheres
         ORDER BY $order
+        $limit $offset;
     }, undef);
 
     # Just return the IDs, if they're what's wanted.
@@ -1644,7 +1713,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
