@@ -18,7 +18,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-11-18 14:43:03 -0800 (Thu, 18 Nov 2004) $
+$LastChangedDate: 2006-06-13 16:06:11 -0700 (Tue, 13 Jun 2006) $
 
 =head1 DESCRIPTION
 
@@ -47,14 +47,11 @@ use strict;
 use Bric::Util::DBI qw(:all);
 use Bric::Biz::Category;
 use Bric::Biz::OutputChannel;
-use Bric::Biz::Asset::Formatting;
+use Bric::Biz::Asset::Template;
 use Bric::Config qw(:ftp);
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 use Net::FTPServer::DirHandle;
 use Bric::Util::Burner::Mason;
-require Bric::Util::Burner::Template if eval { require HTML::Template };
-require Bric::Util::Burner::TemplateToolkit
-  if eval { require Template && $Template::VERSION >= 2.14 };
 use Bric::Util::FTP::FileHandle;
 use Bric::Util::Priv::Parts::Const qw(:all);
 use File::Basename qw(fileparse);
@@ -126,7 +123,7 @@ sub get {
   my $deploy = $filename =~ s/\.deploy$//i;
 
   # look for a template by that name
-  my $list = Bric::Biz::Asset::Formatting->list({
+  my $list = Bric::Biz::Asset::Template->list({
       site_id            => $site_id,
       output_channel__id => $oc_id,
       category_id        => $category_id,
@@ -243,7 +240,7 @@ sub open {
     my $deploy = $filename =~ s/\.deploy$//i;
 
     # find filename
-    my $list = Bric::Biz::Asset::Formatting->list({
+    my $list = Bric::Biz::Asset::Template->list({
         site_id            => $site_id,
         output_channel__id => $oc_id,
         category_id        => $category_id,
@@ -283,26 +280,26 @@ sub open {
     my $start_desk = $wf->get_start_desk;
     my $gid = $start_desk->get_asset_grp;
     return undef
-      unless $self->{ftps}{user_obj}->can_do('Bric::Biz::Asset::Formatting',
+      unless $self->{ftps}{user_obj}->can_do('Bric::Biz::Asset::Template',
                                              CREATE, 0, $gid);
     # create the new template
     my ($name, $dir, $file_type) = fileparse($filename, qr/\..*$/);
     # Remove the dot.
     $file_type =~ s/^\.//;
-    my $tplate_type = Bric::Biz::Asset::Formatting::UTILITY_TEMPLATE;
+    my $tplate_type = Bric::Biz::Asset::Template::UTILITY_TEMPLATE;
 
     # don't look for an element for category templates
     my $at;
     if ( Bric::Util::Burner->class_for_cat_fn($name)) {
         # It's a category template.
-        $tplate_type = Bric::Biz::Asset::Formatting::CATEGORY_TEMPLATE;
+        $tplate_type = Bric::Biz::Asset::Template::CATEGORY_TEMPLATE;
         print STDERR __PACKAGE__, "::open($filename, $mode): will create a "
           . "category template\n" if FTP_DEBUG;
     } else {
         # Look for an element to associate it with.
-        if ($at = Bric::Biz::AssetType->lookup({ key_name => $name })) {
+        if ($at = Bric::Biz::ElementType->lookup({ key_name => $name })) {
             # It's an element template!
-            $tplate_type = Bric::Biz::Asset::Formatting::ELEMENT_TEMPLATE;
+            $tplate_type = Bric::Biz::Asset::Template::ELEMENT_TEMPLATE;
             print STDERR __PACKAGE__, "::open($filename, $mode): creating for",
               " asset type: ", $at->get_name, "\n" if FTP_DEBUG;
         } else {
@@ -313,7 +310,7 @@ sub open {
     }
 
     ## create the new template object
-    my $template = Bric::Biz::Asset::Formatting->new({
+    my $template = Bric::Biz::Asset::Template->new({
         'element'            => $at,
         'site_id'            => $site_id,
         'file_type'          => $file_type,
@@ -446,14 +443,14 @@ sub list {
   # get templates
   my $list;
   if ($like) {
-      $list = Bric::Biz::Asset::Formatting->list({
+      $list = Bric::Biz::Asset::Template->list({
           site_id            => $site_id,
           output_channel__id => $oc_id,
           category_id        => $category_id,
           file_name          => "%/" . ($like || '%')
       });
   } else {
-      $list = Bric::Biz::Asset::Formatting->list({ 
+      $list = Bric::Biz::Asset::Template->list({ 
           site_id            => $site_id,
           output_channel__id => $oc_id,
           category_id        => $category_id,
