@@ -17,7 +17,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-08-12 17:13:34 -0700 (Thu, 12 Aug 2004) $
+$LastChangedDate: 2004-11-08 19:32:57 -0800 (Mon, 08 Nov 2004) $
 
 =head1 SYNOPSIS
 
@@ -1350,7 +1350,7 @@ sub _do_joined_select {
         push @bind,  $object_class_id;
     }
     unless ($all) {
-        push @param, ' m.active=1 ';
+        push @param, " m.active = '1' ";
     }
     push @param, ' m.id=o.member__id ';
     $sql .= ' WHERE ' . join ( ' AND ', @param );
