@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-03-06 13:21:39 -0800 (Sun, 06 Mar 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -671,7 +671,7 @@ sub _do_list {
         FROM   member m, person_member pm, person p, grp g
         WHERE  m.id = pm.member__id
                AND m.grp__id = g.id
-               AND g.active = 1
+               AND g.active = '1'
                AND pm.object_id = p.id$where
         ORDER BY p.lname, p.fname, p.mname
     }, undef);
@@ -710,7 +710,7 @@ NONE.
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
