@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
+$LastChangedDate: 2006-06-13 16:06:11 -0700 (Tue, 13 Jun 2006) $
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,7 @@ our %Lexicon = (
   'Current Version' => 'Aktuelle Version',
   'Currently Related Story' => 'Aktuell Verwandter Beitrag',
   'DISTRIBUTION' => 'VERTEILUNG',
-  'Data Elements' => ' Datenelemente',
+  'Field Elements' => ' Datenelemente',
   'Default Value' => 'Ausgangswert',
   'Deployed Date' => 'Datum der Ausbringung',
   'Description' => 'Beschreibung',
@@ -441,7 +441,7 @@ our %Lexicon = (
   'Alias in Category' => 'Alias in Kategorie',
   'Alias to "[_1]" created and saved.' => 'Alias auf "[_1]" erstellt und gespeichert.',
   'All Types' => 'Alle Typen',
-  'An "[_1]" attribute already exists. Please try another name.' => 'Ein Attribut "[_1]" existiert bereits. Bitte versuchen Sie einen anderen Namen.',
+  'The "[_1]"field type already exists. Please try another key name.' => 'Ein Attribut "[_1]" existiert bereits. Bitte versuchen Sie einen anderen Namen.',
   'An active template already exists for the selected output channel, category, element and burner you selected.  You must delete the existing template before you can add a new one.' => 'Für die gewählte Kombination von Ausgabekanal, Kategorie, Element und Burner existiert bereits eine aktive Vorlage. Sie müssen die existierende Vorlage löschen bevor Sie eine neue hinzufügen können.',
   'An error occurred while processing your request:' => 'Beim bearbeiten Ihrer Anfrage ist ein Fehler aufgetreten:',
   'An error occurred.' => 'Es ist ein Fehler aufgetreten.',
@@ -533,7 +533,7 @@ our %Lexicon = (
   'Media "[_1]" check out canceled.' => 'Checkout des Mediums "[_1]" abgebrochen.',
   'Media "[_1]" created and saved.' => 'Medium "[_1]" erzeugt und gespeichert.',
   'Media "[_1]" deleted.' => 'Medium "[_1]" gelöscht.',
-  'Media "[_1]" published.' => 'Medium "[_1]" veröffentlicht.',
+  'Media "[_1]" published to [_2].' => 'Medium "[_1]" veröffentlicht auf [_2].',
   'Media "[_1]" reverted to V.[_2]' => 'Medium "[_1]" auf Version "[_2]" zurückgefallen',
   'Media "[_1]" saved and checked in to "[_2]".' => 'Medium "[_1]" gespeichert und nach "[_2]" eingecheckt.',
   'Media "[_1]" saved and moved to "[_2]".' => 'Medium "[_1]" gespeichert und nach "[_2]" verschoben.',
@@ -578,7 +578,7 @@ our %Lexicon = (
   'No users were found' => 'Keine Benutzer gefunden',
   'No workflows were found' => 'Keine Workflows gefunden',
   'Note: Container element "[_1]" removed in bulk edit but will not be deleted.' => 'Achtung: Containerelement "[_1]" im Blockeditor entfernt, wird aber nicht gelöscht.',
-  'Note: Data element "[_1]" is required and cannot be completely removed.  Will delete all but one.' => 'Achtung: Datenelement "[_1]" wird benötigt und kann nicht vollständig entfernt werden. Lösche alle bis auf eines.',
+  'Note: Field element "[_1]" is required and cannot be completely removed.  Will delete all but one.' => 'Achtung: Datenelement "[_1]" wird benötigt und kann nicht vollständig entfernt werden. Lösche alle bis auf eines.',
   'Object Groups' => 'Objektgruppen',
   'Object Group Permissions' => 'Objektgruppenrechte',
   'Or Pick a Type' => 'Oder wählen Sie einen Typ',
@@ -632,7 +632,7 @@ our %Lexicon = (
   'Story "[_1]" check out canceled.' => 'Checkout des Beitrags "[_1]" abgebrochen.',
   'Story "[_1]" created and saved.' => 'Beitrag "[_1]" erstellt und gesichert.',
   'Story "[_1]" deleted.' => 'Beitrag "[_1]" gelöscht.',
-  'Story "[_1]" published.' => 'Beitrag "[_1]" veröffentlicht.',
+  'Story "[_1]" published to [_2].' => 'Beitrag "[_1]" veröffentlicht auf [_2].',
   'Story "[_1]" reverted to V.[_2].' => 'Beitrag "[_1]" auf Version [_2] zurückgefallen.',
   'Story "[_1]" saved and checked in to "[_2]".' => 'Beitrag "[_1]" gesichert und nach "[_2]" eingecheckt.',
   'Story "[_1]" saved and moved to "[_2]".' => 'Beitrag "[_1]" gesichert und nach "[_2]" verschoben.',
@@ -677,7 +677,7 @@ our %Lexicon = (
   'Warning! Bricolage is designed to run with JavaScript enabled.' => 'Warnung! Bricolage benötigt zum Betrieb aktiviertes JavaScript.',
   'Warning! State inconsistent: Please use the buttons provided by the application rather than the \'Back\'/\'Forward\' buttons.' => 'Warnung! Inkonsistenter Zustand: Bitte verwenden Sie die von der Applikation zur Verfügung gestellten Buttons anstelle der \'Back\'/\'Forward\' (\'Zurück\'/\'Vor\') Knöpfe des Browsers.',
   'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_container\'.  Please use the element\'s \'key_name\' field instead.' => 'Warnung: von der Verwendung des Feldes \'Name\' des Elementes mit der Methode \'get_container\' wird abgeraten. Verwenden Sie statt dessen bitte das Feld \'key_name\' des Elementes.',
-  'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_data\'.  Please use the element\'s \'key_name\' field instead.' => 'Warnung: von der Verwendung des Feldes \'Name\' des Elementes mit der Methode \'get_data\' wird abgeraten. Verwenden Sie statt dessen bitte das Feld \'key_name\' des Elementes.',
+  'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_value\'.  Please use the element\'s \'key_name\' field instead.' => 'Warnung: von der Verwendung des Feldes \'Name\' des Elementes mit der Methode \'get_value\' wird abgeraten. Verwenden Sie statt dessen bitte das Feld \'key_name\' des Elementes.',
   'Warning: object "[_1]" had no associated desk.  It has been assigned to the "[_2]" desk.' => 'Warnung: das Objekt "[_1]" ist mit keinem B&uuml;ro verknüpft. Es wurde dem B&uuml;ro "[_2]" zugeordnet.',
   'Warning: object "[_1]" had no associated workflow.  It has been assigned to the "[_2]" workflow.' => 'Warnung: das Objekt "[_1]" ist mit keinem Workflow verknüpft. Es wurde dem Workflow "[_2]" zugeordnet.',
   'Warning: object "[_1]" had no associated workflow.  It has been assigned to the "[_2]" workflow. This change also required that this object be moved to the "[_3]" desk.' => 'Warnung: das Objekt "[_1]" ist mit keinem Workflow verknüpft. Es wurde dem Workflow "[_2]" zugeordnet. Diese Änderung bedingt, daß das Objekt zusätzlich dem B&uuml;ro "[_3]" zugeordnet wird.',
@@ -720,9 +720,13 @@ To Translate:
   'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.' => 'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.'
   'You do not have permission to override user "[_1]"' => 'You do not have permission to override user "[_1]"',
   'Template "[_1]" deployed.' => 'Vorlage "[_1]" ausgebracht',
-  'Story "[_1]" scheduled for publication.' => 'Beitrag "[_1]" veröffentlicht.',
-  'Media "[_1]" scheduled for publication.' => 'Medium "[_1]" veröffentlicht.',
+  'Story "[_1]" scheduled for publication to [_2].' => 'Beitrag "[_1]" veröffentlicht [_2].',
+  'Media "[_1]" scheduled for publication to [_2].' => 'Medium "[_1]" veröffentlicht [_2].',
   'Not defined.' => 'Not defined.',
+  'Milliseconds' => 'Milliseconds',
+  'Microseconds' => 'Microseconds',
+  'Not defined.' => 'Not defined.',
+  "You do not have sufficient permission to create a media document for this site" => "You do not have sufficient permission to create a media document for this site"
   'The primary category cannot be deleted.' => 'The primary category cannot be deleted.',
   'Cannot make a dissociated category the primary category.' => 'Cannot make a dissociated category the primary category.'
   'Related [_1] "[_2]" is not activate. Please relate another [_1].' => 'Related [_1] "[_2]" is not activate. Please relate another [_1].'
@@ -732,8 +736,32 @@ To Translate:
   'You do not have permission to auto-publish story "[_1]"' => 'You do not have permission to auto-publish story "[_1]"',
   'You do not have permission to auto-publish media "[_1]"' => 'You do not have permission to auto-publish media "[_1]"',
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  'Include deleted' => 'Include deleted',
+  'Reactivate' => 'Reactivate',
+  'All Subelements' => 'All Subelements',
+      'Code' => 'Code',
+      'Code Select' => 'Code Select',
+      'Invalid codeselect code (didn't return an array ref of even size)' => 'Invalid codeselect code (didn't return an array ref of even size)',
+  'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.' => 'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.',
+  'Job "[_1]" has been reset.' => 'Job "[_1]" has been reset.',
   '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
   '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
+  'No context for content beginning at line [_1].' => 'No context for content beginning at line [_1].',
+  'No such field "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such field "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.' => 'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.',
+  'Unknown tag "[_1]" at line [_2].' => 'Unknown tag "[_1]" at line [_2].',
+  'No such site "[_1]" at line [_2].'=> 'No such site "[_1]" at line [_2].',
+  'No such URI "[_1]" in site "[_2]" at line [_3].' => 'No such URI "[_1]" in site "[_2]" at line [_3].',
+  'No story document found for UUID "[_1]" at line [_2].' => 'No story document found for UUID "[_1]" at line [_2].',
+  'No media document found for UUID "[_1]" at line [_2].' => 'No media document found for UUID "[_1]" at line [_2].',
+  'No story document found for ID "[_1]" at line [_2].' => 'No story document found for ID "[_1]" at line [_2].',
+  'No media document found for ID "[_1]" at line [_2].' => 'No media document found for ID "[_1]" at line [_2].',
+  'No story document found for URI "[_1]" at line [_2].' => 'No story document found for URI "[_1]" at line [_2].',
+  'No media document found for URI "[_1]" at line [_2].' => 'No media document found for URI "[_1]" at line [_2].',
+  'D (for Deployed)'  => 'D',
+  'P (for Published)' => 'P',
+
 
 =end comment
 
