@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
+$LastChangedDate: 2006-01-23 15:34:28 -0800 (Mon, 23 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ our %Lexicon = (
     'Check In' => 'Check In',
     'Recipients' => 'Destinatari',
     'Note saved.' => 'Nota salvata.',
-    'Data Elements' => 'Data Elements',
+    'Field Elements' => 'Field Elements',
     'View' => 'Vista',
     'Contributor Types' => 'Tipi di Collaboratori',
     'Media "[_1]" check out canceled.' => 'check out del Media "[_1]" cancellato.',
@@ -229,7 +229,7 @@ our %Lexicon = (
     'TEMPLATES FOUND' => 'TEMPLATE TROVATI',
     'Source profile "[_1]" saved.' => 'Source profile "[_1]" salvato.',
     'Media "[_1]" saved and moved to "[_2]".' => 'Media "[_1]" salvato e spostato in "[_2]".',
-    'An "[_1]" attribute already exists. Please try another name.' => 'L\'attributo "[_1]" esiste giÂ. Per favora prova con un altro nome.',
+    'The "[_1]" field type already exists. Please try another key name.' => 'L\'attributo "[_1]" esiste giÂ. Per favora prova con un altro nome.',
     'User profile "[_1]" deleted.' => 'Profilo Utente "[_1]" cancellato.',
     '[_1] Field Text' => '[_1] Campo di Testo',
     'Sources' => 'Fonti',
@@ -490,7 +490,7 @@ To translate:
   'No media file is associated with asset "[_1]", so none will be distributed.'
   'Cannot publish asset "[_1]" to "[_2]" because there are no Destinations associated with this output channel.'
   'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_container\'.  Please use the element\'s \'key_name\' field instead.'
-  'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_data\'.  Please use the element\'s \'key_name\' field instead.'
+  'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_value\'.  Please use the element\'s \'key_name\' field instead.'
   'You must be an administrator to use this function.'
   'Template deployed.'
   '[quant,_1,Template] deployed.'
@@ -499,7 +499,7 @@ To translate:
   'Cannot publish story "[_1]" because it is checked out.'
   'Bad element name "[_1]". Did you mean "[_2]"?'
   'Field "[_1]" appears more than once but it is not a repeatable element.  Please remove all but one.'
-  'Note: Data element "[_1]" is required and cannot be completely removed.  Will delete all but one.'
+  'Note: Field element "[_1]" is required and cannot be completely removed.  Will delete all but one.'
   'Note: Container element "[_1]" removed in bulk edit but will not be deleted.'
   'Cannot create an alias to a media in the same site.'
   'Cannot create an alias to a story in the same site.'
@@ -538,16 +538,43 @@ To translate:
   '[_1] Site Categories' => '[_1] Site Categories',
   'You do not have permission to override user "[_1]"' => 'You do not have permission to override user "[_1]"'
   'Not defined.' => 'Not defined.',
+  'Milliseconds' => 'Milliseconds',
+  'Microseconds' => 'Microseconds',
+  'Not defined.' => 'Not defined.',
+  "You do not have sufficient permission to create a media document for this site" => "You do not have sufficient permission to create a media document for this site"
   'The primary category cannot be deleted.' => 'The primary category cannot be deleted.',
   'Cannot make a dissociated category the primary category.' => 'Cannot make a dissociated category the primary category.'
   'Related [_1] "[_2]" is not activate. Please relate another [_1].' => 'Related [_1] "[_2]" is not activate. Please relate another [_1].'
   'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.' => 'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.'
   'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.' => 'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.'
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  'Include deleted' => 'Include deleted',
+  'Reactivate' => 'Reactivate',
+  'All Subelements' => 'All Subelements',
+      'Code' => 'Code',
+      'Code Select' => 'Code Select',
+      'Invalid codeselect code (didn't return an array ref of even size)' => 'Invalid codeselect code (didn't return an array ref of even size)',
+  'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.' => 'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.',
+  'Job "[_1]" has been reset.' => 'Job "[_1]" has been reset.',
   '[quant,_1,media,media] published.' => '[quant,_1,media,media] published.',
   '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
   '[quant,_1,story,stories] published.' => '[quant,_1,story,stories] published.',
   '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
+  'No context for content beginning at line [_1].' => 'No context for content beginning at line [_1].',
+  'No such field "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such field "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.' => 'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.',
+  'Unknown tag "[_1]" at line [_2].' => 'Unknown tag "[_1]" at line [_2].',
+  'No such site "[_1]" at line [_2].'=> 'No such site "[_1]" at line [_2].',
+  'No such URI "[_1]" in site "[_2]" at line [_3].' => 'No such URI "[_1]" in site "[_2]" at line [_3].',
+  'No story document found for UUID "[_1]" at line [_2].' => 'No story document found for UUID "[_1]" at line [_2].',
+  'No media document found for UUID "[_1]" at line [_2].' => 'No media document found for UUID "[_1]" at line [_2].',
+  'No story document found for ID "[_1]" at line [_2].' => 'No story document found for ID "[_1]" at line [_2].',
+  'No media document found for ID "[_1]" at line [_2].' => 'No media document found for ID "[_1]" at line [_2].',
+  'No story document found for URI "[_1]" at line [_2].' => 'No story document found for URI "[_1]" at line [_2].',
+  'No media document found for URI "[_1]" at line [_2].' => 'No media document found for URI "[_1]" at line [_2].',
+  'D (for Deployed)'  => 'D',
+  'P (for Published)' => 'P',
 
 =end comment
 
