@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
+$LastChangedDate: 2006-01-23 15:34:28 -0800 (Mon, 23 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ our %Lexicon =
      'Current Version' => '目前版本' ,
      'Currently Related Story' => '目前相關的稿件' ,
      'DISTRIBUTION' => '散佈' ,
-     'Data Elements' => '資料元素' ,
+     'Field Elements' => '資料元素' ,
      'Default Value' => '預設值' ,
      'Deployed Date' => '佈署的日期' ,
      'Description' => '描述' ,
@@ -431,7 +431,7 @@ our %Lexicon =
      'Alias in Category' => '分類中別名' ,
      'Alias to "[_1]" created and saved.' => '已經建立並儲存 "[_1]" 的別名' ,
      'All Types' => '所有類型' ,
-     'An "[_1]" attribute already exists. Please try another name.' => ' 「[_1]」 屬性已經存在，請選擇別的名稱' ,
+     'The "[_1]" field type already exists. Please try another key name.' => ' 「[_1]」 屬性已經存在，請選擇別的名稱' ,
      'An active template already exists for the selected output channel, category, element and burner you selected.  You must delete the existing template before you can add a new one.' => 'An active template already exists for the selected 所選的輸出頻道、分類、元素中已存在一個行動模板，你必須在儲存前刪除現有的模板' ,
      'An error occurred while processing your request:' => '在處理您的要求時，發生了一個錯誤；' ,
      'An error occurred.' => '發生錯誤。' ,
@@ -568,7 +568,7 @@ our %Lexicon =
      'No users were found' => '找不到使用者' ,
      'No workflows were found' => '找不到流程' ,
      'Note: Container element "[_1]" removed in bulk edit but will not be deleted.' => '注意：容器元素「[_1]」在大量編輯模式中被去掉了，但它並不會被刪除。' ,
-     'Note: Data element "[_1]" is required and cannot be completely removed.  Will delete all but one.' => '注意：資料元素「[_1]」為必要的，因此不能全部被移除，將會留下其中一個。' ,
+     'Note: Field element "[_1]" is required and cannot be completely removed.  Will delete all but one.' => '注意：資料元素「[_1]」為必要的，因此不能全部被移除，將會留下其中一個。' ,
      'Object Groups' => '物件群組' ,
      'Object Group Permissions' => '物件群組權限' ,
      'Or Pick a Type' => '或選擇一個類型' ,
@@ -667,7 +667,7 @@ our %Lexicon =
      'Warning! Bricolage is designed to run with JavaScript enabled.' => '警告！ Bricolage 設計成必須使用 JavaScript' ,
      'Warning! State inconsistent: Please use the buttons provided by the application rather than the \'Back\'/\'Forward\' buttons.' => 'Warning! State inconsistent: Please use the buttons provided by the application rather than the \'Back\'/\'Forward\' buttons.' ,
      'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_container\'.  Please use the element\'s \'key_name\' field instead.' => '警告: 以 \'name\' 欄位呼叫 \'get_container\' 的使用方式已被廢棄不用。請改用元素的 \'key_name\' 欄位。',
-     'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_data\'.  Please use the element\'s \'key_name\' field instead.' => '警告: 以 \'name\' 欄位呼叫 \'get_data\' 的使用方式已被廢棄不用。請改用元素的 \'key_name\' 欄位。',
+     'Warning:  Use of element\'s \'name\' field is deprecated for use with element method \'get_value\'.  Please use the element\'s \'key_name\' field instead.' => '警告: 以 \'name\' 欄位呼叫 \'get_value\' 的使用方式已被廢棄不用。請改用元素的 \'key_name\' 欄位。',
      'Warning: object "[_1]" had no associated desk.  It has been assigned to the "[_2]" desk.' => '警告：[_1] 沒有所屬的桌面，它已經被移動到 [_2] 這個桌面。' ,
      'Warning: object "[_1]" had no associated workflow.  It has been assigned to the "[_2]" workflow.' => '警告：「[_1]」物件並不屬於任何流程，所以已經被放入「[_2]」流程中。' ,
      'Warning: object "[_1]" had no associated workflow.  It has been assigned to the "[_2]" workflow. This change also required that this object be moved to the "[_3]" desk.' => '警告：「[_1]」物件並不屬於任何流程，所以已經被放入「[_2]」流程中。此項異動同時已把物件移到「[_3]」桌面。' ,
@@ -703,14 +703,42 @@ To translate:
   'You do not have permission to override user "[_1]"' => '您不得 override 使用者 "[_1]"'
   'Please select a primary output channel' => '請選擇一個主要輸出頻道',
   'Not defined.' => 'Not defined.',
+  'Milliseconds' => 'Milliseconds',
+  'Microseconds' => 'Microseconds',
+  'Not defined.' => 'Not defined.',
+  "You do not have sufficient permission to create a media document for this site" => "You do not have sufficient permission to create a media document for this site"
   'The primary category cannot be deleted.' => 'The primary category cannot be deleted.',
   'Cannot make a dissociated category the primary category.' => 'Cannot make a dissociated category the primary category.'
   'Related [_1] "[_2]" is not activate. Please relate another [_1].' => 'Related [_1] "[_2]" is not activate. Please relate another [_1].'
   'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.' => 'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.'
   'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.' => 'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.'
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  'Include deleted' => 'Include deleted',
+  'Reactivate' => 'Reactivate',
+  'Subelement' => 'Subelement',
+  'All Subelements' => 'All Subelements',
+      'Code' => 'Code',
+      'Code Select' => 'Code Select',
+      'Invalid codeselect code (didn't return an array ref of even size)' => 'Invalid codeselect code (didn't return an array ref of even size)',
+  'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.' => 'The error message is available below. No further execution attempts will be made on this job unless you check the "Reset this Job" checkbox below.',
+  'Job "[_1]" has been reset.' => 'Job "[_1]" has been reset.',
   '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
   '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
+  'No context for content beginning at line [_1].' => 'No context for content beginning at line [_1].',
+  'No such field "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such field "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?' => 'No such subelement "[_1]" at line [_2]. Did you mean "[_3]"?',
+  'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.' => 'Non-repeatable field "[_1]" appears more than once beginning at line [_2]. Please remove all but one.',
+  'Unknown tag "[_1]" at line [_2].' => 'Unknown tag "[_1]" at line [_2].',
+  'No such site "[_1]" at line [_2].'=> 'No such site "[_1]" at line [_2].',
+  'No such URI "[_1]" in site "[_2]" at line [_3].' => 'No such URI "[_1]" in site "[_2]" at line [_3].',
+  'No story document found for UUID "[_1]" at line [_2].' => 'No story document found for UUID "[_1]" at line [_2].',
+  'No media document found for UUID "[_1]" at line [_2].' => 'No media document found for UUID "[_1]" at line [_2].',
+  'No story document found for ID "[_1]" at line [_2].' => 'No story document found for ID "[_1]" at line [_2].',
+  'No media document found for ID "[_1]" at line [_2].' => 'No media document found for ID "[_1]" at line [_2].',
+  'No story document found for URI "[_1]" at line [_2].' => 'No story document found for URI "[_1]" at line [_2].',
+  'No media document found for URI "[_1]" at line [_2].' => 'No media document found for URI "[_1]" at line [_2].',
+  'D (for Deployed)'  => 'D',
+  'P (for Published)' => 'P',
 
 Notice:
 
