@@ -30,7 +30,7 @@ my @EXP_GRP_IDS;
 # The element object we'll use throughout.
 my $elem;
 sub get_elem {
-    $elem ||= Bric::Biz::AssetType->lookup({ id => 4 });
+    $elem ||= Bric::Biz::ElementType->lookup({ id => 4 });
     $elem;
 }
 
@@ -40,13 +40,14 @@ sub get_elem {
 my $z;
 sub new_args {
     my $self = shift;
-    ( element       => $self->get_elem,
+    ( element_type  => $self->get_elem,
       user__id      => $self->user_id,
       file_name     => 'fun.foo' . ++$z,
       source__id    => 1,
       primary_oc_id => 1,
       site_id       => 100,
-      category__id  => 1
+      category__id  => 1,
+      cover_date    => '2005-03-22 21:07:56',
     )
 }
 
@@ -54,7 +55,7 @@ sub new_args {
 # Test the SELECT methods
 ##############################################################################
 
-sub test_select_methods: Test(107) {
+sub test_select_methods: Test(120) {
     my $self = shift;
     my $class = $self->class;
 
@@ -169,8 +170,10 @@ sub test_select_methods: Test(107) {
                              element     => $element,
                              checked_out => 1,
                              site_id     => 100,
+                             note        => 'Note 1',
                            });
     $media[0]->set_category__id($OBJ->{category}->[0]->get_id());
+    $media[0]->set_cover_date('2005-03-23 06:11:29');
     $media[0]->add_contributor($self->contrib, 'DEFAULT');
     $media[0]->checkin();
     $media[0]->save();
@@ -183,14 +186,20 @@ sub test_select_methods: Test(107) {
     push @{$OBJ_IDS->{media}}, $media[0]->get_id();
     $self->add_del_ids( $media[0]->get_id() );
 
-    # Try doing a lookup
+    # Try doing a lookup by ID and UUID.
     $expected = $media[0];
-    ok( $got = $class->lookup({ id => $OBJ_IDS->{media}->[0] }),
-        'can we call lookup on a Media' );
-    is( $got->get_name(), $expected->get_name(),
-        '... does it have the right name');
-    is( $got->get_description, $expected->get_description,
-        '... does it have the right desc');
+    for my $idf (qw(id uuid)) {
+        my $meth = "get_$idf";
+        ok $got = class->lookup({ $idf => $expected->$meth }),
+          "Look up by $idf";
+        is $got->get_id, $expected->get_id, "... does it have the right ID";
+        is $got->get_uuid, $expected->get_uuid,
+          "... does it have the right UUID";
+        is $got->get_name(), $expected->get_name(),
+            '... does it have the right name';
+        is $got->get_description, $expected->get_description,
+            '... does it have the right desc';
+    }
 
     # check the URI
     my $exp_uri = $OBJ->{category}->[0]->get_uri;
@@ -238,8 +247,10 @@ sub test_select_methods: Test(107) {
                             element     => $element,
                             checked_out => 1,
                             site_id     => 100,
+                            note        => 'Note 2',
                            });
     $media[1]->set_category__id($OBJ->{category}->[1]->get_id());
+    $media[1]->set_cover_date('2005-03-23 06:11:29');
     $media[1]->save();
     $media[1]->save();
     push @{$OBJ_IDS->{media}}, $media[1]->get_id();
@@ -280,8 +291,10 @@ sub test_select_methods: Test(107) {
                              element     => $element,
                              checked_out => 1,
                              site_id     => 100,
+                             note        => 'Note 3',
                            });
     $media[2]->set_category__id( $OBJ->{category}->[0]->get_id() );
+    $media[2]->set_cover_date('2005-03-23 06:11:29');
     $media[2]->add_contributor($self->contrib, 'DEFAULT');
     $media[2]->checkin();
     $media[2]->save();
@@ -328,8 +341,10 @@ sub test_select_methods: Test(107) {
                              element     => $element,
                              checked_out => 1,
                              site_id     => 100,
+                             note        => 'Note 4',
                            });
     $media[3]->set_category__id( $OBJ->{category}->[0]->get_id );
+    $media[3]->set_cover_date('2005-03-23 06:11:29');
     $media[3]->save();
     $media[3]->save();
     push @{$OBJ_IDS->{media}}, $media[3]->get_id();
@@ -389,9 +404,11 @@ sub test_select_methods: Test(107) {
                              element     => $element,
                              checked_out => 1,
                              site_id     => 100,
+                             note        => 'Note 5',
                            });
     $media[4]->add_contributor($self->contrib, 'DEFAULT');
     $media[4]->set_category__id($OBJ->{category}->[0]->get_id());
+    $media[4]->set_cover_date('2005-03-23 06:11:29');
     $media[4]->set_workflow_id( $OBJ->{workflow}->[0]->get_id() );
     $media[4]->save;
     $media[4]->save;
@@ -436,8 +453,10 @@ sub test_select_methods: Test(107) {
                              element     => $element,
                              checked_out => 1,
                              site_id     => 100,
+                             note        => 'Note 6',
                            });
     $media[5]->set_category__id( $OBJ->{category}->[0]->get_id );
+    $media[5]->set_cover_date('2005-03-23 06:11:29');
     $media[5]->set_workflow_id( $OBJ->{workflow}->[0]->get_id );
     $media[5]->save;
 
@@ -696,6 +715,15 @@ sub test_select_methods: Test(107) {
         output_channel_id => ANY($oc1->get_id, $oc3->get_id)
     }), 'Get stories with first and third OC';
     is @$got, 2, 'Should now have two stories';
+
+    # Now search on notes.
+    ok $got = class->list({ note => 'Note 1'}), 'Search on note "Note 1"';
+    is @$got, 1, 'Should have one media';
+    ok $got = class->list({ note => 'Note %'}), 'Search on note "Note %"';
+    is @$got, 6, 'Should have six media';
+    ok $got = class->list({ note => ANY('Note 1', 'Note 2')}),
+                          'Search on note "ANY(Note 1, Note 2)"';
+    is @$got, 2, 'Should have two media';
 }
 
 ###############################################################################
@@ -801,7 +829,6 @@ sub test_new_grp_ids: Test(4) {
     my $class = $self->class;
     my $all_media_grp_id = $class->INSTANCE_GROUP_ID;
 
-    my ($att) = Bric::Biz::ATType->list({ name => 'Insets' });
     my $element = get_elem();
     my $cat = Bric::Biz::Category->new({ name        => "_test_$time.new",
                                          description => 'foo',
