@@ -6,8 +6,7 @@ use Test::More;
 use Test::Exception;
 use Bric::Util::DBI qw(:standard :junction);
 use Bric::Util::Time qw(strfdate);
-use Bric::Biz::ATType;
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 use Bric::Biz::Asset::Business::Story;
 use Bric::Biz::Workflow::Parts::Desk;
 use Bric::Biz::Workflow;
@@ -21,7 +20,7 @@ sub class { 'Bric::Biz::Asset::Business::Story' }
 sub table { 'story' }
 
 my $CATEGORY = Bric::Biz::Category->lookup({ id => 1 });
-my $ELEMENT_CLASS = 'Bric::Biz::AssetType';
+my $ELEMENT_CLASS = 'Bric::Biz::ElementType';
 my $OC_CLASS = 'Bric::Biz::OutputChannel';
 
 # this will be filled during setup
@@ -38,11 +37,16 @@ my @EXP_GRP_IDS;
 ##############################################################################
 # Constructs a new object.
 my $z;
+sub new_args {
+    my $self = shift;
+    return ($self->SUPER::new_args, slug => 'slug' . ++$z);
+}
+
 sub construct {
     my $s = shift->SUPER::construct(@_);
     $s->add_categories([1]);
     $s->set_primary_category(1);
-    $s->set_slug('slug' . ++$z);
+    $s->set_cover_date('2005-03-22 21:07:56');
     return $s;
 }
 
@@ -50,7 +54,7 @@ sub construct {
 # Test the clone() method.
 ##############################################################################
 
-sub test_clone : Test(17) {
+sub test_clone : Test(18) {
     my $self = shift;
     ok( my $story = $self->construct( name => 'Flubber',
                                       slug => 'hugo'),
@@ -79,10 +83,11 @@ sub test_clone : Test(17) {
 
     # Check that the story is really cloned!
     isnt( $sid, $cid, "Check for different IDs" );
+    isnt( $clone->get_uuid, $orig->get_uuid, "Check for different UUIDs" );
     is( $clone->get_title, $orig->get_title, "Compare titles" );
     is( $clone->get_slug, 'jarkko', "Compare slugs" );
     ok( my $ouri = $orig->get_uri, "Get original URI" );
-    $ouri =~ s/slug\d+/jarkko/;
+    $ouri =~ s/hugo/jarkko/;
     is( $clone->get_uri, $ouri, "Compare uris" );
 
     # Check that the output channels are the same.
@@ -95,7 +100,7 @@ sub test_clone : Test(17) {
 # Test the SELECT methods
 ##############################################################################
 
-sub test_select_methods: Test(138) {
+sub test_select_methods: Test(151) {
     my $self = shift;
     my $class = $self->class;
     my $all_stories_grp_id = $class->INSTANCE_GROUP_ID;
@@ -186,7 +191,7 @@ sub test_select_methods: Test(138) {
     }
 
     # look up a story element
-    my ($element) = Bric::Biz::AssetType->list({ name => 'Story' });
+    my ($element) = Bric::Biz::ElementType->list({ name => 'Story' });
 
     # and a user
     my $admin_id = $self->user_id;
@@ -204,11 +209,13 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 1',
                             });
 
     $story[0]->add_categories([ $OBJ->{category}->[0] ]);
     $story[0]->set_primary_category($OBJ->{category}->[0]);
     $story[0]->add_contributor($self->contrib, 'DEFAULT');
+    $story[0]->set_cover_date('2005-03-23 06:11:29');
     $story[0]->checkin();
     $story[0]->save();
     push @{$OBJ_IDS->{story}}, $story[0]->get_id();
@@ -237,17 +244,23 @@ sub test_select_methods: Test(138) {
     $story[0]->checkin();
     $story[0]->save();
 
-    # Try doing a lookup
+    # Try doing a lookup by ID and UUID.
     $expected = $story[0];
-    ok( $got = class->lookup({ id => $OBJ_IDS->{story}->[0] }),
-        'can we call lookup on a Story' );
-    is( $got->get_name(), $expected->get_name,
-        '... does it have the right name');
-    is( $got->get_description(), $expected->get_description(),
-        '... does it have the right desc');
+    for my $idf (qw(id uuid)) {
+        my $meth = "get_$idf";
+        ok $got = class->lookup({ $idf => $expected->$meth }),
+          "Look up by $idf";
+        is $got->get_id, $expected->get_id, "... does it have the right ID";
+        is $got->get_uuid, $expected->get_uuid,
+          "... does it have the right UUID";
+        is $got->get_name(), $expected->get_name(),
+            '... does it have the right name';
+        is $got->get_description, $expected->get_description,
+            '... does it have the right desc';
+    }
 
     # check the URI
-    my $exp_uri = $OBJ->{category}->[0]->get_uri . '/test';
+    my $exp_uri = $OBJ->{category}->[0]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri(), qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -290,10 +303,12 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 2',
                             });
 
     $story[1]->add_categories( $OBJ->{category} );
     $story[1]->set_primary_category( $OBJ->{category}->[1] );
+    $story[1]->set_cover_date('2005-03-23 06:11:29');
     $story[1]->checkin();
     $story[1]->save();
     push @{$OBJ_IDS->{story}}, $story[1]->get_id();
@@ -309,7 +324,7 @@ sub test_select_methods: Test(138) {
         '... does it have the right desc');
 
     # check the URI
-    $exp_uri = $OBJ->{category}->[1]->get_uri . '/test';
+    $exp_uri = $OBJ->{category}->[1]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri, qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -337,11 +352,13 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 3',
                             });
 
     $story[2]->add_categories([ $OBJ->{category}->[0] ]);
     $story[2]->set_primary_category( $OBJ->{category}->[0] );
     $story[2]->add_contributor($self->contrib, 'DEFAULT');
+    $story[2]->set_cover_date('2005-03-23 06:11:29');
     $story[2]->checkin();
     $story[2]->save();
     $story[2]->checkout({ user__id => $self->user_id });
@@ -361,7 +378,7 @@ sub test_select_methods: Test(138) {
         '... does it have the right desc');
 
     # check the URI
-    $exp_uri = $OBJ->{category}->[0]->get_uri . '/test';
+    $exp_uri = $OBJ->{category}->[0]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri, qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -386,10 +403,12 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 4',
                             });
 
     $story[3]->add_categories([ $OBJ->{category}->[0] ]);
     $story[3]->set_primary_category( $OBJ->{category}->[0] );
+    $story[3]->set_cover_date('2005-03-23 06:11:29');
     $story[3]->checkin();
     $story[3]->save();
     push @{$OBJ_IDS->{story}}, $story[3]->get_id();
@@ -418,7 +437,7 @@ sub test_select_methods: Test(138) {
         '... does it have the right desc');
 
     # check the URI
-    $exp_uri = $OBJ->{category}->[0]->get_uri . '/test';
+    $exp_uri = $OBJ->{category}->[0]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri, qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -447,10 +466,12 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 4',
                             });
 
     $story[4]->add_categories([ $OBJ->{category}->[0] ]);
     $story[4]->set_primary_category($OBJ->{category}->[0]);
+    $story[4]->set_cover_date('2005-03-23 06:11:29');
     $story[4]->set_workflow_id( $OBJ->{workflow}->[0]->get_id() );
     $story[4]->add_contributor($self->contrib, 'DEFAULT');
     $story[4]->checkin();
@@ -469,7 +490,7 @@ sub test_select_methods: Test(138) {
         '... does it have the right desc');
 
     # check the URI
-    $exp_uri = $OBJ->{category}->[0]->get_uri . '/test';
+    $exp_uri = $OBJ->{category}->[0]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri(), qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -494,10 +515,12 @@ sub test_select_methods: Test(138) {
                               user__id    => $admin_id,
                               element     => $element,
                               site_id     => 100,
+                              note        => 'Note 6',
                             });
 
     $story[5]->add_categories([ $OBJ->{category}->[0] ]);
     $story[5]->set_primary_category($OBJ->{category}->[0]);
+    $story[5]->set_cover_date('2005-03-23 06:11:29');
     $story[5]->set_workflow_id( $OBJ->{workflow}->[0]->get_id() );
     $story[5]->save;
 
@@ -521,7 +544,7 @@ sub test_select_methods: Test(138) {
         '... does it have the right desc');
 
     # check the URI
-    $exp_uri = $OBJ->{category}->[0]->get_uri . '/test';
+    $exp_uri = $OBJ->{category}->[0]->get_uri . '2005/03/23/test';
     like( $got->get_primary_uri(), qr/^$exp_uri/,
           '...does the uri match the category and slug');
 
@@ -832,6 +855,15 @@ sub test_select_methods: Test(138) {
         output_channel_id => ANY($oc1->get_id, $oc3->get_id)
     }), 'Get stories with first and third OC';
     is @$got, 2, 'Should now have two stories';
+
+    # Now search on notes.
+    ok $got = class->list({ note => 'Note 1'}), 'Search on note "Note 1"';
+    is @$got, 1, 'Should have one story';
+    ok $got = class->list({ note => 'Note %'}), 'Search on note "Note %"';
+    is @$got, 6, 'Should have six stories';
+    ok $got = class->list({ note => ANY('Note 1', 'Note 2')}),
+                          'Search on note "ANY(Note 1, Note 2)"';
+    is @$got, 2, 'Should have two stories';
 }
 
 
@@ -999,16 +1031,14 @@ sub test_new_grp_ids: Test(5) {
     my $class = $self->class;
     my $all_stories_grp_id = $class->INSTANCE_GROUP_ID;
     my $time = time;
-    my ($att) = Bric::Biz::ATType->list({ name => 'Insets' });
-    my $element = Bric::Biz::AssetType->new
+    my $element = Bric::Biz::ElementType->new
       ({ name        => "_test_$time.new",
          key_name    => "_test_$time.new",
          burner      => 1,
          description => 'this is a test',
-         type__id    => $att->get_id,
        });
     $element->save;
-    $self->add_del_ids($element->get_id, 'element');
+    $self->add_del_ids($element->get_id, 'element_type');
     my $cat = Bric::Biz::Category->new({ name => "_test_$time.new",
                                          description => 'foo',
                                          directory => "_test_$time.new",
