@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw(Bric::Test::DevBase);
 use Test::More;
-use Bric::Config qw(:temp);
+use Bric::Config qw(:temp :time);
 use Bric::Dist::Resource;
 use Bric::Util::Job::Dist;
 use Bric::Util::Time qw(strfdate);
@@ -111,15 +111,17 @@ sub test_setup : Test(setup => 50) {
     }
 
     # Save the jobs.
+    my @jids;
     for my $i (0, 1) {
         ok( $jobs[$i]->save, "Save job $i" );
-        ok( $jobs[$i] = $jobs[$i]->get_id, "Get job $i ID" );
+        ok( $jids[$i] = $jobs[$i]->get_id, "Get job $i ID" );
     }
-    $self->add_del_ids(\@jobs, 'job');
-    $self->{jids} = \@jobs;
+    $self->add_del_ids(\@jids, 'job');
+    $self->{jids}  = \@jids;
+    $self->{jobs}  = \@jobs;
     $self->{paths} = \@paths;
-    $self->{rids} = \@rids;
-    $self->{res} = \@res;
+    $self->{rids}  = \@rids;
+    $self->{res}   = \@res;
 }
 
 ##############################################################################
@@ -137,14 +139,15 @@ sub test_lookup : Test(9) {
     is( $res->get_path, $self->{res}[0]->get_path, "Check path" );
     is( $res->get_uri, $self->{res}[0]->get_uri, "Check uri" );
     is( $res->get_size, $self->{res}[0]->get_size, "Check size" );
-    is( $res->get_mod_time, strfdate((stat $self->{res}[0]->get_path)[9]),
+    is( $res->get_mod_time(ISO_8601_FORMAT),
+        strfdate((stat $self->{res}[0]->get_path)[9]),
         "Check mod time" );
     ok( !$res->is_dir, "Check it's not a directory" );
 }
 
 ##############################################################################
 # Test the list() method.
-sub test_list : Test(42) {
+sub test_list : Test(48) {
     my $self = shift;
     # Try uri.
     ok( my @ress = Bric::Dist::Resource->list
@@ -208,7 +211,7 @@ sub test_list : Test(42) {
 
     # Try a range of sizes.
     ok( @ress = Bric::Dist::Resource->list({ size => [$size - 1, $size] }),
-        "Look up size between " . ($size - 1) . "and '$size'" );
+        "Look up size between '" . ($size - 1) . "' and '$size'" );
     is( scalar @ress, 5, "Check for 5 resources" );
 
     # Try is_dir.
@@ -249,6 +252,25 @@ sub test_list : Test(42) {
     ok( @ress = Bric::Dist::Resource->list({ not_job_id => $self->{jids}[1] }),
         "Look up not_job_id '$self->{jids}[1]'" );
     is( scalar @ress, 3, "Check for 2 resources" );
+
+    # Try oc_id.
+    ok( my $oc = Bric::Biz::OutputChannel->lookup({ id => 1 }),
+        'Lookup Web OC' );
+    ok( my $dest = Bric::Dist::ServerType->new({
+        name        => 'tester',
+        site_id     => 100,
+        move_method => 'File System'
+    }), 'Create destination');
+    ok $dest->add_output_channels($oc), 'Add the Web OC to it';
+    ok $dest->save, 'Save the destination';
+    $self->add_del_ids($dest->get_id, 'server_type');
+
+    # Associate one of the jobs with the server type.
+    $self->{jobs}[0]->add_server_types($dest)->save;
+
+    ok( @ress = Bric::Dist::Resource->list({ oc_id => 1 }),
+        "Look up oc_id '5'" );
+    is( scalar @ress, 5, "Check for 5 resources" );
 }
 
 ##############################################################################
@@ -322,7 +344,7 @@ sub test_href : Test(47) {
 
     # Try a range of sizes.
     ok( $ress = Bric::Dist::Resource->href({ size => [$size - 1, $size] }),
-        "Look up size between " . ($size - 1) . "and '$size'" );
+        "Look up size between '" . ($size - 1) . "' and '$size'" );
     is( scalar keys %$ress, 5, "Check for 5 resources" );
 
     # Try is_dir.
@@ -433,7 +455,7 @@ sub test_list_ids : Test(42) {
 
     # Try a range of sizes.
     ok( @res_ids = Bric::Dist::Resource->list_ids({ size => [$size - 1, $size] }),
-        "Look up size between " . ($size - 1) . "and '$size'" );
+        "Look up size between '" . ($size - 1) . "' and '$size'" );
     is( scalar @res_ids, 5, "Check for 5 resource IDs" );
 
     # Try is_dir.
