@@ -2,7 +2,7 @@ package Bric::Test::DevBase;
 
 =head1 NAME
 
-Bric::Test::Base - Bricolage Development Testing Base Class
+Bric::Test::DevBase - Bricolage Development Testing Base Class
 
 =head1 VERSION
 
@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-10-28 22:37:50 -0700 (Fri, 28 Oct 2005) $
+$LastChangedDate: 2006-03-17 16:26:34 -0800 (Fri, 17 Mar 2006) $
 
 =head1 SYNOPSIS
 
@@ -29,10 +29,17 @@ $LastChangedDate: 2005-10-28 22:37:50 -0700 (Fri, 28 Oct 2005) $
   use Bric::Util::Grp::Person;
 
   sub table { 'person' }
+  my $epoch = CORE::time;
 
   # Write some tests.
   sub test_me : Test(4) {
       my $self = shift;
+
+      # Make time static for the duration of this test method.
+      no warnings qw(redefine);
+      local *CORE::GLOBAL::time = sub () { $epoch };
+
+      # Run some tests.
       ok( my $p = Bric::Biz::Person->new, "create" );
       ok( $p->save, "save" );
       $self->add_del_ids($p->get_id);
@@ -48,6 +55,10 @@ classes. It uses the L<Bric::Test::Base|Bric::Test::Base> module as I<its>
 base class, and thus all of its subclasses get all of its benefits. It also
 has a number of methods of its own that are designed to be used in classes
 inherited from this class. They help keep the database cleaned up and such.
+And finally, it sets up the admin user object in the session so that event
+logging and the like works properly and overrides the Perl core C<time>
+function so that individual test methods can override it on an as-needed
+basis.
 
 =cut
 
@@ -56,9 +67,24 @@ use warnings;
 require 5.006;
 use base qw(Bric::Test::Base);
 
+BEGIN {
+    # Override the time function, but just have it use CORE::time. This will
+    # allow us to hijack the function later by locally redefining
+    # CORE::GLOBAL::time. This is to prevent those tests that test for the
+    # time *right now* from getting screwed up by the clock turning over.
+    # NOTE: This MUST come before any Bricolage module that uses
+    # Bric::Util::Time gets loaded!
+    *CORE::GLOBAL::time = sub () { CORE::time() };
+}
+
+# Must come after the BEGIN block.
+use Bric::Biz::Person::User;
+
+##############################################################################
+
 =head1 INTERFACE
 
-Bric::Test::Base inherits from L<Bric::Test::Base|Bric::Test::Base>, and
+Bric::Test::DevBase inherits from L<Bric::Test::Base|Bric::Test::Base>, and
 therefore the entire interface of that class is available to
 Bric::Test::DevBase and its subclasses. The following additional methods have
 been added to its interface.
@@ -137,7 +163,7 @@ sub del_ids : Test(teardown => 0) {
     _del_sites($to_delete) if $to_delete->{site};
 
     # Delete assets, first.
-    foreach my $table (qw(story media formatting)) {
+    foreach my $table (qw(story media template)) {
         if (my $ids = delete $to_delete->{$table}) {
             _do_deletes($table, $ids);
         }
@@ -148,8 +174,9 @@ sub del_ids : Test(teardown => 0) {
         _do_deletes($table, $ids);
     }
 
-    # Finally, delete any groups, members, and events.
+    # Finally, delete any events, orgs, groups, and members.
     Bric::Util::DBI::prepare(qq{DELETE FROM event  WHERE id > 1023})->execute;
+    Bric::Util::DBI::prepare(qq{DELETE FROM org    WHERE id > 1   })->execute;
     Bric::Util::DBI::prepare(qq{DELETE FROM grp    WHERE id > 1023})->execute;
     Bric::Util::DBI::prepare(qq{DELETE FROM member WHERE id > 1023})->execute;
 }
@@ -199,6 +226,15 @@ sub _del_sites {
     }
 }
 
+{
+    # Set up the user object so that event logging works properly.
+    my $user = Bric::Biz::Person::User->lookup({ id => __PACKAGE__->user_id });
+    $HTML::Mason::Commands::session{_bric_user} = {
+        object => $user,
+        login  => $user->get_login,
+        id     => $user->get_id,
+    };
+}
 1;
 __END__
 
@@ -206,7 +242,7 @@ __END__
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
