@@ -18,7 +18,7 @@ use Test::MockModule;
 
 sub table {'job '}
 
-my $date = '2003-01-22 14:43:23';
+my $date = '2003-01-22 14:43:23.000000';
 
 my %job = ( name => 'Test Job',
             user_id => __PACKAGE__->user_id,
@@ -301,6 +301,8 @@ sub test_save : Test(9) {
     ok( Bric::Util::Job::Dist->lookup({ id => $jid }),
         "Look it up again" );
     is( $job->get_name, $new_name, "Check name is '$new_name'" );
+    # Commit so we can be sure all records will be deleted.
+    Bric::Util::DBI::commit();
 }
 
 ##############################################################################
