@@ -15,18 +15,18 @@ use Bric::Dist::Resource;
 use Bric::Config qw(:time TEMP_DIR QUEUE_PUBLISH_JOBS);
 use Bric::Util::Trans::FS;
 use Bric::Util::MediaType;
-use Bric::Biz::AssetType;
+use Bric::Biz::ElementType;
 use Bric::Biz::Asset::Business::Story;
 use Bric::Biz::Asset::Business::Media;
 use Bric::Util::Burner;
 use Bric::Biz::Person::User;
-use Bric::Biz::Asset::Formatting;
+use Bric::Biz::Asset::Template;
 use Bric::Util::DBI qw(:junction);
 use Test::MockModule;
 
-sub table {'job '}
+sub table {'job'}
 
-my $date = '2003-01-22 14:43:23';
+my $date = '2003-01-22 14:43:23.000000';
 
 my %job = (
             name => 'Test Job',
@@ -52,7 +52,7 @@ sub test_teardown : Test(teardown) {
 # Clean out possible test values from Job.tst. We can delete this if we ever
 # delete the .tst files.
 ##############################################################################
-sub _clean_test_vals : Test(0) {
+sub _clean_test_vals : Test(startup) {
     my $self = shift;
     $self->add_del_ids([1,2]);
 }
@@ -62,7 +62,7 @@ sub _clean_test_vals : Test(0) {
 # found because we're using a temporary directory.
 ##############################################################################
 sub _run_me_first : Test(4) {
-    ok( my @tmpl = Bric::Biz::Asset::Formatting->list({
+    ok( my @tmpl = Bric::Biz::Asset::Template->list({
         output_channel__id => 1,
         file_name          => ANY('/story.mc', '/autohandler'),
         Order              => 'file_name',
@@ -113,14 +113,14 @@ sub b_test_lookup : Test(7) {
 
 ##############################################################################
 # Test the list() method.
-sub c_test_list : Test(45) {
+sub c_test_list : Test(47) {
     my $self = shift;
 
     # Create a new job group.
     ok( my $grp = Bric::Util::Grp::Job->new({ name => 'Test JobGrp' }),
         "Create group" );
 
-    my ($element) = Bric::Biz::AssetType->list({ name => 'Story' });
+    my ($element) = Bric::Biz::ElementType->list({ name => 'Story' });
     # And the default OutputChannel.
     my ($oc) = Bric::Biz::OutputChannel->list();
 
@@ -151,8 +151,10 @@ sub c_test_list : Test(45) {
     my $cat = Bric::Biz::Category->lookup({ id => 1 });
     $story->add_categories([$cat]);
     $story->set_primary_category($cat);
+    $story->set_cover_date('2005-03-22 21:07:56');
     $story->save();
-    my $sid = $story->get_id;
+    my $svid = $story->get_version_id;
+    my $sid  = $story->get_id;
     $self->add_del_ids($sid, 'story');
 
     # XXX Check media too !!!
@@ -166,7 +168,7 @@ sub c_test_list : Test(45) {
             $args{server_types} = [$dest];
         } else {
             # Add story ID. Will be two of these.
-            $args{story_id} = $sid;
+            $args{story_instance_id} = $svid;
         }
 
         ok( my $job = Bric::Util::Job::Pub->new(\%args), "Create $args{name}" );
@@ -252,10 +254,15 @@ sub c_test_list : Test(45) {
         "Look up server_type_id '$did'" );
     is( scalar @jobs, 3, "Check for 3 jobs" );
 
-    ## Try story_id.
+    # Try story_id.
     ok( @jobs = Bric::Util::Job::Pub->list({ story_id => $sid }),
         "Look up story_id '$sid'" );
     is( scalar @jobs, 2, "Check for 2 jobs" );
+
+    # Try story_instance_id.
+    ok( @jobs = Bric::Util::Job::Pub->list({ story_instance_id => $svid }),
+        "Look up story_instance_id '$svid'" );
+    is( scalar @jobs, 2, "Check for 2 jobs" );
 }
 
 ##############################################################################
@@ -337,7 +344,7 @@ sub g_test_execute_me : Test(10) {
     my $self = shift;
     my %args = %job;
     # Get the story element
-    my ($element) = Bric::Biz::AssetType->list({ name => 'Story' });
+    my ($element) = Bric::Biz::ElementType->list({ name => 'Story' });
     # And the default OutputChannel.
     my ($oc) = Bric::Biz::OutputChannel->list();
     # and a user
@@ -366,13 +373,14 @@ sub g_test_execute_me : Test(10) {
     my $cat = Bric::Biz::Category->lookup({ id => 1 });
     $story->add_categories([$cat]);
     $story->set_primary_category($cat);
+    $story->set_cover_date('2005-03-22 21:07:56');
     $story->save();
     my $sid = $story->get_id;
     $self->add_del_ids($sid, 'story');
     # create a job
     my $job = Bric::Util::Job::Pub->new(\%args);
     # add the story to the job
-    $job->set_story_id($story->get_id);
+    $job->set_story_instance_id($story->get_version_id);
     # set the job execution time to now
     $job->set_sched_time(local_date(0, ISO_8601_FORMAT, 1));
     # test: Save the job.  With the default config file this will have the
@@ -436,22 +444,21 @@ Page 1
 
 ##############################################################################
 # Test execute_me error_handling.
-sub h_test_execute_me : Test(10) {
+sub h_test_execute_me : Test(16) {
     my $self = shift;
 
-    my $elem = Bric::Biz::AssetType->new({
+    my $elem = Bric::Biz::ElementType->new({
         name          => 'Test Element',
         key_name      => 'test_element',
         description   => 'Testing Publish Job error handling',
-        burner        => Bric::Biz::AssetType::BURNER_MASON,
-        type__id      => 1,
+        top_level     => 1,
         reference     => 0,
         primary_oc_id => 1
     });
     $elem->save;
-    $self->add_del_ids($elem->get_id, 'element');
+    $self->add_del_ids($elem->get_id, 'element_type');
 
-    my $tmpl = Bric::Biz::Asset::Formatting->new({
+    my $tmpl = Bric::Biz::Asset::Template->new({
         output_channel__id => 1,
         user__id           => $self->user_id,
         category_id        => 1,
@@ -460,7 +467,7 @@ sub h_test_execute_me : Test(10) {
         data               => '% die "Goodbye cruel world !";',
     });
     $tmpl->save;
-    $self->add_del_ids($tmpl->get_id, 'formatting');
+    $self->add_del_ids($tmpl->get_id, 'template');
 
     # Create a burner.
     my $fs = Bric::Util::Trans::FS->new;
@@ -504,9 +511,11 @@ sub h_test_execute_me : Test(10) {
     $story->set_primary_category($cat);
     $story->add_output_channels($oc);;
     $story->set_primary_oc_id(1);
+    $story->set_cover_date('2005-03-22 21:07:56');
     $story->save;
     $self->add_del_ids($story->get_id, 'story');
 
+    # Make sure that the old story_id parameter still works.
     my $job = Bric::Util::Job::Pub->new({
         name        => 'Test Job',
         user_id     => $self->user_id,
@@ -535,6 +544,16 @@ sub h_test_execute_me : Test(10) {
     dies_ok {$job->execute_me} "Try again.";
     is($job->get_tries, 3, "... should have three tries now.");
     is($job->has_failed, 1, "... has_failed should now return true.");
+
+    # Try resetting the job.
+    ok($job->reset, 'Reset the job');
+    ok($job->save, 'Save the reset job');
+    ok($job = Bric::Util::Job::Pub->lookup({ id => $job->get_id}),
+       'Look up the job again for good measure');
+    is($job->get_error_message, undef,
+       'The error message should be undefined again');
+    is($job->get_tries, 0, 'Tries should be reset');
+    is($job->has_failed, 0, 'The job should no loner be marked as failed');
 }
 
 1;
